
/* Sample program for testing terminfo definitions                 */
/* 03-08-91                                                        */
/* 07/09/91  ICHOST 3.21 Upgraded to handle Control Codes          */
/* 07/17/91              Support PrintON and PrintOFF              */
/* 11/08/91              Add move(), Bright-Underline-Reverse case */
/* 03/28/92         3.30 Give slighly better errors on start-up    */
/* 08/17/93  ICOBOL 2.00 Updated                                   */
/* 01/12/00  ICOBOL 2.62 Unixware7 does not have ttytype           */

/* Compile with the following

    XENIX:    cc -o termi termi.c -ltinfo
    UNIX:     cc -o termi termi.c -lcurses
    LINUX:    cc -o termi termi.c -lncurses
    UNIXWARE7 cc -DNOTTYTYPE -o termi termi.c -lcurses

*/



#define M_TERMINFO     /* Needed under XENIX */

#ifdef __linux__
#include <ncurses/ncurses.h>
#include <ncurses/term.h>
#else
#include <curses.h>
#include <term.h>
#endif
#include <stdlib.h>
#include <errno.h>

#define ESCAPECHAR  0033


/*
  * Outchar is a function version of putchar that can be passed to
  * tputs as a routine call.
  *
*/
outch(c)
    char c;
{
    putchar (c);
}


main()
{
    int
        escflag, res;
    char *terminalname;

    printf ("\nTerminal I/O tester\n");

    terminalname = getenv ("TERM");
    if ( newterm ( getenv ("TERM"), stdout, stdin) == NULL ) {
        printf ("\n  Error in getting terminal type >%s<.  errno = %d.\n", terminalname, errno);
        printf ("  Below is the initscr error message.\n");
        initscr ();
        goto exitit;
    }
    else {
        endwin ();
        initscr ();
    }

    keypad (stdscr, TRUE);   /* setup to get function keys */

/*    nonl();       /* unset nl mapping */
/*    cbreak();     /* set cbreak mode */
/*    noecho();     /* unset echomode */
/*      raw();  */

/* Line 1 */
    move(0,0);
#ifndef NOTTYTYPE
    addstr("This is terminal type: ");
    addstr(ttytype);
#else
    addstr("No terminal type.");
#endif

/* Line 3 */
    move(2,9);
    addstr("Inside curses (starts at line 3, col 10)\n");
    refresh();

/* Line 4 */
    attrset(A_NORMAL);
    refresh();
    attrset(A_REVERSE);
    addstr("This should be reverse, ");
    attrset(A_NORMAL);
    addstr("normal (not bright), ");
    attrset(A_BOLD);
    addstr("bright, ");
    attrset(A_UNDERLINE);
    addstr("underline, and ");
    attrset(A_BLINK);
    addstr("blink.\n");
    refresh();

/* Line 5 */
    /* The STANDOUT characteristic is not used by ICOBOL */
    attrset(A_STANDOUT);
    addstr("Standout(p1), ");
    attrset(A_UNDERLINE);
    addstr("underline(p2), ");
    attrset(A_REVERSE);
    addstr("reverse(p3), ");
    attrset(A_BLINK);
    addstr("blink(p4), ");
    /* The DIM characteristic is not used by ICOBOL */
    attrset(A_DIM);
    addstr("dim(p5), ");
    attrset(A_BOLD);
    addstr("bright(p6),");
    attrset(A_NORMAL);
    addstr("normal\n");
    refresh();

/* Line 6 */
    attrset(A_UNDERLINE | A_BLINK);
    addstr("This should be blinking underline, ");
    attrset(A_BOLD | A_BLINK);
    addstr("blinking bright, and ");
    attrset(A_REVERSE | A_BLINK);
    addstr("blinking reverse.\n");
    refresh();

/* Line 7 */
    attrset(A_BLINK);
    addstr("This should be only-blinking, ");
    attrset(A_BLINK | A_REVERSE);
    addstr("blinking-reverse, and ");
    attrset(A_REVERSE | A_UNDERLINE | A_BOLD);
    addstr("underline-bright-reverse.");
    attrset(A_NORMAL);
    refresh();

/* Line 9 */
    move(8,9);
    addstr("Keys are: (starts at line 9, col 10)\n");

/* Line 10 */
    addstr(" down-, up-, left-, right-arrow, home, bs, f0   are octal 402-410\n");
/* Line 11 */
    /* Remember that curses requires all function keys f1-f63 to be
       contiguoues, i.e., there must not be holes in the table.
       ICOBOL does not have this requirement.
    */
    addstr(" f1-f15, f16-f30,                               are octal 411-427, 430-446\n");
/* Line 11 */
    addstr(" f31-f45, f46-f60                               are octal 447-465, 466-504\n");
/* Line 12 */
    addstr(" f61-f63, dl, il, dc, ic, eic, clear, eos, eol  are octal 505-517\n");
/* Line 13 */
    addstr("          a1, a3, b2, c1, c3, btab              are octal 534-541\n");

    while ( TRUE ) {
        attrset(A_NORMAL);

/* Line 17 */
        move (16,14);
        clrtoeol ();
        addstr("Enter 2 ESCs to continue, P for Printer-on, O for Printer-off.");
/* Line 16 */
        move (15,10);
        clrtoeol ();
        addstr("Now enter a character: ");
        refresh ();

        res = getch();
/* Note:  For function keys to work correctly there must be
          no holes in the key_f1-key_f60 range else curses
          stops looking for a match with the first null entry

          The problem mentioned above does not effect ICOBOL itself.
*/

        if ( res == -1 ) {
            goto nextloop;
        }
/* Line 19 */
        move (18,1);
        clrtoeol ();
/* Line 18 */
        move (17,1);
        clrtoeol();
        refresh();

        if ( res >= KEY_BREAK ) {
            addstr("The function key was ");
            printw ( "Dec %d  Hex %X  Octal %o", res, res, res);
            escflag = 0;
        }
        else {
            if ( res == ESCAPECHAR ) {
                if ( escflag == 1 ) {
                    break;
                }
                escflag = 1;
                addstr("ESCAPE was hit");
            }
            else {
                if ( res <= 31 ) {
                    addstr("The control key was ");
                    printw ( "Dec %d  Hex %X  Octal %o", res, res, res);
                    addstr("  read character: ");
                    addch (res);
                    escflag = 0;
                }
                else {
                    if ( res == 80 ) {    /* P to send Print-on */
                        tputs(prtr_on, 1, outch);
                        escflag = 0;
                    }
                    else {
                        if ( res == 79 ) {   /* O to send Print-off */
                            tputs(prtr_off, 1, outch);
                            escflag = 0;
                        }
                        else {
                            addstr("This is the read character: ");
                            addch (res);
                            printw ( "  Dec %d  Hex %X  Octal %o", res, res, res);
                            escflag = 0;
                        }
                    }
                }
            }
        }
nextloop:
        refresh();

    }    /* while */

    refresh();
    addstr("\nNow enter another character: ");
again:
    refresh ();
    res = getch();
    if ( res == -1 ) {
        goto again;
    }
    if ( res >= KEY_BREAK ) {
        addstr("\nThe function key was ");
        printw ( "Dec %d  Hex %X  Octal %o", res, res, res);
    }
    else {
        addstr("\nThis is the read character: ");
        addch (res);
    }
    refresh();

    scrollok(stdscr,TRUE);
    addstr("\nThis should be NORMAL\n");
    refresh();
    addstr("This should be NORMAL\n");
    refresh();
    addstr("This should be NORMAL\n");
    refresh();
    addstr("This should be NORMAL\n");
    refresh();
    addstr("This should be NORMAL5\n");
    refresh();
    addstr("This should be NORMAL6\n");
    refresh();
    addstr("This should be NORMAL7\n");
    refresh();
    addstr("This should be NORMAL8\n");
    refresh();
    addstr("This should be NORMAL9\n");
    refresh();
    addstr("This should be NORMAL10\n");
    refresh();
    addstr("This should be NORMAL11\n");
    refresh();
    addstr("This should be NORMAL12\n");
    refresh();
    addstr("This should be NORMAL13\n");
    refresh();


    addstr ("\nThe end");
    refresh();


    endwin();     /* end screen initiazization */
exitit:

    printf ("\nTermination\n");

    exit (0);

}   /* main */
