/*  RUNERRS.H - COBOL Runtime error definitions

    Copyright (C) 1990-2006 Envyr Corporation.
    All rights reserved.

    This file encompasses the message codes used by the cobol runtime
    and the UFOS data manager

    NOTE: As of this file is processed by h2c to build a compiled message
          array for builtin messages and also by icmakems to build
          customized message text in a .ms file.
          As a result, the #defines are limited to simple aliases or equates
          to a numeric value.
          If the define is of the form #define <name> <number> <comment>
          and <comment> starts with MSG, it is taken as a message definition,
          with the message text as a quoted string (C conventions).

    NOTE WELL:
          When customizing message text, only the text should be changed,
          never the numeric value of the message.  The customized messages
          will be in a file named runerrs.ms.
*/

/****************************************************************/
/*                                                              */
/*    runtime and debugger error group (RE_xxx) - 2048-2559     */
/*                                                              */
/****************************************************************/

#define RE_INIT_BLTNS           2048        /* MSG "System-defined builtin initialization" */
#define RE_INIT_USER_BLTNS      2049        /* MSG "User-defined builtin initialization" */
#define RE_INIT_SDMGR           2050        /* MSG "Screen Handler builtin initialization" */
#define RE_INV_DATE             2051        /* MSG "Invalid DATE data value" */
#define RE_INV_TIME             2052        /* MSG "Invalid TIME data value" */
#define RE_INV_TIMESTAMP        2053        /* MSG "Invalid TIMESTAMP data value" */
#define RE_INV_INTERVAL         2054        /* MSG "Invalid INTERVAL data value" */
#define RE_SYM_NOT_FOUND        2055        /* MSG "The required shared library symbol was not found" */
#define RE_TERM_IN_USE          2056        /* MSG "Terminal is already in use" */
#define RE_REASSIGN             2057        /* MSG " (trying to reassign)" */
#define RE_NO_UNASSIGN          2058        /* MSG "There are no more unassigned consoles available" */
#define RE_TERM_NO_ICRUN        2059        /* MSG "The specified terminal is not configured to run ICRUN" */

/* Runtime data entry errors */
#define RE_ALPHABETIC           2060        /* MSG "The character must be alphabetic" */
#define RE_ALPHANUMERIC         2061        /* MSG "The character must be alphanumeric" */
#define RE_NUMERIC              2062        /* MSG "The character must be numeric" */
#define RE_RT_SIGN              2063        /* MSG "The sign must be the rightmost character" */
#define RE_SIGN_CNT             2064        /* MSG "Too many signs have been entered" */
#define RE_LEFT_SIGN            2065        /* MSG "The sign must be the leftmost character" */
#define RE_NO_DECPT             2066        /* MSG "The field does not permit a decimal point" */
#define RE_DECPT_CNT            2067        /* MSG "Too many decimal points have been entered" */
#define RE_NO_DIGITS            2068        /* MSG "No digits were entered" */
#define RE_DATA_REQ             2069        /* MSG "Data entry is required" */
#define RE_FULL_REQ             2070        /* MSG "A full field is required" */
#define RE_NO_SIGN              2071        /* MSG "The field does not permit a sign" */
#define RE_INT_CNT              2072        /* MSG "Too many integer digits were entered" */
#define RE_DEC_CNT              2073        /* MSG "Too many decimal digits were entered" */
#define RE_BLANKS               2074        /* MSG "There are illegal imbedded blanks" */
#define RE_STR_OVERFLOW         2075        /* MSG "String/Unstring Overflow" */
#define RE_EXT_MISMATCH         2076        /* MSG "External item in called program does not match existing item" */
#define RE_VX_CHECKSUM          2077        /* MSG "The code file checksum is bad; possible corrupt file" */
#define RE_VX_LAYOUT            2078        /* MSG "The structure of the code file does not match what the loader expects" */
#define RE_SMTP_AUTH_OK         2079        /* MSG "SMTP Authorization successful" */
#define RE_TERM_CFRM            2080        /* MSG "The process termination request was sent to terminal:" */
#define RE_TO_ARG_REQ           2081        /* MSG "A mail recipient must be specified (mail To: field)" */
#define RE_FROM_ARG_REQ         2082        /* MSG "A mail sender must be specified (mail From: field)" */
#define RE_SUBJ_ARG_REQ         2083        /* MSG "A message subject must be specified (mail Subject: field)" */
#define RE_ICSMTP_REQ           2084        /* MSG "No mail server was specified (ICSMTPSERVER environment variable)" */
#define RE_ICSMTPPORT_BAD       2085        /* MSG "The mail server port was not valid (ICSMTPPORT environment variable)" */
#define RE_SMTP_INFO            2086        /* MSG "SMTP System or Help message" */
#define RE_SMTP_READY           2087        /* MSG "The SMTP service is ready" */
#define RE_SMTP_CLOSING         2088        /* MSG "The SMTP service is closing" */
#define RE_SMTP_OK              2089        /* MSG "The SMTP action completed OK" */
#define RE_SMTP_FORWARD         2090        /* MSG "The recipient is nonlocal, message is being forwarded" */
#define RE_SMTP_NO_VRFY         2091        /* MSG "The recipient was not verified but message was accepted" */
#define RE_SMTP_SEND_DATA       2092        /* MSG "Start message input and end with <CRLF>.<CRLF>" */
#define RE_SMTP_NOT_AVAIL       2093        /* MSG "The SMTP service is not available - closing connection" */
#define RE_SMTP_MBX_UNAVAIL     2094        /* MSG "The command failed because the user's mailbox was unavailable" */
#define RE_SMTP_SERVER_ERR      2095        /* MSG "The command failed because of a server error" */
#define RE_SMTP_SERVER_MEM      2096        /* MSG "The command failed because of insufficient server storage" */
#define RE_BRAND_UNAVAIL        2097        /* MSG "Record manager brand selected is not available" */
#define RE_SMTP_5XX_ERR         2098        /* MSG "The SMTP command failed with a 500 level error" */
#define RE_SMTP_550_ERR         2099        /* MSG "The SMTP command failed because mailbox was unavailable" */
#define RE_EXIT_CODE            2100        /* MSG "A STOP RUN or builtin function set the exit code to" */
#define RE_OLD_ICBLTN           2101        /* MSG "An incompatible version of ICBLTN.DLL has been found" */
#define RE_MSG_BOX_PROMPT       2102        /* MSG " Press any key to continue... " */
#define RE_POP_UP_PROMPT        2103        /* MSG " <NL> to select " */
#define RE_SHELLEX_ASSOCINC     2104        /* MSG "The filename association is incomplete or invalid" */
#define RE_SHELLEX_DDEBUSY      2105        /* MSG "The DDE transaction could not be completed because other DDE transactions were being processed" */
#define RE_SHELLEX_DDEFAIL      2106        /* MSG "An error occurred in sending the command to the application" */
#define RE_SHELLEX_DDETIMEOUT   2107        /* MSG "The DDE transaction could not be completed because the request timed out" */
#define RE_SHELLEX_DLLNOTFND    2108        /* MSG "The specified dynamic-link library was not found" */
#define RE_SHELLEX_NOASSOC      2109        /* MSG "No application is associated with the specified file for this operation" */
#define RE_REFMOD_POSITION      2110        /* MSG "Reference modification position out of range" */
#define RE_REFMOD_LENGTH        2111        /* MSG "Reference modification length out of range" */
#define RE_SMTP_AUTHORIZING     2112        /* MSG "SMTP Authorization in progress" */
#define RE_SMTP_AUTH_REQUIRED   2113        /* MSG "SMTP Authorization required" */
#define RE_SMTP_AUTH_FAILED     2114        /* MSG "SMTP Authorization failed" */

#define RE_ICPOP3_REQ           2115        /* MSG "No pop3 server was specified (ICPOP3SERVER environment variable)" */
#define RE_ICPOP3PORT_BAD       2116        /* MSG "The pop3 server port was not valid (ICPOP3PORT environment variable)" */
#define RE_POP3_BEGIN_ACTIVE    2117        /* MSG "A new pop3 session cannot begin while the previous session is still active" */
#define RE_POP3_NOT_ACTIVE      2118        /* MSG "There is no pop3 session active; this call is not allowed" */
#define RE_POP3_BAD_RESPONSE    2119        /* MSG "An improperly formatted response was received from the POP3 server" */
#define RE_POP3_ERR             2120        /* MSG "The POP3 server returned an ERR response" */
#define RE_POP3_AUTH_ERR        2121        /* MSG "Authentication of the specified user and password returned an error" */
#define RE_POP3_ILL_NAME        2122        /* MSG "The username or password argument is too long or empty" */
#define RE_POP3_INACTIVE        2123        /* MSG "There is no active POP3 session" */
#define RE_POP3_WRONG_STATE     2124        /* MSG "The POP3 session is in the wrong state for the requested operation" */
#define RE_POP3_BAD_LIST_RESP   2125        /* MSG "The POP3 LIST command did not supply the correct number of list entries" */
#define RE_POP3_MSG_NOT_FOUND   2126        /* MSG "The specified message number was not found" */
/* BLANK 103 */

/* set off a block of 64 ISD messages (used by isd_bltn) (base + 192 = 2240) */
#define RE_ISD_MIN              2240

#define RE_ISD_NO_DATA          2240        /* MSG "ISD Interface Error: 'get' function returned null" */
#define RE_ISD_CONFIG           2241        /* MSG "ISD Interface Error: cannot open config file for values" */
#define RE_ISD_READ_CONFIG      2242        /* MSG "ISD Interface Error: error reading config file" */
#define RE_ISD_WSA_STARTUP      2243        /* MSG "ISD Interface Error: WSAStartup() failed" */
#define RE_ISD_SOCK_FAILED      2244        /* MSG "ISD Interface Error: unable to open a socket connection" */
#define RE_ISD_CONNECT_FAILED   2245        /* MSG "ISD Interface Error: unable to establish a connection" */
#define RE_ISD_SET_TIME_OUT_FAILED 2246     /* MSG "ISD Interface Error: unable to set timeout value" */
#define RE_ISD_SEND_FAILED      2247        /* MSG "ISD Interface Error: unable to send request to host" */
#define RE_ISD_RECV_FAILED      2248        /* MSG "ISD Interface Error: unable to receive response from host" */
#define RE_ISD_INVALID_PARAMETER 2249       /* MSG "ISD Interface Error: problem with input parameter" */
#define RE_ISD_INVALID_HANDLE_PASSED 2250   /* MSG "ISD Interface Error: incorrect handle passed on call to function" */
#define RE_ISD_RESP_OVERFLOW    2251        /* MSG "ISD Interface Error: response data / input buffer length mismatch" */
#define RE_ISD_INVALID_TIMEOUT  2252        /* MSG "ISD Interface Error: timeout value is not within the valid range" */
#define RE_ISD_INIT_LIBCURL_FAILED 2253     /* MSG "ISD Interface Error: could not init libcurl library for xml over http" */
#define RE_ISD_NO_UIC_RESP      2254        /* MSG "ISD Interface Error: could not get response from host" */
#define RE_ISD_FAILED_XML_RESP_PARSING 2255 /* MSG "ISD Interface Error: could not parse xml response from host" */

#define RE_ISD_NOT_INITIALIZED  2256        /* MSG "The ISD library has not been initialized" */
#define RE_ISD_DATA_SIZE        2257        /* MSG "The data value is either zero length or too long for the buffer" */
#define RE_ISD_MISSING_CONFIG   2258        /* MSG "A required item is missing from the isd config file" */
#define RE_LOAD_LIB_SYMS        2259        /* MSG "The necessary symbols from the shared library could not be loaded" */
#define RE_LOAD_LIBRARY         2260        /* MSG "The required shared library could not be loaded" */
#define RE_ISD_BEGIN_TRAN       2261        /* MSG "Invalid sequence: begin transaction with an active transaction" */
#define RE_ISD_COMMIT_TRAN      2262        /* MSG "Invalid sequence: commit without an active transaction" */
#define RE_ISD_ROLLBACK_TRAN    2263        /* MSG "Invalid sequence: rollback without an active transaction" */
#define RE_ISD_AUTH_TRAN        2264        /* MSG "Invalid sequence: tender authorization request without an active transaction" */
#define RE_ISD_CONFIG_FAILURE   2265        /* MSG "Configuration errors caused initialization to fail" */
#define RE_ISD_UNKNOWN_TRAN     2266        /* MSG "Internal Error: Unknown or unexpected Transaction Type" */
#define RE_ISD_TRAN_COUNT       2267        /* MSG "The maximum transaction element count has been reached" */
#define RE_ISD_TENDER_TYPE      2268        /* MSG "Unknown TENDER_TYPE from ISD PX request" */
#define RE_ISD_CK_BAD_MICR      2269        /* MSG "Check MICR data is absent or unreadable -- verify check alignment" */
#define RE_ISD_CK_BAD_TRANSIT   2270        /* MSG "Bad MICR format: Invalid transit number format" */
#define RE_ISD_CK_BAD_ACCOUNT   2271        /* MSG "Bad MICR format: Invalid account number format" */
#define RE_ISD_CK_BAD_SEQ_NUM   2272        /* MSG "Bad MICR format: Invalid check sequence number format" */
#define RE_ISD_CK_UNKNOWN_ERR   2273        /* MSG "Reading the check failed for an unknown reason" */
#define RE_ISD_REQ_ENTRY_TYPE   2274        /* MSG "The REQ-ENTRY-TYPE value is not valid" */
#define RE_ISD_REQ_AMOUNT       2275        /* MSG "The REQ-AMOUNT value is not valid" */
#define RE_ISD_PACKET_REV       2276        /* MSG "The ISD-REQ or ISD-RSP record does not have the expected revision" */
#define RE_ISD_REQ_AUTH_CODE    2277        /* MSG "The REQ-AUTH-CODE value is not valid" */
#define RE_ISD_REQ_TOKEN        2278        /* MSG "The REQ-TOKEN value is not valid" */
#define RE_ISD_REQ_EXPIRATION   2279        /* MSG "The REQ-EXPIRATION-DATE value is not valid" */
#define RE_ISD_ERROR_STATUS     2280        /* MSG "The ISD response has an error status" */
#define RE_ISD_CC_PLAN_ERROR    2281        /* MSG "The card could not be authorized as a Credit/Debit card" */
#define RE_ISD_GIFT_PLAN_ERROR  2282        /* MSG "The card could not be authorized as a Gift card" */
#define RE_CERT_CONNECT_FAILED  2283        /* MSG "Certegy Server Error: unable to establish a connection" */
#define RE_CERT_SEND_FAILED     2284        /* MSG "Certegy Server Error: unable to send request to certegyd host" */
#define RE_CERT_RECV_FAILED     2285        /* MSG "Certegy Server Error: unable to receive response from certegyd host" */
#define RE_CERT_SETUP_ERR       2286        /* MSG "Certegy setup error (04,06, or 14) -- Call the help desk" */
#define RE_CERT_DECLINED        2287        /* MSG "Certegy response: check approval declined" */
#define RE_CERT_PROCESSING_ERR  2288        /* MSG "Certegy processing error (09, 13, 15, or 20) -- retry the request" */
#define RE_CERT_UNEXPECTED_ERR  2289        /* MSG "Certegy returned an unexpected response status" */
#define RE_CERT_HOST_TIMEOUT    2290        /* MSG "Certegy Host Error: the request to the host at Certegy timed out" */
#define RE_CERT_HOST_DOWN       2291        /* MSG "Certegy Host Error: the host at Certegy or the network is down" */

#define RE_ISD_MAX              2303

/* set off a block of SQL messages (base + 256 = 2304) */
#define RE_SQL_MIN              2304

#define RE_SQL_OPEN_LIC         2304        /* MSG "28001: Authorization failure: ICSQL License could not be opened" */
#define RE_SQL_NOT_LOADED       2305        /* MSG "IC001: General error: SQL is not loaded" */
#define RE_SQL_ODBC_LOAD        2306        /* MSG "IC002: Unable to load ODBC" */
#define RE_SQL_ODBC_SYMS        2307        /* MSG "IC003: Unable to load ODBC symbols" */
#define RE_SQL_NOT_SETUP        2308        /* MSG "IC004: The ISQL subsystem is not properly initialized" */
#define RE_SQL_EXC_RANGE        2309        /* MSG "IC005: Get Diagnostics exception number is out of range" */
#define RE_SQL_ODBC_HENV        2310        /* MSG "IC006: Unable to allocate ODBC environment" */
#define RE_SQL_MALLOC_ERR       2311        /* MSG "IC007: Memory allocation error" */
#define RE_SQL_CONN_IN_USE      2312        /* MSG "08002: Connection name in use" */
#define RE_SQL_CONN_NOT_EX      2313        /* MSG "08003: Connection does not exist" */
#define RE_SQL_INT_ERR          2314        /* MSG "IC008: Internal error" */
#define RE_SQL_UNEXP_ERR        2315        /* MSG "IC009: Unexpected Error from ODBC" */
#define RE_SQL_INV_HAN          2316        /* MSG "IC010: Invalid Handle error from ODBC" */
#define RE_SQL_SEQ_ERR          2317        /* MSG "HY010: Function sequence error" */
#define RE_SQL_RES_GT_INTO      2318        /* MSG "01503: The number of result columns is larger than the number of INTO items" */
#define RE_SQL_IND_REQ          2319        /* MSG "22002: Indicator variable required but not supplied" */
#define RE_SQL_INV_LEN          2320        /* MSG "HY090: Invalid string or buffer length" */
#define RE_SQL_CONV_ERR         2321        /* MSG "22018: Invalid character value for cast specification" */
#define RE_SQL_NUM_RANGE        2322        /* MSG "22003: Numeric value out of range" */
#define RE_SQL_INV_DT           2323        /* MSG "22007: Invalid datetime format" */
#define RE_SQL_INTVL_OVRF       2324        /* MSG "22015: Interval field overflow" */
#define RE_SQL_INV_CONV         2325        /* MSG "07006: Restricted data type attribute violation" */
#define RE_SQL_STMT_NOT_EX      2326        /* MSG "26501: The statement identifier does not exist" */
#define RE_SQL_USING_REQ        2327        /* MSG "07004: The USING clause is required for dynamic parameters" */
#define RE_SQL_USING_CNT        2328        /* MSG "07001: The number of USING items is not the same as the number of parameter markers" */
#define RE_SQL_NUM_PARM         2329        /* MSG "07500: Numeric parameter conversion error" */
#define RE_SQL_DATE_PARM        2330        /* MSG "07501: Date parameter conversion error" */
#define RE_SQL_TIME_PARM        2331        /* MSG "07502: Time parameter conversion error" */
#define RE_SQL_TS_PARM          2332        /* MSG "07503: Timestamp parameter conversion error" */
#define RE_SQL_INTVL_PARM       2333        /* MSG "07504: Interval parameter conversion error" */
#define RE_SQL_NO_DATA          2334        /* MSG "02000: No data was affected by the operation" */
#define RE_SQL_NEED_DATA        2335        /* MSG "07001: More data is needed" */
#define RE_SQL_INV_TYPE         2336        /* MSG "HY004: Invalid SQL type" */
#define RE_SQL_CURSOR_STATE     2337        /* MSG "24000: Invalid cursor state" */
#define RE_SQL_NO_STMT_WARN     2338        /* MSG "01000: General Warning: The statement identifier does not exist" */
#define RE_SQL_NET_ERR          2339        /* MSG "IC011: Client/Server communication error" */
#define RE_SQL_SERVER_ERR       2340        /* MSG "IC012: Server-side processing error" */
#define RE_SQL_ESC_CHAR_WARN    2341        /* MSG "01000: General Warning: The search pattern escape character could not be determined" */

#define RE_SQL_MAX              2340        /* top of SQL errors */

/* BLANK 84 */

/* messages for debugger */
#define DE_NO_PROGRAM           2413        /* MSG "No Program" */
#define DE_GLOB_USE_PROCS       2414        /* MSG "Global USE Procedures:" */
#define DE_NONE                 2415        /* MSG "  none" */
#define DE_BEG_OF_CODE          2416        /* MSG "   <beginning of code>" */
#define DE_END_OF_CODE          2417        /* MSG "   <end of code>" */
#define DE_EXP_EOL              2418        /* MSG "End of line expected" */
#define DE_EXP_NAME_OR_ANY      2419        /* MSG "'name' or Any expected" */
#define DE_NUM_GT_ZERO          2420        /* MSG "number must be > 0" */
#define DE_INV_CMD              2421        /* MSG "Invalid command" */
#define DE_NO_ACTIVE_PGM        2422        /* MSG "No active program" */
#define DE_INV_PC               2423        /* MSG "Not a valid PC" */
#define DE_NO_BKPTS             2424        /* MSG "No more breakpoints are available" */
#define DE_ERR_NOT_SET          2425        /* MSG "Error not set" */
#define DE_NO_SUCH_BKPT         2426        /* MSG "No such breakpoint" */
#define DE_NO_PREV_CMD          2427        /* MSG "No previous command" */
#define DE_INV_ADDR             2428        /* MSG "Not a valid &address" */
#define DE_EXP_LEN              2429        /* MSG "length expected" */
#define DE_INV_LEN              2430        /* MSG "Not a valid length" */
#define DE_INV_REFNUM           2431        /* MSG "Not a valid @refnum" */
#define DE_CNT_LE_18            2432        /* MSG "count must be <= 18" */
#define DE_CNT_LE_19            2433        /* MSG "count must be <= 19" */
#define DE_CNT_LE_8             2434        /* MSG "count must be <= 8" */
#define DE_CNT_LE_10            2435        /* MSG "count must be <= 10" */
#define DE_CNT_2                2436        /* MSG "count must be 2" */
#define DE_NOT_AT_CALL          2437        /* MSG "Not at a Call" */
#define DE_NOT_AT_PERF          2438        /* MSG "Not at Perform" */
#define DE_EXP_STRING           2439        /* MSG "'String' expected" */
#define DE_EXP_ADDR_REF         2440        /* MSG "Expect &address or @refnum" */
#define DE_SIZE_ERR             2441        /* MSG "SIZE ERROR on store" */
#define DE_EXP_ARG              2442        /* MSG "Argument expected" */
#define DE_EXP_RESET            2443        /* MSG "Reset expected" */
#define DE_BAD_INPUT            2444        /* MSG "Bad command input" */
#define DE_INV_TYPE             2445        /* MSG "Invalid type" */
#define DE_NO_FILES_OPEN        2446        /* MSG "No files are open" */
#define DE_INACTIVE_PGMS        2447        /* MSG "Inactive Programs:" */
#define DE_ACTIVE_PGMS          2448        /* MSG "Active programs:  " */
#define DE_NO_ACTIVE_PERFS      2449        /* MSG "There are no active performs" */
#define DE_EXP_DIGIT            2450        /* MSG "A digit is expected here" */
#define DE_ILL_TOKEN            2451        /* MSG "Unrecognized command line element" */
#define DE_LIT_LEN              2452        /* MSG "Literal is too long" */
#define DE_EOL_IN_LIT           2453        /* MSG "Literal not closed before end of line" */
#define DE_TOK_LEN              2454        /* MSG "Item is too long" */
#define DE_NUM_IN_LIT           2455        /* MSG "Invalid numeric specifier in literal" */
#define DE_EXP_NAME_ANY         2456        /* MSG "Expect 'name' or Any" */
#define DE_INV_CMD_ARG          2457        /* MSG "Invalid command argument" */
#define DE_LIST_TO_ARG          2458        /* MSG "LAST or line number expected" */
#define DE_NO_NEXT_ITEM         2459        /* MSG "Next item or data area is not a valid data location" */
#define DE_PARSE_OVFL           2460        /* MSG "Parse stack overflow, simplify expressions" */
#define DE_PARSE_ENDRULE        2461        /* MSG "Internal parser error - endrule reached" */
#define DE_PARSE_UNFL           2462        /* MSG "Internal parser error - parse stack underflow" */
#define DE_PARSE_TBL            2463        /* MSG "Internal parser error - invalid parse op" */
#define DE_BKPT                 2464        /* MSG "Breakpoint" */
#define DE_ADDED                2465        /* MSG "has been added" */
#define DE_BAD_BKPT_NUM         2466        /* MSG "Invalid breakpoint number" */
#define DE_ALREADY_SEL          2467        /* MSG "Breakpoint is already selected" */
#define DE_BKPT_EXISTS          2468        /* MSG "Breakpoint already exists" */
#define DE_CHANGED              2469        /* MSG "has been changed" */
#define DE_AUDIT_NOT_OPEN       2470        /* MSG "The audit file is not open" */
#define DE_AUDIT_OPEN           2471        /* MSG "The audit file is already open" */
#define DE_EXEC_OPEN            2472        /* MSG "A command file is already active" */
#define DE_NO_SCRN_OPT          2473        /* MSG "Internal Error: Screen optimization not enabled for icdeb" */
#define DE_OPEN_TMP_FILES       2474        /* MSG "Error opening debugger temp files" */
#define DE_PRESS_ANY            2475        /* MSG "Press any key to continue" */
#define DE_SYM_MISMATCH         2476        /* MSG "The symbol file does not match the code file" */
#define DE_NO_SYM_HANDLES       2477        /* MSG "There are no more symbol-file handles available" */
#define DE_NO_LINE_TBL          2478        /* MSG "The source file/line table is not available" */
#define DE_OPEN_SYM_ERR         2479        /* MSG "Unable to open symbol file for " */
#define DE_LINE_MOVED           2480        /* MSG "The specified line is not executable. Line changed to " */
#define DE_DEBR_END_RUN         2481        /* MSG "The run unit is finished" */
#define DE_DEBR_INTERRUPT       2482        /* MSG "Console Interrupt" */
#define DE_DEBR_OP_STARTUP      2483        /* MSG "The initial program is loaded" */
#define DE_PGM_NOT_LOADED       2484        /* MSG "The program is not part of the run unit" */
#define DE_NO_SYM_TBL           2485        /* MSG "The symbol table is not available" */
#define DE_SRC_IS_NEWER         2486        /* MSG "The source file is newer than the one compiled" */
#define DE_SRC_IS_OLDER         2487        /* MSG "The source file is older than the one compiled" */
#define DE_SRC_UNAVAIL          2488        /* MSG "Source viewing is not available for this program" */
#define DE_SYM_FILE_ERR         2489        /* MSG "locking or reading symbol file" */
#define DE_SRC_FILE_ERR         2490        /* MSG "locking or reading source file" */
#define DE_NAVIGATE             2491        /* MSG "Press ESC to exit, cursor up/down, F2 (page up) or F3 (page down)" */
#define DE_NO_PATH              2492        /* MSG "No search path is set" */
#define DE_DEAD_DATA            2493        /* MSG "This data item is not allocated" */
#define DE_SYM_LOAD_ERR         2494        /* MSG "Symbol unavailable - error on symbol file" */
#define DE_END_AR_EXPR          2495        /* MSG "Internal error - bad arithemetic expression" */
#define DE_PUSH_OPER            2496        /* MSG "Internal error - operator stack underflow" */
#define DE_POP_OPND             2497        /* MSG "Internal error - operand stack underflow" */
#define DE_DO_OPER              2498        /* MSG "Internal error - invalid expression operator" */
#define DE_NUM_88               2499        /* MSG "Internal error - bad numeric level 88 expression" */
#define DE_AN_88                2500        /* MSG "Internal error - bad alphanumeric level 88 expression" */
#define DE_SIZE_ERROR           2501        /* MSG "Size Error occured while evaluating this operation" */
#define DE_DUMP_OPND            2502        /* MSG "Invalid type of argument for dump" */
#define DE_TRUE                 2503        /* MSG "TRUE" */
#define DE_FALSE                2504        /* MSG "FALSE" */
#define DE_NOT_END_PERF         2505        /* MSG "The paragraph/section was never used as the end of a perform range" */
#define DE_NO_TEST_BKPTS        2506        /* MSG "No more test breakpoints are available" */
#define DE_NO_TEST_AREAS        2507        /* MSG "No more space left for test breakpoints" */
#define DE_TEST_ARG             2508        /* MSG "Invalid argument for Test" */
#define DE_OLD_DATA             2509        /* MSG "Old data value (alphanumeric format): " */
#define DE_NEW_DATA             2510        /* MSG "New data value: " */
#define DE_NO_FIND_STR          2511        /* MSG "There is no find string to use" */
#define DE_NO_FIND_POS          2512        /* MSG "There is no find position to start from for Find Next/Previous" */
#define DE_STR_NOT_FND          2513        /* MSG "The string was not found" */
#define DE_EXP_QUAL_NAME        2514        /* MSG "A (qualified) symbol name is expected here" */
#define DE_BUILD_REF            2515        /* MSG "Unable to build reference info or address for this data item" */
#define DE_CMD_DISABLED         2516        /* MSG "This command is disabled when stopped for the current reason" */
#define DE_DEBR_SCRN_INT        2517        /* MSG "Console Interrupt within a screen read" */
#define DE_CNT_4                2518        /* MSG "count must be 4" */
#define DE_EXP_REF              2519        /* MSG "Expected a reference of the form @refnum" */
#define DE_INV_ORG              2520        /* MSG "Not a valid file organization" */
#define DE_PREV_DUMP_FILE       2521        /* MSG "The previous Dump command was for a file name or file reference" */
#define DE_INV_REF_TYPE         2522        /* MSG "Internal error - invalid or unexpected reference type" */
#define DE_SYM_ERR              2523        /* MSG "Internal error - symbol unavailable" */
#define DE_EXPECT               2524        /* MSG "The following element was expected here" */
#define DE_NUM_ID_LIT           2525        /* MSG "A numeric identifier or literal is required" */
#define DE_OPND_TYPE            2526        /* MSG "The operand is the wrong class or type for the operation" */
#define DE_NOT_USG_DISP         2527        /* MSG "The item is not USAGE DISPLAY" */
#define DE_EXP_CONDITION        2528        /* MSG "A condition is expected here" */
#define DE_NO_EXPRS             2529        /* MSG "A numeric expression is not allowed here" */
#define DE_INT_ID               2530        /* MSG "This item must refer to an elementary integer data item" */
#define DE_NOT_DATA             2531        /* MSG "This item is not a data-item" */
#define DE_EXP_OVRFL            2532        /* MSG "The level 88, arithmetic, or conditional expression is too complex" */
#define DE_SYM_UNDEF            2533        /* MSG "The symbol is not defined" */
#define DE_NO_MATCH             2534        /* MSG "The symbol (as qualified) was not found" */
#define DE_AMBIG_QUAL           2535        /* MSG "Symbol is not uniquely qualified" */
#define DE_NOT_PROC             2536        /* MSG "The item is not a paragraph or section name" */
#define DE_NOT_DATA_LIT         2537        /* MSG "This item is not a data item or literal" */
#define DE_ILL_MOVE             2538        /* MSG "Illegal combination of data items in MOVE" */
#define DE_QUAL_DEPTH           2539        /* MSG "Too many levels of qualification have been specified" */
#define DE_NOT_SUBSCR           2540        /* MSG "This item may not be subscripted" */
#define DE_EXP_NAME             2541        /* MSG "The element 'data-name' is expected here" */
#define DE_EXP_INT              2542        /* MSG "The element 'integer' is expected here" */
#define DE_FIG_LIT              2543        /* MSG "Figurative constant or nonnumeric literal is expected here" */
#define DE_EXP_ID               2544        /* MSG "The element 'identifier' or 'id' is expected here" */
#define DE_EXP_ID_LIT           2545        /* MSG "The element 'id-lit' is expected here" */
#define DE_EXP_SUBSCR           2546        /* MSG "Subscript specifier expected here" */
#define DE_EXP_SEC_PAR          2547        /* MSG "A section or paragraph is expected here" */
#define DE_EXP_ARITH_EXP        2548        /* MSG "An arithmetic expression is expected here" */
#define DE_EXP_TERM             2549        /* MSG "A Unary + or -, 'id-lit', or '(' is expected here" */
#define DE_EXP_FACTOR           2550        /* MSG "The element 'id-lit' or '(' is expected here" */
#define DE_EXP_COND             2551        /* MSG "A relation, class test, or sign test is expected here" */
#define DE_EXP_COND_EXP         2552        /* MSG "A condition or conditional expression is expected here" */
#define DE_EXP_COND_TERM        2553        /* MSG "A NOT or simple condition is expected here" */
#define DE_EXP_COND_FACT        2554        /* MSG "A simple condition or '(' is expected here" */
#define DE_FEW_SUBSCR           2555        /* MSG "Not enough subscripts were specified; supplying 1's" */
#define DE_REQ_SUBSCR           2556        /* MSG "This item must be subscripted" */
#define DE_TYPE_SUBSCR          2557        /* MSG "The item must be a numeric integer, USAGE INDEX, or an index-name" */
#define DE_NUM_SUBSCR           2558        /* MSG "Too many subscripts have been specified for this item" */
#define DE_EXTRA_RPAREN         2559        /* MSG "Unbalanced parentheses; right parenthesis is being ignored" */


/* use up to 2559 */
#define RE_MAX_ERROR            2559        /* maximum runtime error number */


/****************************************************************/
/*                                                              */
/*    UFOS error group (UFE_xxx) - 2560-3071                    */
/*                                                              */
/****************************************************************/

#define MIN_UFOS_ERR                2560

/* Warnings */
#define UFE_TOP_LEVEL_WARN          2560    /* MSG "-0001 Positioned above main index" */
#define UFE_VERIFY_FND_ERRS         2561    /* MSG "-0002 'ufos_verify' found errors" */
#define UFE_INV_CUR_POS_WARN        2562    /* MSG "-0003 Invalid current position" */
#define UFE_ALT_INDEX               2563    /* MSG "-0074 Indicates alternate index" */
#define UFE_NOT_IMPLEMENTED         2564    /* MSG "-0075 Function not implemented" */
#define UFE_SOFTWARE_EXPIRED        2565    /* MSG "-0076 Software has expired" */
#define UFE_USR_INT                 2566    /* MSG "-0077 User interrupt" */

/* File/Volume Related errors */
#define UFE_START_FATAL_MSGS        2567    /* MSG "-0100 Start of fatal messages (request is aborted)" */
#define UFE_NOT_UFOS_INFOS          2568    /* MSG "-0101 Not a U/FOS database" */
#define UFE_INDEX_DNE               2569    /* MSG "-0102 Unable to access the key volume(s)" */
#define UFE_DATA_DNE                2570    /* MSG "-0103 Unable to access the data volume(s)" */
#define UFE_LOG_DNE                 2571    /* MSG "-0104 Unable to access the logging file" */
#define UFE_SHADOW_DNE              2572    /* MSG "-0105 Unable to access the shadow volume" */
#define UFE_UDB_DNE                 2573    /* MSG "-0106 Unable to access the database directory" */
#define UFE_MAX_VOL_SIZE            2574    /* MSG "-0107 Exceeded maximum volume size" */
#define UFE_EXCL_OPEN               2575    /* MSG "-0110 Database is exclusively open, cannot open" */
#define UFE_OPEN                    2576    /* MSG "-0111 Database is open, cannot exclusively open" */
#define UFE_INVALID_DB              2577    /* MSG "-0112 Database is invalid, must be fixed first" */
#define UFE_DB_LEFT_OPEN            2578    /* MSG "-0113 Database left open, must run 'ufos_verify' with -c or -f option first" */
#define UFE_INDEX_FULL              2579    /* MSG "-0114 Index full, cannot add a new level" */
#define UFE_INDEX_VOL_ACCESS        2580    /* MSG "-0115 Access to index volume denied" */
#define UFE_DATA_VOL_ACCESS         2581    /* MSG "-0116 Access to data volume denied" */
#define UFE_LOG_ACCESS              2582    /* MSG "-0117 Access to logging file denied" */
#define UFE_DATA_FULL               2583    /* MSG "-0120 U/FOS data volumes are full" */
#define UFE_ILL_CHANNEL             2584    /* MSG "-0121 Illegal channel number" */
#define UFE_NOT_OPEN                2585    /* MSG "-0122 Do not have a U/FOS database open" */
#define UFE_NO_DB_ON_CHANNEL        2586    /* MSG "-0123 No database is open on this channel" */
#define UFE_INDEX_SPACE             2587    /* MSG "-0124 No space for main key volume" */
#define UFE_DATA_SPACE              2588    /* MSG "-0125 No space for main data volume" */
#define UFE_READ_ONLY               2589    /* MSG "-0126 Database is read-only" */
#define UFE_NO_SEQ                  2590    /* MSG "-0127 Already opened for read/write; cannot open for sequential" */
#define UFE_NO_VAL_PRIM             2591    /* MSG "-0130 No valid primary index file" */
#define UFE_NO_PRIM                 2592    /* MSG "-0131 Cannot find the primary index file" */
#define UFE_NO_WRITE                2593    /* MSG "-0132 Already opened for sequential, cannot open for write" */
#define UFE_ONLINE_BU               2594    /* MSG "-0133 On-line backup is already in progress" */
#define UFE_SHADOW_ERR              2595    /* MSG "-0134 Problem opening/creating shadow volume" */
#define UFE_NOT_BYTESWAPPED         2596    /* MSG "-0135 Cannot use 'big-endian' (not byteswapped) database here" */
#define UFE_BYTESWAPPED             2597    /* MSG "-0136 Cannot use 'little-endian' (byteswapped) database here" */
#define UFE_NOT_IN_BU_MODE          2598    /* MSG "-0137 Database is not in on-line backup mode" */

/* Packet errors */
#define UFE_UNKNOWN_FNC             2599    /* MSG "-0140 Unknown processing packet function" */
#define UFE_INV_PKT_TYPE            2600    /* MSG "-0141 Invalid packet type (_PPKT)" */
#define UFE_INV_MOTION              2601    /* MSG "-0142 Invalid keyed motion word (_KMOTN)" */
#define UFE_INV_POSITION            2602    /* MSG "-0143 Invalid keyed position word (_KLOCN)" */
#define UFE_INV_KEY_ADDR            2603    /* MSG "-0144 Invalid key address" */
#define UFE_INV_REC_VAL             2604    /* MSG "-0147 Invalid data record (_DREC) value" */
#define UFE_INV_VOL_CNT             2605    /* MSG "-0150 Invalid number of volumes" */
#define UFE_INV_SPLIT_POINT         2606    /* MSG "-0151 Invalid split point" */
#define UFE_INV_SUB_LEVS            2607    /* MSG "-0152 Invalid number of subindex levels" */
#define UFE_INV_MAX_VOL_SIZE        2608    /* MSG "-0153 Inavlid maximum volume size" */
#define UFE_INV_ELEM_SIZE           2609    /* MSG "-0154 Invalid volume element size" */
#define UFE_INV_PAGE_SIZE           2610    /* MSG "-0155 Invalid database page size" */
#define UFE_INV_LOCKS               2611    /* MSG "-0156 Invalid number of concurrent locks; INFOS II lock/unlock error" */
#define UFE_INV_GEN_APP             2612    /* MSG "-0157 __GEN or __APP not allowed on __WRITE" */
#define UFE_ZERO_OCCURENCE          2613    /* MSG "-0160 Occurence number is zero for __DUP read" */
#define UFE_INV_FILE_ADDR_PTR       2614    /* MSG "-0161 Filename address pointer is invalid" */
#define UFE_INV_KEY_ADDR_PTR        2615    /* MSG "-0162 A key address is invalid" */

/* Key/Data Errors */
#define UFE_RL_LESS_THAN_1          2616    /* MSG "-0200 Record length less than 1" */
#define UFE_RL_CONFL_PGSIZE         2617    /* MSG "-0201 Record length too large for page" */
#define UFE_SBINDX_ILL              2618    /* MSG "-0202 Subindices are not allowed in this subindex" */
#define UFE_MAX_SBINDX_LEVELS       2619    /* MSG "-0203 Exceeded maximum number of subindexes" */
#define UFE_PARTIAL_ILL             2620    /* MSG "-0204 Data record 2 (partial record) not allowed in this subindex" */
#define UFE_KEY_NOT_FND             2621    /* MSG "-0205 Key not found" */
#define UFE_NO_KEY_PATH             2622    /* MSG "-0206 No key path has been defined" */
#define UFE_KEY_EXISTS              2623    /* MSG "-0207 Key already exists" */
#define UFE_DR1_REQ                 2624    /* MSG "-0210 Data record 1 must exist" */
#define UFE_DR2_REQ                 2625    /* MSG "-0211 Data record 2 must exist" */
#define UFE_DR1_DNE                 2626    /* MSG "-0212 No data record 1" */
#define UFE_DR2_DNE                 2627    /* MSG "-0213 No data record 2" */
#define UFE_DR1_EXISTS              2628    /* MSG "-0215 Data record 1 already exists" */
#define UFE_DR2_EXISTS              2629    /* MSG "-0216 Data record 2 already exists" */
#define UFE_UNLINK_GROUP            2630    /* MSG "-0217 Tree too deep for unlink in group" */
#define UFE_INV_FEEDBACK            2631    /* MSG "-0220 Invalid feedback value" */
#define UFE_TOP_LEVEL               2632    /* MSG "-0225 Positioned above main index" */
#define UFE_INV_CUR_POS             2633    /* MSG "-0226 Invalid current position" */
#define UFE_SBINDX_EXISTS           2634    /* MSG "-0227 Subindex already defined" */
#define UFE_SBINDX_KEY_DNE          2635    /* MSG "-0230 Subindex key does not exist" */
#define UFE_SBINDX_DNE              2636    /* MSG "-0231 Subindex is not defined" */
#define UFE_END_OF_SBINDX           2637    /* MSG "-0232 End of subindex" */
#define UFE_NO_SBINDX               2638    /* MSG "-0233 Key does not have subindex" */
#define UFE_CUR_POS_DELETED         2639    /* MSG "-0234 Current position has been deleted" */
#define UFE_MAX_LOCKS               2640    /* MSG "-0235 Maximum number of locks exceeded" */
#define UFE_KEY_DEL_ERR             2641    /* MSG "-0236 Cannot erase key, subindex defined" */
#define UFE_REC_NOT_LOCKED          2642    /* MSG "-0237 Data record is not locked by user" */
#define UFE_REC_LOCKED              2643    /* MSG "-0240 Data record (data record 1) is locked by another user" */
#define UFE_PARTIAL_LOCKED          2644    /* MSG "-0241 Partial record (data record 2) is locked by another user" */
#define UFE_KEY_LEN                 2645    /* MSG "-0242 Key too long for this subindex" */
#define UFE_KEY_LEN_ZERO            2646    /* MSG "-0243 Zero length key" */
#define UFE_DUPLICATES_NOT_OK       2647    /* MSG "-0244 Duplicate keys not allowed in this subindex" */
#define UFE_SBINDX_DEL_ERR          2648    /* MSG "-0245 Cannot remove subindex with indices defined" */
#define UFE_TRAN_DNE                2649    /* MSG "-0246 No transaction group defined" */
#define UFE_INV_TRAN_CNT            2650    /* MSG "-0247 Invalid transaction group count" */
#define UFE_KEY_PATH_LEN            2651    /* MSG "-0250 Total key path length too long" */
#define UFE_NULL_BYTE_KEY           2652    /* MSG "-0251 A single null byte '\\0' is not a valid key" */

/* Security Code Errors */
#define UFE_NO_READS                2653    /* MSG "-0300 No reads allowed below this index" */
#define UFE_NO_WRITES               2654    /* MSG "-0301 No writes allowed below this index" */
#define UFE_NO_MODS                 2655    /* MSG "-0302 No modifications allowed below this index" */
#define UFE_NO_DELS                 2656    /* MSG "-0303 No deletes allowed below this index" */
#define UFE_ACCESS_PRIV             2657    /* MSG "-0304 User not privileged to access this file" */
#define UFE_MODIFY_PRIV             2658    /* MSG "-0305 User not privileged to modify this file" */

/* Alternate Index Errors */
#define UFE_PRIM_NOT_FND            2659    /* MSG "-0340 Cannot find primary index for alternate index" */
#define UFE_ALT_TO_ALT              2660    /* MSG "-0341 Alternate index points to another alternate index" */
#define UFE_ALT_KEY_RANGE           2661    /* MSG "-0342 Alternate key indexs pointer out of bounds" */

/* Environment Errors */
#define UFE_NO_SRVR                 2662    /* MSG "-0500 Cannot find the server" */
#define UFE_PIPE_ERR                2663    /* MSG "-0501 Cannot create/open pipe to server" */
#define UFE_NO_SRVR_ACK             2664    /* MSG "-0502 No setup acknowledgement from server" */
#define UFE_SRVR_WRITE              2665    /* MSG "-0503 Error in writing to the server" */
#define UFE_SRVR_READ               2666    /* MSG "-0504 Error in reading from the server" */
#define UFE_USR_CNT                 2667    /* MSG "-0510 Allowed number of system users exceeded" */
#define UFE_SYSTEM_DB_CNT           2668    /* MSG "-0511 Allowed number of system databases exceeded" */
#define UFE_USR_DB_CNT              2669    /* MSG "-0512 Allowed number of databases for this user exceeded" */

/* Log file errors */
#define UFE_LOG_TRUNC               2670    /* MSG "-0550 Log file truncated" */
#define UFE_LOG_REV                 2671    /* MSG "-0551 Incorrect log file revision" */

/* File consistency errors */
#define UFE_NEG_PAGE                2672    /* MSG "-0600 Attempt to access negative page number" */
#define UFE_PAGE_PAST_EOV           2673    /* MSG "-0601 Page is after end of volume" */
#define UFE_PG_TYPE_MISMATCH        2674    /* MSG "-0602 Page types do not match" */
#define UFE_PAGE_NUM_MISMATCH       2675    /* MSG "-0603 Page number mismatch" */
#define UFE_NEXT_KEY_ZERO           2676    /* MSG "-0604 'KEY_NXT' value is 0" */
#define UFE_INV_PAGE_TYPE           2677    /* MSG "-0605 Invalid page type" */
#define UFE_DR_ADDR_ZERO            2678    /* MSG "-0606 Data record address is zero" */
#define UFE_INV_DR_ITEM_NUM         2679    /* MSG "-0607 Data record item number is invalid" */
#define UFE_DATA_PTR_RANGE          2680    /* MSG "-0610 Data item pointer is out of range" */
#define UFE_DATA_ITEM_DELETED       2681    /* MSG "-0611 Data item is marked as deleted" */
#define UFE_INDIRECT_ZERO           2682    /* MSG "-0612 Indirect address is zero" */
#define UFE_PAGE_DESC_ZERO          2683    /* MSG "-0613 Page descriptor is zero" */
#define UFE_INS_INV_1ST_KEY         2684    /* MSG "-0614 Insert invalid first key" */
#define UFE_INV_SBINDX_XREF         2685    /* MSG "-0615 Invalid subindex xref item" */
#define UFE_INV_KEY_VOL_NUM         2686    /* MSG "-0617 Invalid key volume number" */
#define UFE_INV_DATA_VOL_NUM        2687    /* MSG "-0620 Invalid data volume number" */
#define UFE_SBINDX_NULL_DEL         2688    /* MSG "-0621 Attempt to delete subindex null key" */
#define UFE_INV_EXPANDED_RL         2689    /* MSG "-0622 Expanded record is not the correct length" */
#define UFE_KEY_PGSIZE_OVFL         2690    /* MSG "-0623 Key page overflows allowed size" */
#define UFE_DATA_PAGE_CHAIN         2691    /* MSG "-0624 Data page is on the wrong space chain" */
#define UFE_INV_FILE_MODE           2692    /* MSG "-0625 File mode in header is wrong" */
#define UFE_INV_HDR_PAGE_DESC       2693    /* MSG "-0626 Header page descriptor invalid" */

/* Unexpected errors from UNIX */
#define UFE_LSEEK_ERR               2694    /* MSG "-0660 Error from database lseek request" */
#define UFE_READ_ERR                2695    /* MSG "-0661 Error from database read request" */
#define UFE_WRITE_ERR               2696    /* MSG "-0662 Error from database write request" */

/* Internal Errors */
#define UFE_INV_PAGE_TYPE_REQ       2697    /* MSG "-0700 Invalid page type request" */
#define UFE_INV_VOL_NUM             2698    /* MSG "-0701 Bad volume number in page request" */
#define UFE_INV_PAGE_NUM_1          2699    /* MSG "-0702 Bad page number in page request" */
#define UFE_INV_PAGE_NUM_2          2700    /* MSG "-0703 Bad page number in page request" */
#define UFE_READ_HDR                2701    /* MSG "-0704 Attempt to read part of header" */
#define UFE_RESV_142                2702    /* MSG "-0705 Reserved -0705" */
#define UFE_RESV_143                2703    /* MSG "-0706 Reserved -0706" */
#define UFE_WRITE_INV_PG_ADDR       2704    /* MSG "-0707 Attempt to write page with invalid address" */
#define UFE_FLUSH_PG_MISMATCH       2705    /* MSG "-0710 Attempt to flush and page address mismatch" */
#define UFE_VM_PAGE                 2706    /* MSG "-0711 Unable to find allocated VM page for user/db" */
#define UFE_READ_SHADOW             2707    /* MSG "-0712 Error when attempting to read shadow file" */
#define UFE_MAX_USER_DB_OPENS       2708    /* MSG "-0775 Exceeded maximum number of user/database opens" */

/* Envyr U/FOS - INFOS II Errors */
#define UFE_UNEXPECTED              2709    /* MSG "Unexpected error from U/FOS or INFOS II" */
#define UFE_INV_AOS_INFOS_PKT       2710    /* MSG "Invalid AOS INFOS II subindex definition packet" */
#define UFE_DATA_REC_DELETED        2711    /* MSG "Data record is marked as logically deleted" */
#define UFE_PARTIAL_REC_DELETED     2712    /* MSG "Partial record is marked as logically deleted" */
#define UFE_DATA_REC_OVRFLW         2713    /* MSG "Data record read exceeds specified maximum length" */
#define UFE_PARTIAL_REC_OVRFLW      2714    /* MSG "Partial record read exceeds specified maximum length" */
#define UFE_INV_PARTIAL_LEN         2715    /* MSG "Invalid partial record length" */
#define UFE_READ_ONLY_REQ           2716    /* MSG "Request requires read-only access" */
#define UFE_INV_INDEX_NODE_SIZE     2717    /* MSG "Invalid index node size" */
#define UFE_INDEX_EXISTS            2718    /* MSG "Index filename already exists" */
#define UFE_INV_MERIT               2719    /* MSG "Invalid merit factor" */

/* Unused */
#define UFE_2720                    2720
#define UFE_2721                    2721
#define UFE_2722                    2722
#define UFE_2723                    2723
#define UFE_2724                    2724
#define UFE_2725                    2725
#define UFE_2726                    2726
#define UFE_2727                    2727
#define UFE_2728                    2728
#define UFE_2729                    2729
#define UFE_2730                    2730
#define UFE_2731                    2731
#define UFE_2732                    2732
#define UFE_2733                    2733
#define UFE_2734                    2734
#define UFE_2735                    2735
#define UFE_2736                    2736
#define UFE_2737                    2737
#define UFE_2738                    2738
#define UFE_2739                    2739
#define UFE_2740                    2740
#define UFE_2741                    2741
#define UFE_2742                    2742
#define UFE_2743                    2743
#define UFE_2744                    2744
#define UFE_2745                    2745

/* Errors from U/FOS 1.31 */
#define UFE_TG_IN_PROGRESS          2746    /* MSG "-0252 Transaction group already in progress" */
#define UFE_NO_TG_IN_PROGRESS       2747    /* MSG "-0253 No transaction group in progress" */
#define UFE_TG_NOT_BY_USER          2748    /* MSG "-0254 Transaction group not initiated by this user" */
#define UFE_INV_KEY_LEN             2749    /* MSG "-0255 Invalid key length" */
#define UFE_NO_BANNER               2750    /* MSG "-0310 Cannot find banner file name" */
#define UFE_NO_BANNER_PROD          2751    /* MSG "-0311 No banner file present for this product" */
#define UFE_SRVR_NOT_FND            2752    /* MSG "-0312 Banner server not found" */
#define UFE_BANNER_SRVR_ATTACH      2753    /* MSG "-0313 Cannot attach to the banner server" */
#define UFE_AIM_TOOLS               2754    /* MSG "-0314 AIM tools not allowed" */
#define UFE_GET_MAX_USERS           2755    /* MSG "-0315 Cannot get maximum number of users" */
#define UFE_ALLOC_MAX_USERS         2756    /* MSG "-0316 Cannot allocate maximum number of users" */
#define UFE_CORRUPT_MSG_Q_DATA      2757    /* MSG "-0317 Data has been corrupted in message queues" */
#define UFE_NO_MSG_AVAILABLE        2758    /* MSG "-0320 No message available on interprocess queue" */
#define UFE_NO_VALID_SESSION        2759    /* MSG "-0321 Could not generate a valid session" */
#define UFE_BAD_SESSION_ID          2760    /* MSG "-0322 Bad session ID" */
#define UFE_SRVR_ACCESS             2761    /* MSG "-0323 System access to server failed" */
#define UFE_SRVR_DENIED_REQ         2762    /* MSG "-0324 Request denied by banner server" */
#define UFE_BAD_BANNER_NAME         2763    /* MSG "-0325 Corrupt or inaccessible banner name" */
#define UFE_BANNER_ENT_NOT_FND      2764    /* MSG "-0326 Banner file name entry missing from configuration file" */
#define UFE_TARGET_DB               2765    /* MSG "-0343 Error in target database" */
#define UFE_READING_TARGET_DB       2766    /* MSG "-0344 Error reading target database" */
#define UFE_LINK_ALTS               2767    /* MSG "-0345 Cannot link alternate index to another alternate index database" */
#define UFE_MAX_LINKED_INDICES      2768    /* MSG "-0346 No more linked indices allowed for this database" */
#define UFE_POSN_TARGET_DB          2769    /* MSG "-0347 Error positioning target database" */
#define UFE_RW_DB_HDR               2770    /* MSG "-0350 Unable to rewrite database header" */
#define UFE_ALT_CREATE_LINK         2771    /* MSG "-0351 Unable to create alternate index symbolic link" */
#define UFE_ALT_CREATE              2772    /* MSG "-0352 Unable to create alternate index" */
#define UFE_ALT_WRITE               2773    /* MSG "-0353 Unable to write to alternate index" */
#define UFE_2774                    2774
#define UFE_2775                    2775
#define UFE_2776                    2776
#define UFE_2777                    2777

/* Errors from U/FOS 2.1 */
#define UFE_MSG_QUEUE               2778    /* MSG "-0327 Unable to place message on message queue" */
#define UFE_MSG_SND_TIMEOUT         2779    /* MSG "-0330 Message send timed out" */
#define UFE_MSG_RCV_TIMEOUT         2780    /* MSG "-0331 Message receive timed out" */
#define UFE_SHMEM_SPACE_KERNELS     2781    /* MSG "-0360 No space in shared memory table of kernel processes" */
#define UFE_SHMEM_SPACE_DBS         2782    /* MSG "-0361 No space in shared memory table of databases opened" */
#define UFE_DB_REQ_QUEUE_FULL       2783    /* MSG "-0362 Database request queue full" */
#define UFE_REQ_QUEUE_TIMEOUT       2784    /* MSG "-0363 Timed out waiting on request queue" */
#define UFE_MONITOR_START_FAIL      2785    /* MSG "-0364 Failed to start monitor process" */
#define UFE_SHARED_MEMORY_INV       2786    /* MSG "-0365 Shared memory tables invalid" */
#define UFE_LOG_WRITE               2787    /* MSG "-0552 Failed to write to log file" */
#define UFE_LOG_WRITE_ERR           2788    /* MSG "-0663 Error attaching to shared memory" */
#define UFE_SHMEM_SEMAPHORE_ERR     2789    /* MSG "-0664 Error accessing shared memory semaphore" */
#define UFE_PROCESS_LOCKS_ERR       2790    /* MSG "-0665 Error accessing file of process locks" */
#define UFE_FILE_STATUS_ERR         2791    /* MSG "-0666 Error getting file status" */
#define UFE_SEMAPHORE_SET_ERR       2792    /* MSG "-0667 Error removing the semaphore set" */
#define UFE_SHMEM_REMOVAL_ERR       2793    /* MSG "-0670 Error removing the shared memory set" */
#define UFE_DB_SEMAPHORE_ERR        2794    /* MSG "-0671 Error accessing database semaphore set" */
#define UFE_MULTI_REQ_DIFF_ERR      2795    /* MSG "-0673 Error reading page from multi-request diff file" */
#define UFE_DB_VOL_UNLINK_ERR       2796    /* MSG "-0674 Error from database volume unlink request" */
#define UFE_DB_VOL_TRUNC_ERR        2797    /* MSG "-0675 Error from database volume truncate request" */

/* Error codes from U/FOS 2.4 */
#define UFE_INV_ROOT_NODE_SIZE      2798    /* MSG "-0256 Invalid subindex root node size" */
#define UFE_CHKPT_TRANS_CONFL       2799    /* MSG "-0257 Database in checkpointing mode, cannot start transaction" */
#define UFE_NOT_CHKPT_MODE          2800    /* MSG "-0260 Cannot checkpoint, as not in checkpointing mode" */
#define UFE_CHKPT_REQ_DB_CLOSED     2801    /* MSG "-0261 Can only perform a checkpoint with database closed" */
#define UFE_NOT_EXPL_CHKPT_MODE     2802    /* MSG "-0262 Cannot checkpoint, as not in explicit checkpointing mode" */
#define UFE_LOCK_TBL_VOL_OPEN       2803    /* MSG "-0335 Cannot open database lock table volume" */
#define UFE_LOCK_TBL_VOL_WRITE      2804    /* MSG "-0336 Failed to write to database lock table volume" */
#define UFE_LOCK_TBL_VOL_READ       2805    /* MSG "-0337 Failed to read from database lock table volume" */
#define UFE_UFOS_CONNECT            2806    /* MSG "-0367 Failed to start the 'ufos_connect' process" */
#define UFE_CANNOT_OPEN_UNP         2807    /* MSG "-0560 Failed to open the network path (.unp) file" */
#define UFE_UFOS_NOT_IMPL_HERE      2808    /* MSG "-0561 U/FOS kernel not yet implemented on this platform" */
#define UFE_ERROR_IN_UNP_FILE       2809    /* MSG "-0562 Error in the network path (.unp) file" */
#define UFE_ACCESS_TO_IPC_TYPE      2810    /* MSG "-0563 Unable to access the ipc type used by the kernel" */
#define UFE_INV_HOST_NAME           2811    /* MSG "-0564 Invalid host name specified" */
#define UFE_KERNEL_CONFIG_FILE      2812    /* MSG "-0513 Error reading the kernel configuration file" */
#define UFE_MAX_DB_COMBINATIONS     2813    /* MSG "-0514 Exceeded number of user database combinations" */
#define UFE_UID_ERR                 2814    /* MSG "-0530 Error setting effective user ID" */
#define UFE_GID_ERR                 2815    /* MSG "-0531 Error setting effective group ID" */
#define UFE_GROUP_LIST_ERR          2816    /* MSG "-0532 Error setting supplementary group access list" */
#define UFE_KERN_LACKS_NEW_LOG      2817    /* MSG "-0553 Log in use by kernel not supporting 'ufos_new_log'" */
#define UFE_LOG_FILE_RENAME         2818    /* MSG "-0554 Failed to rename old log file" */
#define UFE_LOG_FILE_CREATE         2819    /* MSG "-0555 Failed to create a new log file" */
#define UFE_ROOT_NODE_PAGE_TBL      2820    /* MSG "-0627 Subindex root-node page item table corrupt" */
#define UFE_ROOT_NODE_INV_ITEM      2821    /* MSG "-0630 Subindex root-node item number invalid" */
#define UFE_DB_INCOMPLETE_CHKPT     2822    /* MSG "-0631 Database volumes contain an incomplete checkpoint" */
#define UFE_MULT_REQ_DIFF_ERR       2823    /* MSG "-0713 Error processing the multiple request differential file" */
#define UFE_PROCESS_ROOT_NODE       2824    /* MSG "-0714 Error processing subindex root node" */
#define UFE_EXPAND_ROOT_NODE        2825    /* MSG "-0715 Error expanding subindex root node" */
#define UFE_OPENING_CHKPNT_ERR      2826    /* MSG "-0716 Error processing opening checkpoint" */

#define MAX_UFOS_ERR                2826

/* up to 3071 is available */
#define UFE_MAX_ERROR               3071


/****************************************************************/
/*                                                              */
/*    special AOS/VS error group (ISE_xxx) - 3072-4095          */
/*                                                              */
/****************************************************************/

/* this is the old infostat group */

#define IS_SYS_BASE      0
#define IS_INFOS_BASE    07000
#define IS_COBOL_BASE    015000
#define IS_C_BASE        0221000

/* NOTE:  These messages are never referenced by the code.
          Only their text is retrieved.
*/

/* AOS/VS system errors */
#define ISE_SYS_BEGIN   3072
#define ISE_3072  3072  /* MSG "No error" */
#define ISE_3073  3073  /* MSG "Illegal system command" */
#define ISE_3074  3074  /* MSG "Channel not open" */
#define ISE_3075  3075  /* MSG "Channel already open" */
#define ISE_3076  3076  /* MSG "Shared I/O request not map slot aligned" */
#define ISE_3077  3077  /* MSG "Insufficient memory available" */
#define ISE_3078  3078  /* MSG "Illegal starting address" */
#define ISE_3079  3079  /* MSG "Illegal overlay number" */
#define ISE_3080  3080  /* MSG "Illegal set time argument" */
#define ISE_3081  3081  /* MSG "No task control block available" */
#define ISE_3082  3082  /* MSG "?XMT to address already in use" */
#define ISE_3083  3083  /* MSG "Error in user task queue table" */
#define ISE_3084  3084  /* MSG "Task ID error" */
#define ISE_3085  3085  /* MSG "Data channel map is full" */
#define ISE_3086  3086  /* MSG "System call parameter address error" */
#define ISE_3087  3087  /* MSG "Task not found for abort" */
#define ISE_3088  3088  /* MSG "Insufficient room in buffer" */
#define ISE_3089  3089  /* MSG "File space exhausted" */
#define ISE_3090  3090  /* MSG "User stack fault" */
#define ISE_3091  3091  /* MSG "Directory does not exist" */
#define ISE_3092  3092  /* MSG "Illegal filename character" */
#define ISE_3093  3093  /* MSG "File does not exist" */
#define ISE_3094  3094  /* MSG "Filename already exists" */
#define ISE_3095  3095  /* MSG "Non-directory argument in pathname" */
#define ISE_3096  3096  /* MSG "End of file" */
#define ISE_3097  3097  /* MSG "Directory delete error" */
#define ISE_3098  3098  /* MSG "Write access denied" */
#define ISE_3099  3099  /* MSG "Read access denied" */
#define ISE_3100  3100  /* MSG "Append and/or write access denied" */
#define ISE_3101  3101  /* MSG "No free channels" */
#define ISE_3102  3102  /* MSG "Release of non-active shared slot" */
#define ISE_3103  3103  /* MSG "Illegal process priority" */
#define ISE_3104  3104  /* MSG "Illegal maximum process size" */
#define ISE_3105  3105  /* MSG "Illegal process type" */
#define ISE_3106  3106  /* MSG "Console device specification error" */
#define ISE_3107  3107  /* MSG "Out of swap file room" */
#define ISE_3108  3108  /* MSG "Device already in system" */
#define ISE_3109  3109  /* MSG "Illegal device code" */
#define ISE_3110  3110  /* MSG "Error on shared partition set" */
#define ISE_3111  3111  /* MSG "Error on remap call" */
#define ISE_3112  3112  /* MSG "Illegal agent gate call" */
#define ISE_3113  3113  /* MSG "No PID available for this process" */
#define ISE_3114  3114  /* MSG "IPC message longer than buffer" */
#define ISE_3115  3115  /* MSG "Invalid port number" */
#define ISE_3116  3116  /* MSG "No matching send" */
#define ISE_3117  3117  /* MSG "No outstanding receive" */
#define ISE_3118  3118  /* MSG "Illegal origin port" */
#define ISE_3119  3119  /* MSG "Illegal destination port" */
#define ISE_3120  3120  /* MSG "Invalid shared library reference" */
#define ISE_3121  3121  /* MSG "Illegal record length specified" */
#define ISE_3122  3122  /* MSG "Attempt to release console device" */
#define ISE_3123  3123  /* MSG "Device already in use" */
#define ISE_3124  3124  /* MSG "Attempt to release unassigned device" */
#define ISE_3125  3125  /* MSG "Attempt to close unopen channel or device" */
#define ISE_3126  3126  /* MSG "I/O terminated by CLOSE" */
#define ISE_3127  3127  /* MSG "Line too long" */
#define ISE_3128  3128  /* MSG "Parity error" */
#define ISE_3129  3129  /* MSG "Resident process tried to create son and block" */
#define ISE_3130  3130  /* MSG "Not a directory" */
#define ISE_3131  3131  /* MSG "Shared I/O request not to shared area" */
#define ISE_3132  3132  /* MSG "Too many subordinate processes" */
#define ISE_3133  3133  /* MSG "File read error" */
#define ISE_3134  3134  /* MSG "Device timeout" */
#define ISE_3135  3135  /* MSG "Wrong I/O type for OPEN type" */
#define ISE_3136  3136  /* MSG "Filename too long" */
#define ISE_3137  3137  /* MSG "Positioning before beginning of file" */
#define ISE_3138  3138  /* MSG "Caller not privileged for this action" */
#define ISE_3139  3139  /* MSG "Simultaneous requests on same channel" */
#define ISE_3140  3140  /* MSG "Illegal file type" */
#define ISE_3141  3141  /* MSG "Insufficient room in directory" */
#define ISE_3142  3142  /* MSG "Illegal OPEN" */
#define ISE_3143  3143  /* MSG "Attempt to access process not in hierarchy" */
#define ISE_3144  3144  /* MSG "Attempt to block unblockable process" */
#define ISE_3145  3145  /* MSG "Invalid system call parameter" */
#define ISE_3146  3146  /* MSG "Attempt to start multiple agents" */
#define ISE_3147  3147  /* MSG "Channel in use" */
#define ISE_3148  3148  /* MSG "Not enough contiguous disk blocks" */
#define ISE_3149  3149  /* MSG "Stack overflow" */
#define ISE_3150  3150  /* MSG "Inconsistent bitmap data" */
#define ISE_3151  3151  /* MSG "Illegal block size for device" */
#define ISE_3152  3152  /* MSG "Attempt to ?XMT illegal message" */
#define ISE_3153  3153  /* MSG "Physical unit failure" */
#define ISE_3154  3154  /* MSG "Physical write lock" */
#define ISE_3155  3155  /* MSG "Physical unit off-line" */
#define ISE_3156  3156  /* MSG "Illegal OPEN option for file type" */
#define ISE_3157  3157  /* MSG "Too many or too few device names" */
#define ISE_3158  3158  /* MSG "Disk and file system revision numbers don't match" */
#define ISE_3159  3159  /* MSG "Inconsistent device information block (DIB) data" */
#define ISE_3160  3160  /* MSG "Inconsistent logical disk unit (LDU)" */
#define ISE_3161  3161  /* MSG "Incomplete logical disk unit (LDU)" */
#define ISE_3162  3162  /* MSG "Illegal device name type" */
#define ISE_3163  3163  /* MSG "Illogical process address space definition" */
#define ISE_3164  3164  /* MSG "LDU in use, cannot release" */
#define ISE_3165  3165  /* MSG "Too many directories in search list" */
#define ISE_3166  3166  /* MSG "Cannot get IPC data from father" */
#define ISE_3167  3167  /* MSG "Illegal library number given" */
#define ISE_3168  3168  /* MSG "Illegal record format" */
#define ISE_3169  3169  /* MSG "Too many or too few arguments to PMGR" */
#define ISE_3170  3170  /* MSG "Illegal ?GTMES parameters" */
#define ISE_3171  3171  /* MSG "Illegal CLI message" */
#define ISE_3172  3172  /* MSG "Message receive disabled by CHARACTERISTICS/NRM" */
#define ISE_3173  3173  /* MSG "Not a console device" */
#define ISE_3174  3174  /* MSG "Attempt to exceed maximum index level" */
#define ISE_3175  3175  /* MSG "Illegal channel" */
#define ISE_3176  3176  /* MSG "No receiver waiting" */
#define ISE_3177  3177  /* MSG "Short receive request" */
#define ISE_3178  3178  /* MSG "Transmitter inoperative" */
#define ISE_3179  3179  /* MSG "Illegal username" */
#define ISE_3180  3180  /* MSG "Illegal link number" */
#define ISE_3181  3181  /* MSG "Disk positioning error" */
#define ISE_3182  3182  /* MSG "Message text longer than specified" */
#define ISE_3183  3183  /* MSG "Short transmission" */
#define ISE_3184  3184  /* MSG "Illogical histogram call" */
#define ISE_3185  3185  /* MSG "Illegal retry value" */
#define ISE_3186  3186  /* MSG "ASSIGN error - already your device" */
#define ISE_3187  3187  /* MSG "Mag tape request past logical end of tape" */
#define ISE_3188  3188  /* MSG "Packet specifies stack too small" */
#define ISE_3189  3189  /* MSG "Packet would create too many tasks" */
#define ISE_3190  3190  /* MSG "Spooler open retry count exceeded" */
#define ISE_3191  3191  /* MSG "Illegal ACL" */
#define ISE_3192  3192  /* MSG "?STMAP buffer contains invalid or write-protected page" */
#define ISE_3193  3193  /* MSG "Partner process has not opened IPC file" */
#define ISE_3194  3194  /* MSG "FPU hardware not installed" */
#define ISE_3195  3195  /* MSG "Illegal process name" */
#define ISE_3196  3196  /* MSG "Process name already in use" */
#define ISE_3197  3197  /* MSG "Disconnect error" */
#define ISE_3198  3198  /* MSG "Process must block to pass generic files" */
#define ISE_3199  3199  /* MSG "System not installed" */
#define ISE_3200  3200  /* MSG "Maximum directory tree depth exceeded" */
#define ISE_3201  3201  /* MSG "Releasing out-of-use overlay" */
#define ISE_3202  3202  /* MSG "Resource deadlock" */
#define ISE_3203  3203  /* MSG "File is open, cannot exclusively open" */
#define ISE_3204  3204  /* MSG "File is exclusively opened, cannot open" */
#define ISE_3205  3205  /* MSG "Initialization privilege denied" */
#define ISE_3206  3206  /* MSG "Multiple ?I#define IFS_0  0    calls to same DCT" */
#define ISE_3207  3207  /* MSG "Illegal link" */
#define ISE_3208  3208  /* MSG "Illegal DUMP format" */
#define ISE_3209  3209  /* MSG "EXEC not available" */
#define ISE_3210  3210  /* MSG "EXEC request function unknown" */
#define ISE_3211  3211  /* MSG "EXEC's process subtree only" */
#define ISE_3212  3212  /* MSG "Request refused by system operator" */
#define ISE_3213  3213  /* MSG "Cannot dismount, was not mounted" */
#define ISE_3214  3214  /* MSG "Switch or argument value greater than 65535" */
#define ISE_3215  3215  /* MSG "Input file does not exist" */
#define ISE_3216  3216  /* MSG "Output file does not exist" */
#define ISE_3217  3217  /* MSG "LIST file does not exist" */
#define ISE_3218  3218  /* MSG "DATA file does not exist" */
#define ISE_3219  3219  /* MSG "Recursive generic file OPEN failure" */
#define ISE_3220  3220  /* MSG "No message waiting" */
#define ISE_3221  3221  /* MSG "User data area (UDA) does not exist" */
#define ISE_3222  3222  /* MSG "Illegal device type from VSGEN" */
#define ISE_3223  3223  /* MSG "AOS/VS restart of system call" */
#define ISE_3224  3224  /* MSG "Fatal user runtime error" */
#define ISE_3225  3225  /* MSG "User commercial stack fault" */
#define ISE_3226  3226  /* MSG "User floating point stack fault" */
#define ISE_3227  3227  /* MSG "User data area (UDA) already exists" */
#define ISE_3228  3228  /* MSG "Illegal screenedit request (PMGR)" */
#define ISE_3229  3229  /* MSG "?SEND destination device held by ^S (CTRL-S)" */
#define ISE_3230  3230  /* MSG "Data overrun error" */
#define ISE_3231  3231  /* MSG "Control point directory max size exceeded" */
#define ISE_3232  3232  /* MSG "System or bootstrap disk not part of master logical disk (LDU)" */
#define ISE_3233  3233  /* MSG "Universal system, you can't do that" */
#define ISE_3234  3234  /* MSG "Execute access denied" */
#define ISE_3235  3235  /* MSG "Cannot initialize LDU; run FIXUP on it" */
#define ISE_3236  3236  /* MSG "File access denied" */
#define ISE_3237  3237  /* MSG "Directory access denied" */
#define ISE_3238  3238  /* MSG "Attempt to define more than one INFOS II process" */
#define ISE_3239  3239  /* MSG "INFOS II process not running" */
#define ISE_3240  3240  /* MSG "Attempt to issue MCA request while direct I/O in progress" */
#define ISE_3241  3241  /* MSG "Attempt to issue MCA direct I/O with request outstanding" */
#define ISE_3242  3242  /* MSG "Last task was killed" */
#define ISE_3243  3243  /* MSG "Resource load or release failure" */
#define ISE_3244  3244  /* MSG "Zero length filename specified" */
#define ISE_3245  3245  /* MSG "Buffer overflow" */
#define ISE_3246  3246  /* MSG "Transmission failure (too many NAKS)" */
#define ISE_3247  3247  /* MSG "Transmission failure (timeouts)" */
#define ISE_3248  3248  /* MSG "Disconnect occurred on sync line" */
#define ISE_3249  3249  /* MSG "EOT character received" */
#define ISE_3250  3250  /* MSG "Possible lost data on HASP line" */
#define ISE_3251  3251  /* MSG "Sync DCU inoperative (I/O aborted)" */
#define ISE_3252  3252  /* MSG "Conversational reply received" */
#define ISE_3253  3253  /* MSG "End of polling list reached without a response" */
#define ISE_3254  3254  /* MSG "Illegal relative terminal number" */
#define ISE_3255  3255  /* MSG "Reverse interrupt response received" */
#define ISE_3256  3256  /* MSG "Illegal line number specified" */
#define ISE_3257  3257  /* MSG "Not enough space for polling list" */
#define ISE_3258  3258  /* MSG "Contention situation while bidding" */
#define ISE_3259  3259  /* MSG "Out-of-sequence gen entry during SINIT" */
#define ISE_3260  3260  /* MSG "Request to a non-synchronous line" */
#define ISE_3261  3261  /* MSG "Not enough memory for communications buffer" */
#define ISE_3262  3262  /* MSG "Line already enabled when ?SEBL call issued" */
#define ISE_3263  3263  /* MSG "Line already disabled when ?SDBL call issued" */
#define ISE_3264  3264  /* MSG "I/O request on a disabled line" */
#define ISE_3265  3265  /* MSG "Line in session on initial I/O request" */
#define ISE_3266  3266  /* MSG "Line not in session on continue I/O request" */
#define ISE_3267  3267  /* MSG "Buffer byte count larger than system buffer" */
#define ISE_3268  3268  /* MSG "Bid error (too many NAKS)" */
#define ISE_3269  3269  /* MSG "Wait-A-Bit received (HASP line only)" */
#define ISE_3270  3270  /* MSG "User buffer byte pointer invalid" */
#define ISE_3271  3271  /* MSG "Retry count exceeded" */
#define ISE_3272  3272  /* MSG "ETX code received" */
#define ISE_3273  3273  /* MSG "Input status format error" */
#define ISE_3274  3274  /* MSG "Failure to connect error" */
#define ISE_3275  3275  /* MSG "Uninterpretable response received" */
#define ISE_3276  3276  /* MSG "ENQ received" */
#define ISE_3277  3277  /* MSG "Block check error" */
#define ISE_3278  3278  /* MSG "Initialization parameter error" */
#define ISE_3279  3279  /* MSG "Transmitter failure error" */
#define ISE_3280  3280  /* MSG "Line not multidrop" */
#define ISE_3281  3281  /* MSG "Not a control station" */
#define ISE_3282  3282  /* MSG "Polling list not defined" */
#define ISE_3283  3283  /* MSG "Inconsistent tab format" */
#define ISE_3284  3284  /* MSG "Cannot delete permanent file" */
#define ISE_3285  3285  /* MSG "System call abort" */
#define ISE_3286  3286  /* MSG "Extended context already defined" */
#define ISE_3287  3287  /* MSG "Unreadable tape or diskette label" */
#define ISE_3288  3288  /* MSG "Incorrect labeled volume mounted" */
#define ISE_3289  3289  /* MSG "Incorrect labeled tape fileset" */
#define ISE_3290  3290  /* MSG "Incorrect file section number" */
#define ISE_3291  3291  /* MSG "Incorrect labeled tape file generation number" */
#define ISE_3292  3292  /* MSG "Incorrect labeled tape file version number" */
#define ISE_3293  3293  /* MSG "No operator available" */
#define ISE_3294  3294  /* MSG "Unknown tape label format" */
#define ISE_3295  3295  /* MSG "Extended context already initialized" */
#define ISE_3296  3296  /* MSG "Extended context not initialized" */
#define ISE_3297  3297  /* MSG "Extended context not defined" */
#define ISE_3298  3298  /* MSG "Memory release error" */
#define ISE_3299  3299  /* MSG "Illegal translation parameter" */
#define ISE_3300  3300  /* MSG "Missing or invalid argument" */
#define ISE_3301  3301  /* MSG "Not in CLI format" */
#define ISE_3302  3302  /* MSG "Illegal bias factor" */
#define ISE_3303  3303  /* MSG "CPU time limit exceeded" */
#define ISE_3304  3304  /* MSG "Error in setting max CPU limit" */
#define ISE_3305  3305  /* MSG "File element size not multiple of 4" */
#define ISE_3306  3306  /* MSG "WACK response received" */
#define ISE_3307  3307  /* MSG "Process is not a server" */
#define ISE_3308  3308  /* MSG "Connection does not exist" */
#define ISE_3309  3309  /* MSG "Connection table full" */
#define ISE_3310  3310  /* MSG "Directory in use - cannot delete" */
#define ISE_3311  3311  /* MSG "Attempt to grow a shared file" */
#define ISE_3312  3312  /* MSG "Illegal directory name specification" */
#define ISE_3313  3313  /* MSG "Network not available" */
#define ISE_3314  3314  /* MSG "Host already exist" */
#define ISE_3315  3315  /* MSG "Illegal host specification" */
#define ISE_3316  3316  /* MSG "Host does not exist" */
#define ISE_3317  3317  /* MSG "Cannot rename host entries" */
#define ISE_3318  3318  /* MSG "Empty mailbox on ?RECNW" */
#define ISE_3319  3319  /* MSG "Unable to access network in this manner" */
#define ISE_3320  3320  /* MSG "Attempt to create multiple local host" */
#define ISE_3321  3321  /* MSG "Not awaiting ?IWKUP" */
#define ISE_3322  3322  /* MSG "Illegal remote ?PROC parameter(s)" */
#define ISE_3323  3323  /* MSG "Illegal host name" */
#define ISE_3324  3324  /* MSG "Not proper for a virtual circuit" */
#define ISE_3325  3325  /* MSG "HDLC - invalid window size" */
#define ISE_3326  3326  /* MSG "Invalid frame size" */
#define ISE_3327  3327  /* MSG "SEND active" */
#define ISE_3328  3328
#define ISE_3329  3329
#define ISE_3330  3330
#define ISE_3331  3331
#define ISE_3332  3332
#define ISE_3333  3333
#define ISE_3334  3334
#define ISE_3335  3335
#define ISE_3336  3336
#define ISE_3337  3337
#define ISE_3338  3338
#define ISE_3339  3339
#define ISE_3340  3340
#define ISE_3341  3341
#define ISE_3342  3342
#define ISE_3343  3343
#define ISE_3344  3344
#define ISE_3345  3345
#define ISE_3346  3346
#define ISE_3347  3347
#define ISE_3348  3348  /* MSG "Unknown Error" */
#define ISE_3349  3349
#define ISE_3350  3350
#define ISE_3351  3351
#define ISE_SYS_END     3351


/* AOS/VS COBOL runtime errors */

#define ISE_COBOL_BEGIN 3352
#define ISE_3352  3352  /* MSG "AOS/VS COBOL Runtime Error Messages" */
#define ISE_3353  3353  /* MSG "Abnormal termination of a SORT/MERGE operation" */
#define ISE_3354  3354  /* MSG "Error during OPEN of a file for ACCEPT" */
#define ISE_3355  3355  /* MSG "Error during OPEN of a file for DISPLAY" */
#define ISE_3356  3356  /* MSG "Successful completion, duplicate key entry written" */
#define ISE_3357  3357  /* MSG "END OF FILE condition" */
#define ISE_3358  3358  /* MSG "INVALID KEY condition, duplicate key not permitted" */
#define ISE_3359  3359  /* MSG "INVALID KEY condition, selected record does not exist" */
#define ISE_3360  3360  /* MSG "INVALID KEY condition, relative key value is too large" */
#define ISE_3361  3361  /* MSG "I/O error (such as data check, parity error, transmission error)" */
#define ISE_3362  3362  /* MSG "Disk overflow or physical end of file (end of a tape reel)" */
#define ISE_3363  3363  /* MSG "File does not exist (OPEN error)" */
#define ISE_3364  3364  /* MSG "On access: file not open in correct mode. On OPEN: file locked or open" */
#define ISE_3365  3365  /* MSG "On access: record locked. on OPEN: exclusive open conflict" */
#define ISE_3366  3366  /* MSG "OPEN labeled tape error" */
#define ISE_3367  3367  /* MSG "Record accessed has been marked as logically deleted" */
#define ISE_3368  3368  /* MSG "REWRITE or DELETE attempted without executing previous READ" */
#define ISE_3369  3369  /* MSG "INFOS error has occurred for which there is no corresponding FILE STATUS" */
#define ISE_3370  3370  /* MSG "Record (from READ) is longer than maximum record length specified" */
#define ISE_3371  3371  /* MSG "DELETE ... RECORD may not be used with this RELATIVE file" */
#define ISE_COBOL_END   3371


/* C runtime errors */

#define ISE_C_BEGIN     3372
#define ISE_3372  3372  /* MSG "Data General C runtime error messages." */
#define ISE_3373  3373  /* MSG "Illegal argument." */
#define ISE_3374  3374  /* MSG "Failed to open standard error file." */
#define ISE_3375  3375  /* MSG "Illegal open type for file type." */
#define ISE_3376  3376  /* MSG "No open channel." */
#define ISE_3377  3377  /* MSG "Error on input occurred." */
#define ISE_3378  3378
#define ISE_3379  3379  /* MSG "Assertion failed." */
#define ISE_3380  3380  /* MSG "Illegal argument value passed." */
#define ISE_3381  3381  /* MSG "Invalid mode passed to fseek or ftell." */
#define ISE_3382  3382  /* MSG "Attempt to use a character pointer as a word pointer." */
#define ISE_3383  3383  /* MSG "Attempt to use a word pointer as a character pointer." */
#define ISE_3384  3384  /* MSG "Use of an illegal pointer." */
#define ISE_3385  3385  /* MSG "End of Infos-II record." */
#define ISE_3386  3386  /* MSG "Attempt to convert an odd character pointer to a word pointer." */
#define ISE_3387  3387
#define ISE_3388  3388
#define ISE_3389  3389
#define ISE_3390  3390
#define ISE_3391  3391
#define ISE_3392  3392
#define ISE_3393  3393
#define ISE_3394  3394
#define ISE_3395  3395
#define ISE_3396  3396
#define ISE_3397  3397
#define ISE_3398  3398
#define ISE_3399  3399
#define ISE_3400  3400
#define ISE_3401  3401
#define ISE_3402  3402
#define ISE_3403  3403
#define ISE_3404  3404
#define ISE_3405  3405
#define ISE_3406  3406
#define ISE_3407  3407
#define ISE_3408  3408
#define ISE_3409  3409
#define ISE_3410  3410
#define ISE_3411  3411
#define ISE_3412  3412
#define ISE_3413  3413
#define ISE_3414  3414
#define ISE_3415  3415
#define ISE_3416  3416
#define ISE_3417  3417
#define ISE_3418  3418
#define ISE_3419  3419
#define ISE_3420  3420
#define ISE_3421  3421
#define ISE_3422  3422
#define ISE_3423  3423
#define ISE_3424  3424
#define ISE_3425  3425
#define ISE_3426  3426
#define ISE_3427  3427
#define ISE_3428  3428
#define ISE_3429  3429
#define ISE_3430  3430
#define ISE_3431  3431
#define ISE_3432  3432
#define ISE_3433  3433
#define ISE_3434  3434
#define ISE_3435  3435
#define ISE_3436  3436  /* MSG "Illegal SIGNAL number" */
#define ISE_3437  3437  /* MSG "Failure while initializing C environment." */
#define ISE_3438  3438  /* MSG "Attempt to perform an illegal I/O operation." */
#define ISE_3439  3439  /* MSG "File is not open." */
#define ISE_3440  3440  /* MSG "File was not found." */
#define ISE_3441  3441  /* MSG "Invalid file descriptor." */
#define ISE_3442  3442  /* MSG "Unimplemented feature." */
#define ISE_3443  3443  /* MSG "User ID is not in /etc/passwd." */
#define ISE_3444  3444  /* MSG "Only the owner of the file can do that." */
#define ISE_3445  3445  /* MSG "Access error." */
#define ISE_3446  3446  /* MSG "Attempt to open more than 64 files simulaneously." */
#define ISE_3447  3447  /* MSG "Illegal open mode." */
#define ISE_3448  3448  /* MSG "'lseek' was applied to a pipe" */
#define ISE_3449  3449  /* MSG "'lseek' is illegal on this channel" */
#define ISE_3450  3450
#define ISE_3451  3451
#define ISE_3452  3452
#define ISE_3453  3453
#define ISE_3454  3454
#define ISE_3455  3455
#define ISE_3456  3456
#define ISE_3457  3457
#define ISE_3458  3458
#define ISE_3459  3459
#define ISE_3460  3460
#define ISE_3461  3461
#define ISE_3462  3462
#define ISE_3463  3463
#define ISE_3464  3464
#define ISE_3465  3465
#define ISE_3466  3466
#define ISE_3467  3467
#define ISE_3468  3468
#define ISE_3469  3469
#define ISE_3470  3470
#define ISE_3471  3471
#define ISE_3472  3472
#define ISE_3473  3473
#define ISE_3474  3474
#define ISE_3475  3475
#define ISE_3476  3476
#define ISE_3477  3477
#define ISE_3478  3478
#define ISE_3479  3479
#define ISE_3480  3480
#define ISE_3481  3481
#define ISE_3482  3482
#define ISE_3483  3483
#define ISE_3484  3484
#define ISE_3485  3485
#define ISE_3486  3486
#define ISE_3487  3487
#define ISE_3488  3488
#define ISE_3489  3489
#define ISE_3490  3490
#define ISE_3491  3491
#define ISE_3492  3492
#define ISE_3493  3493
#define ISE_3494  3494
#define ISE_3495  3495
#define ISE_3496  3496
#define ISE_3497  3497
#define ISE_3498  3498
#define ISE_3499  3499
#define ISE_3500  3500
#define ISE_3501  3501  /* MSG "Error EPERM(1) -- Not owner of file." */
#define ISE_3502  3502  /* MSG "Error ENOENT(2) -- No such file or directory." */
#define ISE_3503  3503  /* MSG "Error ESRCH(3) -- No such process." */
#define ISE_3504  3504
#define ISE_3505  3505  /* MSG "Error EIO(5) -- Error in input/output." */
#define ISE_3506  3506  /* MSG "Error ENXIO(6) -- Unknown device failure." */
#define ISE_3507  3507  /* MSG "Error E2BIG(7) -- Argument list too long." */
#define ISE_3508  3508  /* MSG "Error ENOEXEC(8) -- Exec format error." */
#define ISE_3509  3509  /* MSG "Error EBADF(9) -- Bad file number." */
#define ISE_3510  3510  /* MSG "Error ECHILD(10) -- No children." */
#define ISE_3511  3511  /* MSG "Error EAGAIN(11) -- No more processes allowed." */
#define ISE_3512  3512  /* MSG "Error ENOMEM(12) -- Not enough memory." */
#define ISE_3513  3513  /* MSG "Error EACCES(13) -- Permission denied." */
#define ISE_3514  3514  /* MSG "Error EFAULT(14) -- Bad address." */
#define ISE_3515  3515
#define ISE_3516  3516
#define ISE_3517  3517  /* MSG "Error EEXIST(17) -- File already exists." */
#define ISE_3518  3518
#define ISE_3519  3519
#define ISE_3520  3520  /* MSG "Error ENOTDIR(20) -- File is not a directory." */
#define ISE_3521  3521
#define ISE_3522  3522  /* MSG "Error EINVAL(22) -- Invalid argument." */
#define ISE_3523  3523
#define ISE_3524  3524  /* MSG "Error EMFILE(24) -- Too many open files." */
#define ISE_3525  3525
#define ISE_3526  3526
#define ISE_3527  3527  /* MSG "Error EFBIG(27) -- File too large." */
#define ISE_3528  3528  /* MSG "Error ENOSPC(28) -- No space left on device." */
#define ISE_3529  3529  /* MSG "Error ESPIPE(29) -- Seek on a pipe." */
#define ISE_3530  3530
#define ISE_3531  3531
#define ISE_3532  3532  /* MSG "Error EPIPE(32) -- Broken pipe." */
#define ISE_3533  3533  /* MSG "Error EDOM(33) -- Math argument out of domain of function." */
#define ISE_3534  3534  /* MSG "Error ERANGE(34) -- Math routine produces result too large." */
#define ISE_3535  3535
#define ISE_3536  3536
#define ISE_3537  3537
#define ISE_3538  3538
#define ISE_3539  3539
#define ISE_3540  3540
#define ISE_3541  3541
#define ISE_3542  3542
#define ISE_3543  3543
#define ISE_3544  3544
#define ISE_3545  3545
#define ISE_3546  3546
#define ISE_3547  3547
#define ISE_3548  3548
#define ISE_3549  3549
#define ISE_3550  3550
#define ISE_3551  3551
#define ISE_3552  3552
#define ISE_3553  3553
#define ISE_3554  3554
#define ISE_3555  3555
#define ISE_3556  3556
#define ISE_3557  3557
#define ISE_3558  3558
#define ISE_3559  3559
#define ISE_3560  3560
#define ISE_3561  3561
#define ISE_3562  3562
#define ISE_3563  3563
#define ISE_3564  3564
#define ISE_3565  3565  /* MSG "Signal SIGHUP (hangup) aborted program." */
#define ISE_3566  3566  /* MSG "Signal SIGINT (interrupt) aborted program." */
#define ISE_3567  3567  /* MSG "Signal SIGQUIT (quit) aborted program with memory dump." */
#define ISE_3568  3568  /* MSG "Signal SIGILL (bad instruction) aborted program with memory dump." */
#define ISE_3569  3569  /* MSG "Signal SIGTRAP (trace trap) aborted program with memory dump." */
#define ISE_3570  3570  /* MSG "Signal SIGIOT (abort routine) aborted program with memory dump." */
#define ISE_3571  3571  /* MSG "Signal SIGEMT aborted program with memory dump." */
#define ISE_3572  3572  /* MSG "Signal SIGFPE (floating exception) aborted program with memory dump." */
#define ISE_3573  3573  /* MSG "Signal SIGKILL aborted program." */
#define ISE_3574  3574  /* MSG "Signal SIGBUS aborted program." */
#define ISE_3575  3575  /* MSG "Signal SIGSEGV (address trap) aborted program with memory dump." */
#define ISE_3576  3576  /* MSG "Signal SIGSYS aborted program with memory dump." */
#define ISE_3577  3577  /* MSG "Signal SIGPIPE aborted program." */
#define ISE_3578  3578  /* MSG "Signal SIGALRM (alarm clock) aborted program." */
#define ISE_3579  3579  /* MSG "Signal SIGTERM (software termination) aborted program." */
#define ISE_3580  3580  /* MSG "Signal SIGUSR1 (user defined #1) aborted program." */
#define ISE_3581  3581  /* MSG "Signal SIGUSR2 (user defined #2) aborted program." */
#define ISE_3582  3582  /* MSG "Signal SIGCHLD aborted program." */
#define ISE_3583  3583  /* MSG "Signal SIGPWR aborted program." */
#define ISE_C_END       3583

#define ISE_INFOS_BEGIN 3584
#define ISE_3584  3584  /* MSG "(IOUER) Illegal command" */
#define ISE_3585  3585  /* MSG "(IONMD) All volumes at maximum size" */
#define ISE_3586  3586  /* MSG "(IOCON) Continuing execution" */
#define ISE_3587  3587  /* MSG "(IOINI) Revision 5.01 of AOS/VS INFOS II error codes" */
#define ISE_3588  3588  /* MSG "(IOSPE) Illegal relative motion" */
#define ISE_3589  3589  /* MSG "(IOICE) Invalid current entry" */
#define ISE_3590  3590  /* MSG "(IOTLV) Warning - positioned above main index (top level)" */
#define ISE_3591  3591  /* MSG "(IOSNA) Subindexes not allowed" */
#define ISE_3592  3592  /* MSG "(IOSNP) Subindex not defined" */
#define ISE_3593  3593  /* MSG "(IOESI) End of subindex" */
#define ISE_3594  3594  /* MSG "(IODPE) A requestor on another channel is positioned on the key to delete" */
#define ISE_3595  3595  /* MSG "(IOKAE) Key already exists" */
#define ISE_3596  3596  /* MSG "(IONDR) Warning - data base record not present" */
#define ISE_3597  3597  /* MSG "(IODRL) Data record locked" */
#define ISE_3598  3598  /* MSG "(IOSAE) Already linked to subindex" */
#define ISE_3599  3599  /* MSG "(IOSTL) File consistency error" */
#define ISE_3600  3600  /* MSG "(IOSLO) Define subindex command would exceed max. index levels for file" */
#define ISE_3601  3601  /* MSG "(IOSST) Entry has subindex -- delete error" */
#define ISE_3602  3602  /* MSG "(IODWK) Attempt to delete entry without keyed access" */
#define ISE_3603  3603  /* MSG "(IOIRI) Index entry already points to a different record" */
#define ISE_3604  3604  /* MSG "(IOWWK) Command requires keyed access" */
#define ISE_3605  3605  /* MSG "(IOENL) Partial record locked" */
#define ISE_3606  3606  /* MSG "(IOLVR) Too many index levels" */
#define ISE_3607  3607
#define ISE_3608  3608  /* MSG "(IOKPE) Keyed positioning error" */
#define ISE_3609  3609  /* MSG "(IOIEN) Invalid entry number in index" */
#define ISE_3610  3610  /* MSG "(IOINA) Invalid node address" */
#define ISE_3611  3611  /* MSG "(IODIP) Delete index error -- another user is positioned in that subindex" */
#define ISE_3612  3612  /* MSG "(IOTML) Lock request exceeds maximum number of locks" */
#define ISE_3613  3613  /* MSG "(IOSYS) Unexpected system call error return" */
#define ISE_3614  3614  /* MSG "(IODNS) Duplicate key not allowed in subindex" */
#define ISE_3615  3615  /* MSG "(IOIDE) File consistency error" */
#define ISE_3616  3616  /* MSG "(IOMAP) Space management map consistency error" */
#define ISE_3617  3617  /* MSG "(IOOCC) Occurred at location" */
#define ISE_3618  3618  /* MSG "(IOACE) Channel opened read-only, or read-only ACL; cannot modify file" */
#define ISE_3619  3619  /* MSG "(IONMT) Subindex not empty" */
#define ISE_3620  3620  /* MSG "(IORTL) Key file record wrong length" */
#define ISE_3621  3621  /* MSG "(IONIO) Key not in order" */
#define ISE_3622  3622  /* MSG "(IOLPR) Illegal partial record length -- use 1 to max allowed in subindex" */
#define ISE_3623  3623  /* MSG "(IOPIU) Communication file page in use -- access denied" */
#define ISE_3624  3624  /* MSG "(IOINF) Invalid in-use flag in single message request" */
#define ISE_3625  3625  /* MSG "(IOTMU) Maximum number of users exceeded" */
#define ISE_3626  3626  /* MSG "(IOISF) Invalid single message request format" */
#define ISE_3627  3627  /* MSG "(IOMTE) Maximum number of user tasks exceeded" */
#define ISE_3628  3628  /* MSG "(IOFER) File error -- please close" */
#define ISE_3629  3629  /* MSG "(IOFE2) File error -- cannot open at this time" */
#define ISE_3630  3630  /* MSG "RESERVED ERROR CODE" */
#define ISE_3631  3631  /* MSG "(IOPOW) File opened for exclusive write, you cannot open it for write access" */
#define ISE_3632  3632  /* MSG "(IOCOI) Cannot issue inverted create on file in logging mode" */
#define ISE_3633  3633  /* MSG "(IOPCH) Invalid channel number specified" */
#define ISE_3634  3634  /* MSG "(IOPDA) ?PDAT{.D} Data record or retrieve high key byte pointer invalid" */
#define ISE_3635  3635  /* MSG "(IOPKP) ?PKPN{.B} Illegal # of keys -- use 1 to # of subindex levels in the index" */
#define ISE_3636  3636  /* MSG "(IOPLE) ?PLEN{.W} Data record bytelength exceeds database pagesize-8, or is zero" */
#define ISE_3637  3637  /* MSG "(IOPLN) Data record link words invalid for inversion" */
#define ISE_3638  3638  /* MSG "(IOIPS) ?PCCW{.D} Neither keyed nor relative processing specified" */
#define ISE_3639  3639  /* MSG "(IOPSI) ?PSID{.D} Subindex definition packet address invalid" */
#define ISE_3640  3640  /* MSG "(IOPPP) ?PPRA{.D} Partial record byte pointer invalid" */
#define ISE_3641  3641  /* MSG "(IOLKX) Lock/unlock error -- either both lock and unlock specified, or neither partial nor data record selected" */
#define ISE_3642  3642  /* MSG "(IOPNZ) Initial packet contained nonzero reserved entries" */
#define ISE_3643  3643  /* MSG "(IORSE) Maximum request size exceeded" */
#define ISE_3644  3644  /* MSG "(IOUEE) Unexpected error -- error code exceeds 16 bits" */
#define ISE_3645  3645  /* MSG "(IOREV) Incompatible INFOS_LS.PR and INFOS_GS.PR revisions" */
#define ISE_3646  3646  /* MSG "(IOROS) File is already opened for read/write access, you cannot open it for sequential access" */
#define ISE_3647  3647  /* MSG "(IOLSS) File is already opened with locks specified, you cannot open it for sequential access" */
#define ISE_3648  3648  /* MSG "(IOSSL) File is opened for sequential access, you cannot specify any locks" */
#define ISE_3649  3649  /* MSG "(IOSWA) File is opened for sequential access, you cannot open for write access" */
#define ISE_3650  3650  /* MSG "(IORRA) Request requires read-only access" */
#define ISE_3651  3651  /* MSG "(IOKTY) ?KTYP{.D} Inconsistent key type flags" */
#define ISE_3652  3652  /* MSG "(IOKYL) ?KYLN{.B} Illegal key bytelength -- use 1 to maximum allowed in subindex" */
#define ISE_3653  3653  /* MSG "(IOKKY) ?KKYP{.D} Invalid key byte pointer" */
#define ISE_3654  3654  /* MSG "(IOKDK) Key not found in subindex" */
#define ISE_3655  3655  /* MSG "(IOKNZ) Key packet contained nonzero reserved entries" */
#define ISE_3656  3656  /* MSG "(IOKDO) Key descriptor level overflow" */
#define ISE_3657  3657  /* MSG "(IOKPR) Too many key descriptor packets for link subindex destination key path" */
#define ISE_3658  3658  /* MSG "(IOAKI) Alternate key field is invalid" */
#define ISE_3659  3659
#define ISE_3660  3660
#define ISE_3661  3661
#define ISE_3662  3662
#define ISE_3663  3663
#define ISE_3664  3664  /* MSG "(IONTS) ?FRNS{.W} Subindex definition root node size won't hold 3 key entries" */
#define ISE_3665  3665  /* MSG "(IONTL) ?FRNS{.W} Subindex definition root node size too large for page size" */
#define ISE_3666  3666  /* MSG "(IOMKL) ?FMKL{.B} Subindex definition maximum keylength exceeds ?MXKL{VS} bytes" */
#define ISE_3667  3667  /* MSG "(IOPRL) ?FPRL{.B} Subindex definition partial record length exceeds ?MXPR{VS} bytes" */
#define ISE_3668  3668  /* MSG "(IOSNZ) Subindex definition packet contained nonzero reserved entries" */
#define ISE_3669  3669
#define ISE_3670  3670
#define ISE_3671  3671
#define ISE_3672  3672
#define ISE_3673  3673
#define ISE_3674  3674
#define ISE_3675  3675
#define ISE_3676  3676
#define ISE_3677  3677  /* MSG "(IOVER) File version conflict" */
#define ISE_3678  3678  /* MSG "(IOPVR) Parameter version error -- reassemble with new user parameter files" */
#define ISE_3679  3679  /* MSG "(IORVR) Runtime version error -- relink with new INFOS II ICALL runtime" */
#define ISE_3680  3680  /* MSG "(IODDM) Index and database must be in same parent directory" */
#define ISE_3681  3681  /* MSG "(IONIV) Not an INFOS II volume file" */
#define ISE_3682  3682  /* MSG "(IOTMO) You attempted to open more than ?MXCHN{VS} INFOS II channels" */
#define ISE_3683  3683  /* MSG "(IODNC) Directory name doesn't begin with colon -- probable runtime error" */
#define ISE_3684  3684  /* MSG "(IONLR) ?FNLR{.B} Specified maximum number of simultaneous locks exceeds ?MXLK{VS}" */
#define ISE_3685  3685  /* MSG "RESERVED ERROR CODE" */
#define ISE_3686  3686  /* MSG "(IODBF) ?FDBP{.D} Database file definition packet address invalid" */
#define ISE_3687  3687  /* MSG "(IOAMD) ?FAM1{.S} ?FAM2{.S} Access method illegal in ?FFLG{.D}" */
#define ISE_3688  3688  /* MSG "(IONIL) ?FNIL{.B} Maximum index levels illegal -- use 1 to ?MXIL{VS}" */
#define ISE_3689  3689
#define ISE_3690  3690  /* MSG "(IOIOO) Illegal or conflicting options requested" */
#define ISE_3691  3691  /* MSG "(IOPNR) INFOS II disabled; user not recognized" */
#define ISE_3692  3692  /* MSG "(IODNM) Database must be simple filename with no special characters" */
#define ISE_3693  3693  /* MSG "(IOFDP) INFOS II index file definition packet pointer invalid" */
#define ISE_3694  3694  /* MSG "(IOIVP) IVERIFY in progress" */
#define ISE_3695  3695  /* MSG "(IOLOP) Log file open request exceeds maximum number allowed" */
#define ISE_3696  3696  /* MSG "(IONCL) COMLOG process not running" */
#define ISE_3697  3697  /* MSG "(IOOVE) Runtime version error -- incompatible with current rev of system" */
#define ISE_3698  3698  /* MSG "(IOINR) Remote INFOS II communications process not running on local host" */
#define ISE_3699  3699  /* MSG "(IOINN) Runtime version error -- ICALL doesn't support INFOS II networking" */
#define ISE_3700  3700  /* MSG "(IOPNQ) Local file pathname must not be networking qualified" */
#define ISE_3701  3701  /* MSG "(IORFR) Access to remote INFOS II files restricted to VTA" */
#define ISE_3702  3702  /* MSG "(IOSMF) Runtime version error -- incompatible single message format" */
#define ISE_3703  3703  /* MSG "(IOCSM) Spurious COMLOG acknowledgement message" */
#define ISE_3704  3704  /* MSG "(IOSMR) Spurious message received" */
#define ISE_3705  3705  /* MSG "(IOFNI) Not an INFOS II index file" */
#define ISE_3706  3706  /* MSG "(IODNI) Not an INFOS II database file" */
#define ISE_3707  3707  /* MSG "(IOFNA) ?FNAM{.D} Index filename byte pointer invalid" */
#define ISE_3708  3708  /* MSG "(IODNA) ?FNAM{.D} Database filename byte pointer invalid" */
#define ISE_3709  3709  /* MSG "(IOFPA) ?FPAG{.W} Index pagesize illegal -- use 2048 or 4096 bytes" */
#define ISE_3710  3710  /* MSG "(IODPA) ?FPAG{.W} Database pagesize illegal -- use 2048 or 4096 bytes" */
#define ISE_3711  3711  /* MSG "(IOFFL) ?FFLG{.D} Reserved bits set in index FDP flag word" */
#define ISE_3712  3712  /* MSG "(IODFL) ?FFLG{.D} Reserved bits set in database FDP flag word" */
#define ISE_3713  3713  /* MSG "(IOFNV) ?FNVD{.B} Index volume count illegal -- use 1 to ?MXVOL{VS}" */
#define ISE_3714  3714  /* MSG "(IODNV) ?FNVD{.B} Database volume count illegal -- use 1 to ?MXVOL{VS}" */
#define ISE_3715  3715  /* MSG "(IOFNZ) Packet contained nonzero reserved entries" */
#define ISE_3716  3716  /* MSG "(IODNZ) Database packet contained nonzero reserved entries" */
#define ISE_3717  3717  /* MSG "(IOVVN) ?VVNP{.D} Index volume name byte pointer invalid" */
#define ISE_3718  3718  /* MSG "(IODVN) ?VVNP{.D} Database volume name byte pointer invalid" */
#define ISE_3719  3719  /* MSG "(IOVVS) ?VVSZ{.D} Index maximum volume size exceeds 1,048,576 blocks" */
#define ISE_3720  3720  /* MSG "(IODVS) ?VVSZ{.D} Database maximum volume size exceeds 1,048,576 blocks" */
#define ISE_3721  3721  /* MSG "(IOFDE) Index file does not exist" */
#define ISE_3722  3722  /* MSG "(IODDE) Database file does not exist" */
#define ISE_3723  3723  /* MSG "(IOFAE) Index filename already exists" */
#define ISE_3724  3724  /* MSG "(IODAE) Database filename already exists" */
#define ISE_3725  3725  /* MSG "(IOFAD) Index file access denied" */
#define ISE_3726  3726  /* MSG "(IODAD) Database file access denied" */
#define ISE_3727  3727  /* MSG "(IOF01) Someone has the index open, you can't open it exclusively" */
#define ISE_3728  3728  /* MSG "(IOD01) Someone has the database open, you can't open it exclusively" */
#define ISE_3729  3729  /* MSG "(IOF02) Someone has the index exclusively opened, you can't open it" */
#define ISE_3730  3730  /* MSG "(IOD02) Someone has the database exclusively opened, you can't open it" */
#define ISE_3731  3731  /* MSG "(IOVNZ) Index file definition packet contained nonzero reserved entries" */
#define ISE_3732  3732  /* MSG "(IODZN) Database file definition packet contained nonzero reserved entries" */
#define ISE_3733  3733  /* MSG "(IOFTL) Index pathname longer than ?MXPL bytes including terminator" */
#define ISE_3734  3734  /* MSG "(IODTL) Database pathname longer than ?MXPL bytes including terminator" */
#define ISE_3735  3735  /* MSG "(IOFNR) Index filename required" */
#define ISE_3736  3736  /* MSG "(IODNR) Database filename required for inversion" */
#define ISE_3737  3737  /* MSG "(IOFDC) File open during system or INFOS II crash -- run IVERIFY" */
#define ISE_3738  3738  /* MSG "(IODDC) Database file open during system or INFOS II crash -- run IVERIFY" */
#define ISE_3739  3739  /* MSG "RESERVED ERROR CODE" */
#define ISE_3740  3740  /* MSG "RESERVED ERROR CODE" */
#define ISE_3741  3741  /* MSG "(IOVDE) An index volume does not exist" */
#define ISE_3742  3742  /* MSG "(IODVE) A database volume does not exist" */
#define ISE_3743  3743  /* MSG "(IOVMF) Index volume merit factor out of order" */
#define ISE_3744  3744  /* MSG "(IODVM) Database volume merit factor out of order" */
#define ISE_3745  3745  /* MSG "(IOIVA) Index volume file access denied" */
#define ISE_3746  3746  /* MSG "(IODVA) Database volume file access denied" */
#define ISE_3747  3747
#define ISE_3748  3748
#define ISE_3749  3749
#define ISE_3750  3750
#define ISE_3751  3751
#define ISE_3752  3752
#define ISE_3753  3753
#define ISE_3754  3754
#define ISE_3755  3755
#define ISE_3756  3756
#define ISE_3757  3757
#define ISE_3758  3758
#define ISE_3759  3759
#define ISE_3760  3760
#define ISE_3761  3761
#define ISE_3762  3762
#define ISE_3763  3763
#define ISE_3764  3764
#define ISE_3765  3765  /* MSG "(IOITC) Regenerate with at least 3 tasks" */
#define ISE_3766  3766  /* MSG "(IONSU) Created without superuser privileges" */
#define ISE_3767  3767  /* MSG "(IONIP) Created without IPC privileges" */
#define ISE_3768  3768  /* MSG "(IOVIF) Created without special process privilege ?PVIF" */
#define ISE_3769  3769  /* MSG "(IOILL) Internal logic error" */
#define ISE_3770  3770  /* MSG "(IOTER) Terminating -- terminate users and restart INFOS II" */
#define ISE_3771  3771  /* MSG "(IOREA) Request entry @INFOS already exists" */
#define ISE_3772  3772  /* MSG "(IOPER) Initial directory must be :PER" */
#define ISE_3773  3773  /* MSG "(IOTMI) Another INFOS II running" */
#define ISE_3774  3774
#define ISE_3775  3775
#define ISE_3776  3776  /* MSG "(IOIDS) Invalid system time date." */
#define ISE_3777  3777  /* MSG "(IOVMS) VM file space exhausted" */
#define ISE_3778  3778  /* MSG "(IOUGH) INFOS II global server forcibly terminated" */
#define ISE_3779  3779
#define ISE_3780  3780
#define ISE_3781  3781
#define ISE_3782  3782
#define ISE_3783  3783
#define ISE_3784  3784
#define ISE_3785  3785
#define ISE_3786  3786
#define ISE_3787  3787
#define ISE_3788  3788
#define ISE_3789  3789
#define ISE_3790  3790
#define ISE_3791  3791
#define ISE_3792  3792
#define ISE_3793  3793
#define ISE_3794  3794
#define ISE_3795  3795
#define ISE_3796  3796
#define ISE_3797  3797
#define ISE_3798  3798
#define ISE_3799  3799
#define ISE_3800  3800
#define ISE_3801  3801
#define ISE_3802  3802
#define ISE_3803  3803
#define ISE_3804  3804
#define ISE_3805  3805
#define ISE_3806  3806
#define ISE_3807  3807
#define ISE_3808  3808
#define ISE_3809  3809
#define ISE_3810  3810
#define ISE_3811  3811
#define ISE_3812  3812
#define ISE_3813  3813
#define ISE_3814  3814
#define ISE_3815  3815
#define ISE_3816  3816
#define ISE_3817  3817
#define ISE_3818  3818
#define ISE_3819  3819
#define ISE_3820  3820
#define ISE_3821  3821
#define ISE_3822  3822
#define ISE_3823  3823
#define ISE_3824  3824
#define ISE_3825  3825
#define ISE_3826  3826
#define ISE_3827  3827
#define ISE_3828  3828
#define ISE_3829  3829
#define ISE_3830  3830
#define ISE_3831  3831
#define ISE_3832  3832
#define ISE_3833  3833
#define ISE_3834  3834
#define ISE_3835  3835
#define ISE_3836  3836
#define ISE_3837  3837
#define ISE_3838  3838
#define ISE_3839  3839
#define ISE_3840  3840
#define ISE_3841  3841  /* MSG "(IOCPC) Differential file crashed during checkpoint -- run CHECKPOINT utility" */
#define ISE_3842  3842  /* MSG "(IOCNC) Crashed file was not checkpointing -- run IRECOVER" */
#define ISE_3843  3843  /* MSG "(IOCPT) ?TYPE{.W} Is not checkpoint packet type" */
#define ISE_3844  3844  /* MSG "(IOCND) Database file is not in differential mode" */
#define ISE_3845  3845  /* MSG "(IOCDB) Checkpoint file must be a database file" */
#define ISE_3846  3846  /* MSG "(IOCNO) File is not currently open to INFOS II" */
#define ISE_3847  3847  /* MSG "(IOODV) ?FNVD{.B} differential file volume count illegal -- use 1 to 16" */
#define ISE_3848  3848  /* MSG "RESERVED ERROR CODE" */
#define ISE_3849  3849  /* MSG "RESERVED ERROR CODE" */
#define ISE_3850  3850  /* MSG "(IOTP3) Database file is opened exclusively; you may not checkpoint" */
#define ISE_3851  3851  /* MSG "(IOOPU) File currently open to a utility or INFOS II" */
#define ISE_3852  3852  /* MSG "(IORCV) Log mode file open during system or INFOS II crash -- run IRECOVER" */
#define ISE_3853  3853  /* MSG "(IOROC) File open with read-only access during system or INFOS II crash" */
#define ISE_3854  3854  /* MSG "(IOUCR) File open to utility during system or INFOS II crash" */
#define ISE_3855  3855  /* MSG "(IOOPI) File currently open to INFOS II" */
#define ISE_3856  3856  /* MSG "(IOCDF) Differential file open during system or INFOS II crash -- run IRECOVER/DELETE" */
#define ISE_3857  3857  /* MSG "(IOCIP) Checkpoint already in progress" */
#define ISE_3858  3858  /* MSG "(IODVI) Differential volume inconsistencies; cannot restart checkpoint" */
#define ISE_3859  3859  /* MSG "(IOFNS) Database file not in standard file mode" */
#define ISE_3860  3860  /* MSG "(IOEAR) Exclusive database access required for this request" */
#define ISE_3861  3861  /* MSG "(IOCDC) Differential file crashed during checkpoint -- run IRECOVER/RESTART" */
#define ISE_3862  3862  /* MSG "(IOION) Invalid occurrence number specified" */
#define ISE_3863  3863  /* MSG "(IORLD) INFOS II request logging disabled" */
#define ISE_3864  3864  /* MSG "(IOBYE) INFOS II process shutdown" */
#define ISE_3865  3865  /* MSG "(IOINV) Invalid control message" */
#define ISE_3866  3866  /* MSG "(IOACT) INFOS II users active, termination refused" */
#define ISE_3867  3867  /* MSG "ERROR CODE RESERVED FOR FUTURE USE" */
#define ISE_3868  3868  /* MSG "ERROR CODE RESERVED FOR FUTURE USE" */
#define ISE_3869  3869  /* MSG "(IONEC) File is not in explicit checkpoint mode" */
#define ISE_3870  3870  /* MSG "(IOCCC) Cannot checkpoint until file in CC mode is closed" */
#define ISE_3871  3871  /* MSG "(IOFBD) File is being DDUMP'ed" */
#define ISE_3872  3872
#define ISE_3873  3873
#define ISE_3874  3874
#define ISE_3875  3875
#define ISE_3876  3876
#define ISE_3877  3877  /* MSG "(IODCS) Duplicate channel numbers specified" */
#define ISE_3878  3878  /* MSG "(IOTIP) TPMS transaction in progress" */
#define ISE_3879  3879  /* MSG "(IOICC) Invalid channel count" */
#define ISE_3880  3880  /* MSG "(IOITI) Invalid TPMS transaction ID" */
#define ISE_3881  3881  /* MSG "(IONOT) File(s) not open for TPMS transactions" */
#define ISE_3882  3882  /* MSG "(IOLRQ) Logging required for TPMS transactions" */
#define ISE_3883  3883  /* MSG "(IOODC) Other opens depend on this channel" */
#define ISE_3884  3884  /* MSG "(IOTTE) Maximum number of outstanding TPMS transactions exceeded" */
#define ISE_3885  3885
#define ISE_3886  3886
#define ISE_3887  3887
#define ISE_3888  3888  /* MSG "(IONPG) Caller not privileged to issue grants on this file" */
#define ISE_3889  3889  /* MSG "(IOGPN) Grantee PID is not recognized by INFOS II" */
#define ISE_3890  3890  /* MSG "(IONMG) Caller not privileged to make this grant" */
#define ISE_3891  3891
#define ISE_3892  3892
#define ISE_3893  3893
#define ISE_3894  3894
#define ISE_3895  3895
#define ISE_3896  3896  /* MSG "(IOANS) Remote access to AOS INFOS II not supported by this revision" */
#define ISE_3897  3897  /* MSG "(IOIIR) Incompatible revisions of INFOS_LS.PR with Remote server PR" */
#define ISE_3898  3898  /* MSG "(IOTNR) No response from target node" */
#define ISE_3899  3899  /* MSG "(IOIRC) Illegal remote command" */
#define ISE_3900  3900  /* MSG "(IOCRD) Cannot return data -- illegal address" */
#define ISE_3901  3901  /* MSG "(IOMRH) Reached limit of remote hosts" */
#define ISE_3902  3902  /* MSG "(IOMRC) Reached limit of channels on remote host" */
#define ISE_3903  3903  /* MSG "(IODRS) Remote surrogate terminated" */
#define ISE_3904  3904  /* MSG "(IORNR) Remote INFOS II communications process not running on remote host" */
#define ISE_3905  3905  /* MSG "(IOPNF) Remote user profile not found" */
#define ISE_3906  3906  /* MSG "(IORNA) Remote server not accepting network requests" */
#define ISE_3907  3907  /* MSG "(IOI03) Invalid INFOS II interface array" */
#define ISE_3908  3908  /* MSG "(IOI04) First element of an argument-pair is not an interface variable" */
#define ISE_3909  3909  /* MSG "(IOI05) Second element of an argument-pair is too large" */
#define ISE_3910  3910  /* MSG "(IOI06) Second element of an argument-pair not allowed to set those bits" */
#define ISE_3911  3911  /* MSG "(IOI07) IOPEN call specifies invalid number of levels" */
#define ISE_3912  3912  /* MSG "(IOI10) First element of an argument-pair not applicable to this subroutine" */
#define ISE_3913  3913  /* MSG "(IOI11) Interface calls must have at least 2 arguments (ARRAY, ERROR)" */
#define ISE_3914  3914  /* MSG "(IOI12) INFOS II interface internal consistency error" */
#define ISE_3915  3915  /* MSG "(IOI13) F77 interface call must have 'ENDLIST' to mark end of argument list" */
#define ISE_3916  3916  /* MSG "(IOI14) INFOS II interface version error -- must use latest interface" */
#define ISE_3917  3917
#define ISE_3918  3918
#define ISE_3919  3919
#define ISE_3920  3920
#define ISE_3921  3921
#define ISE_3922  3922
#define ISE_3923  3923
#define ISE_3924  3924
#define ISE_3925  3925
#define ISE_3926  3926
#define ISE_3927  3927
#define ISE_3928  3928
#define ISE_3929  3929
#define ISE_3930  3930
#define ISE_3931  3931
#define ISE_3932  3932
#define ISE_3933  3933
#define ISE_3934  3934
#define ISE_3935  3935
#define ISE_3936  3936  /* MSG "(IONSC) No service class assigned to Client" */
#define ISE_3937  3937  /* MSG "(IORSD) Remote server terminated" */
#define ISE_3938  3938  /* MSG "(IONSA) No remote Servers available" */
#define ISE_3939  3939  /* MSG "(IORCM) Remote connections are at maximum" */
#define ISE_3940  3940  /* MSG "(IOSCN) Service class not enabled for Clients and/or Servers" */
#define ISE_3941  3941  /* MSG "(IOCAS) Client or Server could not access statistics file" */
#define ISE_3942  3942
#define ISE_3943  3943
#define ISE_3944  3944
#define ISE_3945  3945
#define ISE_3946  3946
#define ISE_3947  3947
#define ISE_3948  3948
#define ISE_3949  3949
#define ISE_3950  3950
#define ISE_3951  3951
#define ISE_3952  3952
#define ISE_3953  3953
#define ISE_3954  3954
#define ISE_3955  3955
#define ISE_3956  3956
#define ISE_3957  3957
#define ISE_3958  3958
#define ISE_3959  3959
#define ISE_3960  3960
#define ISE_3961  3961
#define ISE_3962  3962
#define ISE_3963  3963
#define ISE_3964  3964
#define ISE_3965  3965
#define ISE_3966  3966
#define ISE_3967  3967
#define ISE_3968  3968  /* MSG "(IORLC) Resource lock calls are valid only within the setup section of a request group" */
#define ISE_3969  3969  /* MSG "(IOSRL) Subindex resource locked" */
#define ISE_3970  3970  /* MSG "(IOKRL) Key resource locked" */
#define ISE_3971  3971  /* MSG "(IONPR) You cannot set position on a reserve key resource lock request" */
#define ISE_3972  3972  /* MSG "(IOCOA) A channel outside your request group is positioned on the key to resource lock" */
#define ISE_3973  3973  /* MSG "(IOCDR) You cannot access the data record without an established resource lock" */
#define ISE_3974  3974  /* MSG "(IOCPR) You cannot access the partial record without an established resource lock" */
#define ISE_3975  3975  /* MSG "(IOCKR) You cannot issue that request without an established key resource lock" */
#define ISE_3976  3976  /* MSG "(IOCSR) You cannot issue that request without an established subindex resource lock" */
#define ISE_3977  3977  /* MSG "(IOKEW) A key resource lock exists within the subindex to resource lock" */
#define ISE_3978  3978  /* MSG "(IODEW) A data record resource lock exists within the subindex to resource lock" */
#define ISE_3979  3979  /* MSG "(IOPEW) A partial record resource lock exists within the subindex to resource lock" */
#define ISE_3980  3980  /* MSG "(IOCPW) A channel outside your request group is positioned within the subindex to resource lock" */
#define ISE_3981  3981  /* MSG "(IOGIP) Request group in progress" */
#define ISE_3982  3982  /* MSG "(IOGTI) Invalid request group ID" */
#define ISE_3983  3983  /* MSG "(IONOG) File(s) not open in request group mode" */
#define ISE_3984  3984  /* MSG "(IOMAR) You cannot issue a modify request prior to the modify section of a request group" */
#define ISE_3985  3985  /* MSG "(IONSF) All files must be within the same file set" */
#define ISE_3986  3986  /* MSG "(IOCIG) One of the channels specified is currently active within another request group" */
#define ISE_3987  3987  /* MSG "(IOMGE) Maximum number of outstanding request groups exceeded" */
#define ISE_3988  3988  /* MSG "(IONRL) You cannot release locks in the modify section of a request group" */
#define ISE_3989  3989  /* MSG "(IOCEM) Channel count exceeds maximum allowed" */
#define ISE_3990  3990  /* MSG "(IONFM) File is not a file set member" */
#define ISE_3991  3991  /* MSG "(IOFNM) File is not a member of this file set" */
#define ISE_3992  3992  /* MSG "(IOIFL) Specified file set does not match enabled file set" */
#define ISE_3993  3993  /* MSG "(IOFNC) File(s) need to be checkpointed" */
#define ISE_3994  3994  /* MSG "(IOSFM) Files must be in same mode(s)" */
#define ISE_3995  3995  /* MSG "(IOIFM) Invalid file mode" */
#define ISE_3996  3996  /* MSG "(IODPL) Key to position on after delete is resource locked" */
#define ISE_3997  3997  /* MSG "(IOAIM) Request group is already in modify section" */
#define ISE_3998  3998
#define ISE_3999  3999
#define ISE_4000  4000
#define ISE_4001  4001
#define ISE_4002  4002
#define ISE_4003  4003
#define ISE_4004  4004
#define ISE_4005  4005
#define ISE_4006  4006
#define ISE_4007  4007
#define ISE_4008  4008
#define ISE_4009  4009
#define ISE_4010  4010
#define ISE_4011  4011
#define ISE_4012  4012
#define ISE_4013  4013
#define ISE_4014  4014
#define ISE_4015  4015
#define ISE_4016  4016
#define ISE_4017  4017
#define ISE_4018  4018
#define ISE_4019  4019
#define ISE_4020  4020
#define ISE_4021  4021
#define ISE_4022  4022
#define ISE_4023  4023
#define ISE_4024  4024
#define ISE_4025  4025
#define ISE_4026  4026
#define ISE_4027  4027
#define ISE_4028  4028
#define ISE_4029  4029
#define ISE_4030  4030
#define ISE_4031  4031
#define ISE_4032  4032  /* MSG "(IOTID) Task ID cannot be zero" */
#define ISE_4033  4033  /* MSG "(IOIPR) Incompatible packet and runtime versions" */
#define ISE_4034  4034  /* MSG "(IOIPT) Invalid packet type" */
#define ISE_4035  4035  /* MSG "(IOBRD) Bad runtime data (probably ICALL internal data is incorrect)" */
#define ISE_4036  4036  /* MSG "(IOIPP) Illegal packet position" */
#define ISE_4037  4037  /* MSG "(IOIRN) Runtime error -- invalid ICALL ring number" */
#define ISE_4038  4038  /* MSG "(IOCLI) Cannot load lower ring INFOS II PR file" */
#define ISE_4039  4039  /* MSG "(IOCFI) Cannot find path to lower ring INFOS II PR file" */
#define ISE_4040  4040  /* MSG "(IOWNP) User runtime error -- wrong number of parameters passed to ICALL32" */
#define ISE_4041  4041  /* MSG "(IONET) Not enough tasks -- allow one additional task for lower ring INFOS II" */
#define ISE_4042  4042  /* MSG "(IOUSN) ?FUSN{.D} Username byte pointer invalid" */
#define ISE_4043  4043
#define ISE_4044  4044
#define ISE_4045  4045
#define ISE_4046  4046
#define ISE_4047  4047
#define ISE_4048  4048
#define ISE_4049  4049
#define ISE_4050  4050
#define ISE_4051  4051
#define ISE_4052  4052
#define ISE_4053  4053
#define ISE_4054  4054
#define ISE_4055  4055
#define ISE_4056  4056
#define ISE_4057  4057
#define ISE_4058  4058
#define ISE_4059  4059
#define ISE_4060  4060
#define ISE_4061  4061
#define ISE_4062  4062
#define ISE_4063  4063
#define ISE_4064  4064
#define ISE_4065  4065
#define ISE_4066  4066
#define ISE_4067  4067
#define ISE_4068  4068
#define ISE_4069  4069
#define ISE_4070  4070
#define ISE_4071  4071
#define ISE_4072  4072
#define ISE_4073  4073
#define ISE_4074  4074
#define ISE_4075  4075
#define ISE_4076  4076
#define ISE_4077  4077
#define ISE_4078  4078
#define ISE_4079  4079
#define ISE_4080  4080
#define ISE_4081  4081
#define ISE_4082  4082
#define ISE_4083  4083
#define ISE_4084  4084
#define ISE_4085  4085
#define ISE_4086  4086
#define ISE_4087  4087
#define ISE_4088  4088
#define ISE_4089  4089
#define ISE_4090  4090
#define ISE_4091  4091
#define ISE_4092  4092
#define ISE_4093  4093
#define ISE_4094  4094
#define ISE_4095  4095  /* MSG "(IONIE) Not implemented error" */
#define ISE_INFOS_END   4095

