/*  indexed.h

    Copyright (C) 1993-1995, 1999, 2003 Envyr Corporation. All rights reserved.

    Revision History:
        11/10/93 LAD ic2.00     New, from ICHOST 3.4x indexed library
        05/06/94 LAD ic2.01     Changed names from 'isam' to 'indexed'.
        08/23/95 LAD io2.12     Implemented Version 1 interface, previous
                                version supported by #define IC_API_VER_0.
        04/13/99 LAD api2.50    Implemented the 4GB big file attribute.
        11/14/03 DJP 3.40       Removed IC_API_VER_0
*/

/* Miscellaneous limitations */
#define IC_MAX_KEYS_INDEXED           17    /* Max number of keys */
#define IC_MAX_HANDLES_INDEXED        64    /* Max number of file handles */

#define IC_MAX_KEY_SIZE_INDEXED      255    /* Max size of a key */
#define IC_MAX_KEY_SUFFIXES_INDEXED    3    /* Max number of key suffixes */
#define IC_MAX_KEY_OCCURS_INDEXED     31    /* Max number of key occurs values */
#define IC_MAX_KEY_ALSOS_INDEXED       6    /* Max number of key also values */
#define IC_MAX_RECORD_SIZE_INDEXED 16384    /* Max size of a record */


/* Handle type definition */
typedef short unsigned int ic_indexed_handle_t;


/* Key specification type definition */
typedef struct {
    unsigned char
        opts,                           /* Options */
        size;                           /* Size of base value */
    unsigned char
        null,                           /* Null key value byte */
        count;                          /* Count of occurs/alsos */
    short unsigned int
        offset;                         /* Offset of base value */
    unsigned char
        reserved [2];                   /* Reserved (must be zero) */
    union {
        struct {
            short unsigned int
                span;                   /* Span between occurs elements */
            struct {
                unsigned char
                    count;              /* Count of suffixes */
                unsigned char
                    size [IC_MAX_KEY_SUFFIXES_INDEXED];     /* Sizes of suffixes */
                short unsigned int
                    offset [IC_MAX_KEY_SUFFIXES_INDEXED];   /* Offsets of suffixes */
            } suffix;
        } occurs;
        short unsigned int
            offset [IC_MAX_KEY_ALSOS_INDEXED];  /* Offsets of also key values */
    } extension;
} ic_indexed_key_spec_t;

/* Key attribute bits for use in 'ic_indexed_key_spec_t' */
#define IC_DUPL_KEY_OPT_INDEXED 0x80    /* Key index may have duplicate key values */
#define IC_UPPR_KEY_OPT_INDEXED 0x40    /* Key index is case-insensitive */
#define IC_RVRS_KEY_OPT_INDEXED 0x20    /* Key index is reverse ordered */
#define IC_NULL_KEY_OPT_INDEXED 0x10    /* Key values can be null (and null-valued keys are not inverted) */
#define IC_ALSO_KEY_OPT_INDEXED 0x08    /* Key index has also key values (in record) */


/* Indexed file specification type definition */
typedef struct {
    short unsigned int
        identifier;                     /* Specification identifier */
    unsigned char
        reserved [2];                   /* Reserved (must be zero) */
    unsigned char
        version,                        /* File version */
        attributes;                     /* Attributes */
    short unsigned int
        min_record_size,                /* Minimum record size */
        max_record_size;                /* Maximum record size */
    short unsigned int
        number_of_keys;                 /* Number of keys (including the primary) */
    ic_indexed_key_spec_t
        key [IC_MAX_KEYS_INDEXED];      /* Key specifications */
} ic_indexed_file_spec_t;

/* Above plus two counters at end */
typedef struct {
    short unsigned int
        identifier;                     /* Specification identifier */
    unsigned char
        reserved [2];                   /* Reserved (must be zero) */
    unsigned char
        version,                        /* File version */
        attributes;                     /* Attributes */
    short unsigned int
        min_record_size,                /* Minimum record size */
        max_record_size;                /* Maximum record size */
    short unsigned int
        number_of_keys;                 /* Number of keys (including the primary) */
    ic_indexed_key_spec_t
        key [IC_MAX_KEYS_INDEXED];      /* Key specifications */
    unsigned int
      record_count,
      record_del_count;
} ic_indexed_file_spec2_t;

/* Specification identifier definition */
#define IC_FILE_SPEC_ID_INDEXED  0x6930  /* Current (latest) specification id */
#define IC_FILE_SPEC_ID_INDEXED2 0x6931  /* Current (latest) specification id2 */

/* File versions
    ICOBOL INDEXED Revisions 5.09 (version == 5), 6.00 (version == 6),
    and 7.00 thru 7.11 (version == 7) are supported.
*/
#define IC_MIN_VERSION_INDEXED  5       /* Minimum file version */
#define IC_MAX_VERSION_INDEXED  7       /* Maximum file version */

/* File attribute bits for use in 'ic_indexed_file_spec_t' */
#define IC_PURGE_ATTR_SET_INDEXED   0x80    /* Purge attribute value is set */
#define IC_PURGE_ATTR_INDEXED       0x40    /* Purge attribute value (on/off) */
#define IC_4GBIG_ATTR_SET_INDEXED   0x20    /* 4GB big file attribute value is set */
#define IC_4GBIG_ATTR_INDEXED       0x10    /* 4GB big file attribute value (on/off) */


/* Null option value, used for any operation */
#define IC_NULL_OPTION_INDEXED      0x0000  /* Null option */

/* Open option bits, used for the 'open' and 'open_unspec' operations */
#define IC_OPEN_INPUT_INDEXED       0x8000  /* Input access requested */
#define IC_OPEN_OUTPUT_INDEXED      0x4000  /* Output access requested */
#define IC_OPEN_CREATE_INDEXED      0x2000  /* Create if file does not exist */
#define IC_OPEN_RECREATE_INDEXED    0x1000  /* Recreate if file does exist */
#define IC_OPEN_EXCLUSIVE_INDEXED   0x0800  /* Exclude any other access */

/* Start option values, used for the 'start' operation (mutually exclusive) */
#define IC_START_EQL_INDEXED    0x0001  /* Start at key equal */
#define IC_START_GEQ_INDEXED    0x0002  /* Start at key greater or equal */
#define IC_START_GTR_INDEXED    0x0003  /* Start at key greater */
#define IC_START_LEQ_INDEXED    0x0004  /* Start at key less or equal */
#define IC_START_LSS_INDEXED    0x0005  /* Start at key less */
#define IC_START_BEG_INDEXED    0x0006  /* Start at the beginning */
#define IC_START_END_INDEXED    0x0007  /* Start at the end */
#define IC_MIN_START_INDEXED    0x0001  /* Minimum start operation */
#define IC_MAX_START_INDEXED    0x0007  /* Maximum start operation */

/* Lock option bits, used for the 'read', 'read_next', and 'read_prev' operations */
#define IC_LOCK_SET_INDEXED     0x8000  /* Set a lock on the record being read */
#define IC_LOCK_IGNORE_INDEXED  0x4000  /* Ignore any lock on the record being read */
#define IC_LOCK_CLEAR_INDEXED   0x2000  /* Clear a lock on the record last read */

/* Update option bits, used for the 'write', and 'rewrite' operations */
#define IC_UPDATE_FILE_INDEXED  0x0800  /* Update the file after modification */


/* ind_api.h */
#ifndef _IND_API_H_
#define _IND_API_H_

/* set up definitions to control the declarations according to how it is being
  included
*/
#ifdef ICWIN32
#ifdef ICINDLL
#define ICDECLSPEC  __declspec (dllexport)
#define ICEXTERN
#else
#define ICDECLSPEC  __declspec (dllimport)
#define ICEXTERN    extern
#endif
#else
#define ICDECLSPEC
#define ICEXTERN    extern
#endif

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_init_indexed (void);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_term_indexed (void);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_delete_file_indexed (char *filename_ptr);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_open_indexed (char *filename_ptr,
                                short unsigned int open_options,
                                ic_indexed_file_spec_t *indexed_file_spec_ptr,
                                ic_indexed_handle_t *handle_ptr);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_open_void_indexed (char *filename_ptr,
                                short unsigned int open_options,
                                ic_indexed_file_spec_t *indexed_file_spec_ptr,
                                ic_indexed_handle_t *handle_ptr);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_close_indexed (ic_indexed_handle_t handle);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_update_indexed (ic_indexed_handle_t handle);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_start_indexed (ic_indexed_handle_t handle,
                                short unsigned int start_options,
                                short unsigned int key_number,
                                unsigned char *key_ptr,
                                short unsigned int key_size);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_unlock_indexed (ic_indexed_handle_t handle);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_delete_key_indexed (ic_indexed_handle_t handle,
                                unsigned char *key_ptr,
                                short unsigned int key_size);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_read_next_indexed (ic_indexed_handle_t handle,
                                unsigned char *record_ptr,
                                short unsigned int *record_size_ptr,
                                short unsigned int read_options);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_read_next_keyto_indexed (ic_indexed_handle_t handle,
                                unsigned char *record_ptr,
                                short unsigned int *record_size_ptr,
                                short unsigned int read_options,
                                unsigned char *keyto_ptr,
                                short unsigned int *keyto_size_ptr);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_read_prev_indexed (ic_indexed_handle_t handle,
                                unsigned char *record_ptr,
                                short unsigned int *record_size_ptr,
                                short unsigned int read_options);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_read_prev_keyto_indexed (ic_indexed_handle_t handle,
                                unsigned char *record_ptr,
                                short unsigned int *record_size_ptr,
                                short unsigned int read_options,
                                unsigned char *keyto_ptr,
                                short unsigned int *keyto_size_ptr);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_read_key_indexed (ic_indexed_handle_t handle,
                                short unsigned int key_number,
                                unsigned char *key_ptr,
                                short unsigned int key_size,
                                unsigned char *record_ptr,
                                short unsigned int *record_size_ptr,
                                short unsigned int read_options);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_write_indexed (ic_indexed_handle_t handle,
                                unsigned char *record_ptr,
                                short unsigned int record_size,
                                short unsigned int write_options);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_rewrite_indexed (ic_indexed_handle_t handle,
                                unsigned char *record_ptr,
                                short unsigned int record_size,
                                short unsigned int rewrite_options);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_get_records_indexed (ic_indexed_handle_t handle,
                                unsigned int *record_cnt_ptr);

ICEXTERN ic_api_status_t ICDECLSPEC ICSTDCALL ic_get_delrecords_indexed (ic_indexed_handle_t handle,
                                unsigned int *record_cnt_ptr);


#endif

