/*  status.h

    Copyright (C) 1994, 1995,  Envyr Corporation.  All rights reserved.

    Revision History:
        ic2.10
            08/03/94    JMB     New.
        io2.12
            08/23/95    LAD     Implemented Version 1 interface, previous
                                version supported by #define IC_API_VER_0.
*/

/* standard exit code definitions */
#define EXIT_OK         0               /* everything is OK */
#define EXIT_JOB_ERR    1               /* processing had errors */
#define EXIT_JOB_INT    2               /* processing was interrupted or aborted */
#define EXIT_JOB_FATAL  3               /* processing was halted by fatal internal error */
#define EXIT_CMD_ERR    4               /* command-line errors prevented running */
#define EXIT_AUTH_ERR   5               /* authorization failure prevented running */
#define EXIT_INIT_ERR   6               /* program initialization errors prevented running */
#define EXIT_CMD_HELP   7               /* request for command-line help prevented running */

/* standard error handling definitions
    A zero return values means no error occurred
    A positive return value means an error occurred
    A negative return value means the operation was ok, but a status
        code is being returned.
    The success and failure macros can be used to test function results.
    The status code itself is divided into an operating system error
        number, severity level, group and message number fields, which may be
        extracted with the get_oserr, get_sevnum, get_grpnum, and get_msgnum
        macros respectively.  The complete error code (group and message
        number fields) value may also be extracted with the get_errnum macro.
    Note that get_errnum must be used to compare a status code to any
        particular error code defined below, otherwise values in the other
        fields may cause the comparison to inappropriately fail.
*/

#define success(a)      ((a)<=0)        /* true if status indicates success */
#define failure(a)      ((a)>0)         /* true if status indicates faulure */
#define has_info(a)     ((a)<0)         /* true if status has information only */

typedef int status_t;

#define SE_INFO_BIT     0x80000000      /* set sign bit for info */
#define SE_INFO_MASK    0x7FFFFFFF      /* mask all but info indicator */

#define se_get_oserr(s)    ((unsigned int)(((s)&0x7FFF0000)>>16))
#define se_get_sevnum(s)   ((unsigned int)(((s)&0x00007000)>>12))
#define se_get_grpnum(s)   ((unsigned int)(((s)&0x00000E00)>>9))
#define se_get_msgnum(s)   ((unsigned int)((s)&0x000001FF))
#define se_get_errnum(s)   ((unsigned int)((s)&0x00007FFF))


/*  api_defs.h

    Copyright (C) 1995, 1998, 2003 Envry Corporation. All rights reserved.

    Revision History:
        08/23/95 LAD io2.12     New.
        07/08/98 DJP api2.43    Dual syscall and stdcall support
        11/14/03 DJP 3.40       Removed VER_0 defs
*/

/* Status code type definition */
typedef status_t ic_api_status_t;

/* if calling interface was not defined (on command line), use default */
#ifdef ICWIN32
#ifdef ICSTDAPI
/* win32/new stdcall conventions */
#define ICSTDCALL   __stdcall
#define IQSTDCALL   FAR PASCAL
#else
/* win32/old syscall conventions */
#define ICSTDCALL
#define IQSTDCALL   FAR PASCAL
#endif
#else
#define ICSTDCALL
#define IQSTDCALL
#endif

/* SYSERRS.H  - system error code definitions

    Copyright (C) 1987-2006, 2008 Envyr Corporation.
    All rights reserved.

    This file encompasses the message codes used by the base system
    (icsys.dll/.so) and the utilities (SE_xxx and UE_xxx) and is which
    is compiled into icsys.dll/.so.

    NOTE: As of 3.40, a number of the network errors are also used by UNIX

    NOTE: As of 3.60, this file is processed by h2c to build a compiled message
          array for builtin messages and is also shipped for use by icmakems
          to build customized message text in a .ms file, and for use by
          the C API.
          As a result, the #defines are limited to simple aliases or equates
          to a numeric value.
          If the define is of the form #define <name> <number> <comment>
          and <comment> starts with MSG, it is taken as a message definition,
          with the message text as a quoted string (C conventions).

    NOTE: From 4.02 to 4.03 the messages were rearranged so that any rev4
          messages with a counterpart in rev3 have the same error number
          in rev4 as it had in rev3 (especially in the UE range).  Some of the
          error numbers can be passed between rev3 and rev4 in client-server
          and icpermit scenarios so this helps get the correct error
          handling and message text on both ends.

    NOTE WELL:
          When customizing message text, only the text should be changed,
          never the numeric value of the message.  The customized messages
          will be in a file named syserrs.ms.
*/

/****************************************************************/
/*                                                              */
/*    system error group (SE_xxx) - 0-511                       */
/*                                                              */
/****************************************************************/

#define SE_MIN_ERROR            0       /* minimum allowable system error number */

/* no error - must be value 0 */
#define SE_NO_ERR               0       /* MSG "No error" */

/* Error messages for DOS 2.00/2.10 INT 21H Errors (1 - 18) */
#define SE_INV_OPER             1       /* MSG "Invalid operation" */
#define SE_F_NOT_FND            2       /* MSG "The file was not found" */
#define SE_P_NOT_FND            3       /* MSG "The path was not found" */
#define SE_NO_HANDLES           4       /* MSG "There are no more handles available" */
#define SE_ACCESS               5       /* MSG "Access to the file or device is denied" */
#define SE_INV_HANDLE           6       /* MSG "Invalid handle" */
#define SE_MEM_CTRL             7       /* MSG "Memory control blocks are bad" */
#define SE_NO_MEMORY            8       /* MSG "Insufficient memory" */
#define SE_INV_MEM_ADDR         9       /* MSG "Invalid memory control block address" */
#define SE_INV_ENV              10      /* MSG "Invalid environment" */
#define SE_INV_FORMAT           11      /* MSG "Invalid format" */
#define SE_INV_ACC_CODE         12      /* MSG "Invalid access code" */
#define SE_INV_DATA             13      /* MSG "Invalid data" */
#define SE_OUTOFMEMORY          14      /* MSG "Insufficient memory to complete this operation" */
#define SE_INV_DRIVE            15      /* MSG "Invalid drive specifier" */
#define SE_REMV_DRIVE           16      /* MSG "Attempt to remove the current directory" */
#define SE_NOT_SAME_DEV         17      /* MSG "Not the same device" */
#define SE_NO_FILES             18      /* MSG "No more files are available" */

/* Error messages for DOS 2.00/2.10 INT 24H (Critical) Errors (19 - 31) */
#define SE_WRITE_PROT           19      /* MSG "Write protected disk" */
#define SE_UNKNOWN_UNIT         20      /* MSG "Unknown hardware unit" */
#define SE_NOT_READY            21      /* MSG "Drive is not ready" */
#define SE_UNKNOWN_CMD          22      /* MSG "Unknown hardware command for device" */
#define SE_CRC_ERROR            23      /* MSG "CRC error in data" */
#define SE_BAD_REQUEST          24      /* MSG "Hardware drive request is bad" */
#define SE_SEEK_ERROR           25      /* MSG "Disk seek error" */
#define SE_UNKNOWN_TYPE         26      /* MSG "Unknown disk media type" */
#define SE_SECTOR_ERROR         27      /* MSG "Sector not found error" */
#define SE_PAPER_ERROR          28      /* MSG "Printer out of paper" */
#define SE_WRITE_FAULT          29      /* MSG "Write fault" */
#define SE_READ_FAULT           30      /* MSG "Read fault" */
#define SE_FAILURE              31      /* MSG "General failure" */

#define MAX_DOS_ERROR           31

/* Error messages for icobol specific errors (32 - 199) */
#define SE_EXISTS               32      /* MSG "The file already exists" */
#define SE_EXCL_OPEN            33      /* MSG "The file is exclusively opened" */
#define SE_FILE_SIZE            34      /* MSG "The file size is too big" */
#define SE_OPEN                 35      /* MSG "Attempt to exclusively open an open file" */
#define SE_ILL_NAME             36      /* MSG "The filename is not valid" */
#define SE_EOF                  37      /* MSG "End of file" */
#define SE_INV_REL_KEY_REV3_    38      /* MSG "Invalid relative key (from rev3)" */
#define SE_SPACE                39      /* MSG "Out of (disk) space" */
#define SE_RDL_LEN              40      /* MSG "Readline argument is too long" */
#define SE_IS_OPEN              41      /* MSG "Attempt to open an open file" */
#define SE_IS_CLOSED            42      /* MSG "Attempt to close a closed file" */
#define SE_LOCKED               43      /* MSG "Attempt to open locked file" */
#define SE_PASS_FULL            44      /* MSG "Printer control table is full" */
#define SE_ILL_OPER             45      /* MSG "Invalid operation for open mode" */
#define SE_HANDLE_NOT_OPEN      46      /* MSG "Handle is not open" */
#define SE_DELETE_OPEN          47      /* MSG "Attempt to delete an open file" */
#define SE_RECORD_AREA_SIZE     48      /* MSG "Record area size too small for record" */
#define SE_REWRITE_SIZE         49      /* MSG "Record size mismatch on rewrite" */
#define SE_RECORD_TOO_LONG      50      /* MSG "Record is too long" */
#define SE_TOO_MANY_KEYS        51      /* MSG "Too many keys requested" */
#define SE_INV_KEY_PACKET       52      /* MSG "Invalid key packet length" */
#define SE_KEY_TOO_LONG         53      /* MSG "Key is too long" */
#define SE_KEY_NOT_IN_RECORD    54      /* MSG "Invalid key definition (not in record)" */
#define SE_RECORD_SIZE          55      /* MSG "Record size mismatched on open" */
#define SE_NUMBER_OF_KEYS       56      /* MSG "Number of keys mismatched on open" */
#define SE_KEY_SIZE             57      /* MSG "Key size mismatch on open" */
#define SE_KEY_OFFSET           58      /* MSG "Key offset mismatch on open" */
#define SE_INV_NX_VERSION       59      /* MSG "NX file version is not valid" */
#define SE_INV_XD_VERSION       60      /* MSG "XD file version is not valid" */
#define SE_NO_LOCKS             61      /* MSG "Out of record locks" */
#define SE_LOCKED_RECORD        62      /* MSG "Record is locked" */
#define SE_INV_CRP              63      /* MSG "No valid current record pointer has been established" */
#define SE_DELETED_RECORD       64      /* MSG "Record is deleted" */
#define SE_NOT_DELETED_RECORD   65      /* MSG "Record is not deleted" */
#define SE_NOT_REWRITE_CRP      66      /* MSG "Not rewriting the current record" */
#define SE_KEY_NOT_FND          67      /* MSG "Key not found" */
#define SE_DUPLICATE_KEY        68      /* MSG "Attempt to write a duplicate key" */
#define SE_NX_BTREES_FULL       69      /* MSG "NX file B-tree is full" */
#define SE_NOT_WRITE_SEQ        70      /* MSG "Not writing in ascending order" */
#define SE_INV_NX_CONTENT       71      /* MSG "The NX file is corrupt" */
#define SE_INV_XD_CONTENT       72      /* MSG "The XD file is corrupt" */
#define SE_NX_UNRELIABLE        73      /* MSG "Reliability flag indicates the NX file may be corrupt" */
#define SE_XD_UNRELIABLE        74      /* MSG "Reliability flag indicates the XD file may be corrupt" */
#define SE_RENAME_OPEN          75      /* MSG "Attempt to rename an open file" */
#define SE_TIMEOUT              76      /* MSG "Device timeout" */
#define SE_IO_ERROR             77      /* MSG "Device i/o error" */
#define SE_OFFLINE_REV3_        78      /* MSG "Printer is offline (from rev3)" */
#define SE_PAPER_OUT_REV3_      79      /* MSG "Printer is out of paper (from rev3)" */
#define SE_IO_BREAK             80      /* MSG "I/O operation aborted by console interrupt" */
#define SE_NO_DEVICE            81      /* MSG "Device is not available or does not exist" */
#define SE_INV_FILE             82      /* MSG "The file format is not valid" */
#define SE_BAD_REV              83      /* MSG "The file does not have the correct revision" */
#define SE_RECSIZE_ZERO         84      /* MSG "Record size is zero" */
#define SE_RECPOS_TOO_SMALL     85      /* MSG "Record position is too small" */
#define SE_RECPOS_NOT_ALIGNED   86      /* MSG "Record position is not aligned" */
#define SE_RECPOS_TOO_BIG       87      /* MSG "Record position is too big" */
#define SE_RECPOS_PAST_EOF      88      /* MSG "Record position is past EOF" */
#define SE_NODE_NOT_ZERO        89      /* MSG "Node block number is not zero" */
#define SE_NODE_ZERO            90      /* MSG "Node block number is zero" */
#define SE_NODE_TOO_BIG         91      /* MSG "Node block number is too big" */
#define SE_DUPLICATES_OK        92      /* MSG "Duplicates are permitted" */
#define SE_DUPLICATES_NOT_OK    93      /* MSG "Duplicates are not permitted" */
#define SE_KEYSIZE_ZERO         94      /* MSG "Key size is zero" */
#define SE_NODE_PAST_EOF        95      /* MSG "Node block number is past EOF" */
#define SE_XD_SIZE_TOO_SMALL    96      /* MSG "XD file size is too small" */
#define SE_NX_SIZE_TOO_SMALL    97      /* MSG "NX file size is too small" */
#define SE_KEY_DELETED          98      /* MSG "Key entry is deleted" */
#define SE_RECPOS_MISMATCH      99      /* MSG "Record position does not match" */
#define SE_VERSION_MISMATCH     100     /* MSG "File version does not match" */
#define SE_NODE_INVALID         101     /* MSG "Node block number is inconsistent" */
#define SE_NODE_COUNT_ZERO      102     /* MSG "Node entry count is zero" */
#define SE_NODE_COUNT_TOO_BIG   103     /* MSG "Node entry count is too big" */
#define SE_NODE_COUNT_FULL      104     /* MSG "Node entry count is the maximum" */
#define SE_NODE_LEVEL_INVALID   105     /* MSG "Node level is inconsistent" */
#define SE_NODE_PATH_INVALID    106     /* MSG "Node key number is inconsistent" */
#define SE_NODE_LEAF_INVALID    107     /* MSG "Node leaf indicator is inconsistent" */
#define SE_NOT_NODE_ALIGNED     108     /* MSG "Position is not aligned on a node boundary" */
#define SE_RELATIVE_KEY         109     /* MSG "Relative key value is inconsistent" */
#define SE_KEY_INVALID          110     /* MSG "Key value is inconsistent" */
#define SE_NOT_UNRELIABLE       111     /* MSG "Reliability flag(s) have been cleared" */
#define SE_BUF_USE_PANIC        112     /* MSG "Internal error - invalid use of buffer manager" */
#define SE_RELEASE_BUF_PANIC    113     /* MSG "Attempt to release buffer not in use" */
#define SE_NO_BUFS_PANIC        114     /* MSG "No buffers were available" */
#define SE_DESTROY_BUF_PANIC    115     /* MSG "Attempt to destroy buffer still in use" */
#define SE_OBJECT_IN_USE        116     /* MSG "The object definition is in use (internal error)" */
#define SE_NO_FILE_OPENS        117     /* MSG "No more files may be OPENed" */
#define SE_NO_OPEN_RESOURCES    118     /* MSG "No more OPEN resources are available" */
#define SE_NO_SEQUENTIAL        119     /* MSG "No more SEQUENTIAL files may be OPENed" */
#define SE_NO_RELATIVE          120     /* MSG "No more RELATIVE files may be OPENed" */
#define SE_NO_INDEXED           121     /* MSG "No more INDEXED files may be OPENed" */
#define SE_DATA_CARRIER_LOST    122     /* MSG "Data carrier signal (CD) has been lost on a MODEM line" */
#define SE_OBJECT_NOT_REG       123     /* MSG "The requested object definition is not registered (internal error)" */
#define SE_PATH_NOT_DIR         124     /* MSG "The path does not specify a directory" */
#define SE_IO_WATCH_INT         125     /* MSG "I/O aborted by WATCH interrupt" */
#define SE_WATCH_MISMATCH       126     /* MSG "This terminal has fewer lines/cols than the selected terminal" */
#define SE_OBJECT_MISMATCH      127     /* MSG "The object does not match the expected object type (internal error)" */
#define SE_INTS_DISABLED        128     /* MSG "Console interrupts are disabled" */
#define SE_DUMP_INT             129     /* MSG "Aborted by DUMP interrupt" */
#define SE_OBJECT_NULL          130     /* MSG "Object handle or index entry is NULL (internal error)" */
#define SE_NO_DATA              131     /* MSG "No data is available" */
#define SE_ILL_TYPE             132     /* MSG "Named item is the wrong type to perform this operation" */
#define SE_ILL_PARMSTR          133     /* MSG "The parameter string is not valid for this object" */
#define SE_BAD_INI_STD_HDR      134     /* MSG "File's standard header information is bad (ini)" */
#define SE_NO_RESOURCE_REV3_    135     /* MSG "Out of system resources for request (from rev3)" */
#define SE_INT_ERROR            136     /* MSG "Internal system error" */
#define SE_INV_ARG              137     /* MSG "Invalid argument to system call" */
#define SE_NOT_REMOTE           138     /* MSG "A remote computer can not be specified for this operation" */
#define SE_WRITE_DUPLICATE      139     /* MSG "A duplicate key value has been written" */
#define SE_READ_DUPLICATE       140     /* MSG "A duplicate key value has been read" */
#define SE_BAD_VALIDITY         141     /* MSG "File standard header or data packet header is not valid" */
#define SE_BAD_CHECKSUM         142     /* MSG "File standard header or data packet checksum is bad" */
#define SE_BAD_FILE_TYPE        143     /* MSG "File type does not match required type" */
#define SE_BAD_FILE_HDR         144     /* MSG "File header length, offset, or checksum is bad" */
#define SE_BAD_BYTE_ORDER       145     /* MSG "File has wrong byte order" */
#define SE_KEY_DUPLICATES       146     /* MSG "Key with duplicates specification does not match" */
#define SE_ISAM_FORMAT          147     /* MSG "ISAM file format does not match" */
#define SE_ISAM_VERSION         148     /* MSG "ISAM file version does not match" */
#define SE_NX_XD_MISMATCH       149     /* MSG "The .NX and .XD files are not properly paired" */
#define SE_DELETE_PURGES        150     /* MSG "Purge deleted records mismatch on open" */
#define SE_KEY_NULL_SUPPRESS    151     /* MSG "Key null value suppression specification does not match" */
#define SE_KEY_CONVERT_UPPER    152     /* MSG "Key uppercase conversion specification does not match" */
#define SE_FILE_CREATED         153     /* MSG "The optional file was created" */
#define SE_OPT_NOT_AVAIL        154     /* MSG "The optional file is not available" */
#define SE_ILL_OPER_INPUT       155     /* MSG "Invalid operation for file without input access" */
#define SE_ILL_OPER_OUTPUT      156     /* MSG "Invalid operation for a file without output access" */
#define SE_ILL_OPER_IO          157     /* MSG "Invalid operation for a file without input-output access" */
#define SE_SEQ_DELETE_REWRITE   158     /* MSG "DELETE or REWRITE was not preceded by a successful READ" */
#define SE_NX_XD_INCONSISTENT   159     /* MSG "The header information from the .nx and .xd files is not consistent" */
#define SE_SM_IN_USE            160     /* MSG "A Sort or Merge operation is already active" */
#define SE_READ_SEQ_UNAVAIL     161     /* MSG "Optional file was unavailable for sequential READ" */
#define SE_READ_START_UNAVAIL   162     /* MSG "Optional file was unavailable for random READ or START" */
#define SE_READ_REL_KEY_SIZE    163     /* MSG "The relative key value exceeds the size of the relative key on READ" */
#define SE_WRITE_REL_KEY_SIZE   164     /* MSG "The relative key value exceeds the size of the relative key on WRITE" */
#define SE_NOT_PAGE_ALIGNED     165     /* MSG "Position is not aligned on a shared page boundary" */
#define SE_UNMODIFIABLE_KEY     166     /* MSG "Attempt to modify an unmodifiable key" */
#define SE_RECORD_CONFLICT      167     /* MSG "Attempt to rewrite a record which has been modified since it was read" */
#define SE_DEADLOCK_DETECTED    168     /* MSG "Attempt to perform an operation which would lead to a deadlock situation" */
#define SE_INV_RECLEN_HDR       169     /* MSG "Invalid record length value in record header" */
#define SE_KEY_TOO_MANY_OCCUR   170     /* MSG "Too many key occurs requested" */
#define SE_KEY_TOO_MANY_SUFFIX  171     /* MSG "Too many key suffixes requested" */
#define SE_KEY_TOO_MANY_ALSO    172     /* MSG "Too many key alsos requested" */
#define SE_KEY_OCCURS_ALSO      173     /* MSG "Key occurs/also specification does not match" */
#define SE_KEY_OCCURS_COUNT     174     /* MSG "Key occurs/also count specification does not match" */
#define SE_KEY_OCCURS_SPAN      175     /* MSG "Key occurs span specification does not match" */
#define SE_KEY_SUFFIX_COUNT     176     /* MSG "Key suffix count specification does not match" */
#define SE_KEY_REVERSE_ORDER    177     /* MSG "Key reverse order specification does not match" */
#define SE_ISAM_LOG_MISMATCH    178     /* MSG "The .XL and .XD files are not properly paired" */
#define SE_LOG_POSN_MISMATCH    179     /* MSG "The .XL operation is not in sequence" */
#define SE_ILL_OPEN_OPTS        180     /* MSG "Invalid combination of open options" */
#define SE_INV_NET_PKT          181     /* MSG "An invalid or corrupted network packet was received" */
#define SE_INV_DATA_VALUE       182     /* MSG "Data value is not a valid data-type-value" */
#define SE_INV_DATA_AREA        183     /* MSG "Data does not fit in the data area provided" */
#define SE_FILE_SIZE_MAX_4GB    184     /* MSG "4GB maximum file size specification does not match" */
#define SE_WRITE_RELEASE_SIZE   185     /* MSG "Record size specified exceeds the maximum or is less than the minimum for the file" */
#define SE_PREAMBLE             186     /* MSG "*ERROR: " */
#define SE_CONVERT              187     /* MSG "Conversion error (index register overflow)" */
#define SE_INX_RANGE            188     /* MSG "An index is out of range" */
#define SE_PERF_CNT             189     /* MSG "The perform count is too large" */
#define SE_PERF_OVRFL           190     /* MSG "The perform stack has overflowed" */
#define SE_FATAL_IO             191     /* MSG "Fatal I/O error" */
#define SE_READ_LENGTH          192     /* MSG "Length of record read does not conform to that specified for the file" */
#define SE_OPER_INT             193     /* MSG "The program was terminated by a console interrupt" */
#define SE_STOP_RUN             194     /* MSG " ** stop run **" */
#define SE_FATAL_RT             195     /* MSG "Fatal Runtime System Error" */
#define SE_INV_OPCODE           196     /* MSG "Fatal Runtime System Error: invalid operation code" */
#define SE_LOGON                197     /* MSG "The system is ready.  Press Newline to begin LOGON" */
#define SE_UNAVAILABLE          198     /* MSG "The system is currently unavailable" */
#define SE_ABORT                199     /* MSG "The program was terminated by another console" */

/* DG ICOBOL CALL compatible sta(tus codes (200 - 214) */
#define SE_ILL_PGM_SIZE         200     /* MSG "program is too big" */
#define SE_DG_RESERVED_201      201     /* MSG "(not used) program has invalid revision" */
#define SE_INV_PGM              202     /* MSG "not a valid program file" */
#define SE_PGM_NOT_FND          203     /* MSG "the program was not found" */
#define SE_DG_RESERVED_204      204     /* MSG "(not used) the program could not be loaded" */
#define SE_DG_RESERVED_205      205     /* MSG "(not used) error processing using" */
#define SE_DG_RESERVED_206      206     /* MSG "(not used) the program could not be accessed" */
#define SE_PGM_IS_ACTIVE        207     /* MSG "program is active" */
#define SE_CALL_TOO_MANY        208     /* MSG "attempt to call too many pgms" */
#define SE_PARM_MISMATCH        209     /* MSG "parameter mismatch in call" */
#define SE_DG_RESERVED_210      210     /* MSG "(not used) out of VM space" */
#define SE_DG_RESERVED_211      211     /* MSG "(not used) out of handles during call" */
#define SE_NO_PGM_TASKS         212     /* MSG "no tasks available for #O" */
#define SE_PGM_LOAD_ERROR       213     /* MSG "program file cannot be loaded" */
#define SE_DG_RESERVED_214      214     /* MSG "(not used) error processing VM file" */

/* More error messages (215 - 255) */
#define SE_PGM_DISABLED         215     /* MSG "The program has been disabled" */
#define SE_IO_WAKEUP_INT        216     /* MSG "I/O aborted by Wakeup Interrupt" */
#define SE_TRANSITION_NOT_SUPP  217     /* MSG "Transition logging is not suported - use iclog to disable" */
#define SE_REV1_LOG_NOT_SUPP    218     /* MSG "Revision 1 logging is not supported - use iclog to disable or upgrade file" */
#define SE_INV_TASK             219     /* MSG "Invalid task number" */
#define SE_NO_ENTRIES           220     /* MSG "There are no more entries in the table" */
#define SE_PERMISSION           221     /* MSG "This operation is not permitted" */
#define SE_IN_USE               222     /* MSG "The item is currently in use" */
#define SE_REMOVED              223     /* MSG "The item was removed" */
#define SE_PAGE_ERROR           224     /* MSG "The requested page is not in the file" */
#define SE_CANCELLED            225     /* MSG "The operation was cancelled by the user" */
#define SE_REMOTE_NEEDS_SYNC    226     /* MSG "Remote log status indicates ICLOG Fixup required" */
#define SE_MIRROR_NEEDS_SYNC    227     /* MSG "Mirror status indicates ICLOG Fixup required" */
#define SE_TERM_NOT_ACTIVE      228     /* MSG "The terminal is not logged on" */
#define SE_NO_SUCH_TERM         229     /* MSG "The terminal is not configured into the system" */
#define SE_FEATURE_UNAVAILABLE  230     /* MSG "The requested feature is not available" */
#define SE_UNS_FEATURE_TERM     231     /* MSG "Unsupported feature for the current terminal type" */
#define SE_REM_MIR_NOT_OPENED   232     /* MSG "Remote log or Mirror was not opened" */
#define SE_LOGON_TYPE_FAILURE   233     /* MSG "The user has not been granted the requested logon type at this computer." */
#define SE_ABORT_CFRM           234     /* MSG "The abort request was sent to terminal" */
#define SE_SEND_CFRM            235     /* MSG "The message was sent to terminal" */
#define SE_MAX_LOGON            236     /* MSG "The maximum number of terminals are already in use" */
#define SE_ILL_OPT              237     /* MSG "The option is not a valid option" */
#define SE_SHLIB_ERROR          238     /* MSG "Shared Library load error (no more information available)" */
#define SE_PROC_INIT_ERROR      239     /* MSG "Process initialization error" */
#define SE_ARG_EXP              240     /* MSG "The option requires an argument" */
#define SE_ARG_LEN              241     /* MSG "The argument is too long to process" */
#define SE_OPT_END              242     /* MSG "There are no more options to process" */
#define SE_AGAIN                243     /* MSG "Out of processes or system resources, or no data available" */
#define SE_SHM_ERROR            244     /* MSG "Shared Memory initialization error" */
#define SE_SHM_REV              245     /* MSG "The shared area revision does not match" */
#define SE_SHM_ENABLE           246     /* MSG "The shared area is not enabled for use" */
#define SE_247                  247
#define SE_NO_PROCS             248     /* MSG "No more processes can be run" */
#define SE_249                  249
#define SE_ICEXEC_REQUIRED      250     /* MSG "The Shared Resource Executive Agent (icexec) is required" */
#define SE_QUIT                 251     /* MSG "Process termination (Quit/Logoff)" */
#define SE_NOT_AUTHORIZED       252     /* MSG "This program is not authorized to run" */
#define SE_HANGUP               253     /* MSG "Process termination (Modem Hangup)" */
#define SE_ABORT_TIMEOUT        254     /* MSG "Process termination (Global Timeout)" */
#define SE_TERMINATE            255     /* MSG "Process termination (Shutdown)" */

/* NOTE: dos errors were remapped by adding 256 if > 31, so we could use the
         extended error area from 256-287 for other messages
*/

#define SE_SUPERUSER            256     /* MSG "Super user privileges are required" */
#define SE_DETACH               257     /* MSG "Detaching from login session context" */
#define SE_DETACHED             258     /* MSG "Detached from login session context" */
#define SE_ICEXEC_ABNORMAL      259     /* MSG "icexec was abnormally terminated" */
#define SE_SEC_NOT_FND          260     /* MSG "The (.ini) file section or value was not found" */
#define SE_OPEN_STDIN           261     /* MSG "Unable to initialize standard input file" */
#define SE_OPEN_STDOUT          262     /* MSG "Unable to initialize standard output file" */
#define SE_OPEN_STDERR          263     /* MSG "Unable to initialize standard error file" */
#define SE_INV_STDIO_TYPE       264     /* MSG "Invalid type for stdio file" */
#define SE_LOCK_OPEN_SEM        265     /* MSG "Locking Open/Close semaphore" */
#define SE_BAD_TERMINFO         266     /* MSG "Unknown terminal type from terminfo" */
#define SE_KBD_TBL              267     /* MSG "Terminal Description Keyboard Table" */
#define SE_UNS_SCRN_TYPE        268     /* MSG "Unsupported terminal type" */
#define SE_SCRN_TBL             269     /* MSG "Screen Control Area" */
#define SE_TOO_MANY_PATH        270     /* MSG "Too many directories in path list" */
#define SE_MALLOC_PATH_NAME     271     /* MSG "Insufficient memory for pathlist names" */
#define SE_TOO_MANY_LIBS        272     /* MSG "Too many libraries have been requested" */
#define SE_INV_ENV_ARG          273     /* MSG "The environment argument is not valid" */
#define SE_MISSING_ENV          274     /* MSG "The following environment argument was not present (default value used):" */
#define SE_USING_DEFAULT        275     /* MSG "Using default" */
#define SE_PDF_UNAVAIL          276     /* MSG "The PDF writing facility is not available" */
#define SE_NO_PDF_DESC          277     /* MSG "The requested PDF format descriptor is not configured or not enabled" */
#define SE_NET_PKT_REV          278     /* MSG "The required network packet format revision is not supported" */
#define SE_NET_REQ_REV          279     /* MSG "The required network command revision level is not supported" */
#define SE_PDF_FORM_ERRS        280     /* MSG "The required form for PDF writing had errors" */
#define SE_PDF_FORM_UNIMPL_ITEM 281     /* MSG "The background form uses features that are not implemented yet" */
#define SE_PDF_FORM_FILE_ERROR  282     /* MSG "The background form reader encountered unexpected errors with the file format" */
#define SE_PDF_UNSUPPORTED      283     /* MSG "The background form has attribute values that are not supported." */
#define SE_IC2X_REQUIRED        284     /* MSG "The IC2X option is needed to run this program" */
#define SE_285                  285
#define SE_286                  286
#define SE_287                  287

/* NOTE: Errors 288-355 were remapped for DOS 3.00 to 3.30 error by adding 256 if > 31.
         They are now handled with a table lookup; however, we still can't move these
         because some are passed by icnetd and must remain compatible with older revisions.
*/

#define SE_SHARE_VIOLATION      288     /* MSG "File sharing violation" */
#define SE_LOCK_VIOLATION       289     /* MSG "File lock violation " */
#define SE_INV_DISK_CHANGE      290     /* MSG "(unused) Invalid disk change" */
#define SE_FCB_UNAVAILABLE      291     /* MSG "(unused) FCB unavailable" */
#define SE_SHARE_BUFF_OVER      292     /* MSG "(unused) Sharing buffer overflow" */
#define SE_DOS_RESERVED_37      293
#define SE_NO_MORE_INPUT        294     /* MSG "(unused) Out of input" */
#define SE_NO_DISK_SPACE        295     /* MSG "Disk quota exceeded" */
#define SE_DOS_RESERVED_40      296
#define SE_DOS_RESERVED_41      297
#define SE_DOS_RESERVED_42      298
#define SE_DOS_RESERVED_43      299
#define SE_DOS_RESERVED_44      300
#define SE_DOS_RESERVED_45      301
#define SE_DOS_RESERVED_46      302
#define SE_DOS_RESERVED_47      303
#define SE_DOS_RESERVED_48      304
#define SE_DOS_RESERVED_49      305
#define SE_NET_REQ_NO_SUPPORT   306     /* MSG "The request is not supported" */
#define SE_REMOTE_NOT_LISTED    307     /* MSG "The network path cannot be found " */
#define SE_DUPLICATE_NET_NAME   308     /* MSG "Duplicate name on network" */
#define SE_NET_NAME_NOT_FND1    309     /* MSG "Network name not found or remote login failed" */
#define SE_NET_BUSY             310     /* MSG "The network is busy" */
#define SE_NET_DEVICE_GONE      311     /* MSG "Network device is no longer available" */
#define SE_NET_COMMAND_LIMIT    312     /* MSG "(unused) Net BIOS command limit exceeded" */
#define SE_NET_HARD_ERROR       313     /* MSG "A network adapter hardware error occurred" */
#define SE_NET_BAD_RESPONSE     314     /* MSG "Incorrect response from network" */
#define SE_NET_ERR_UNEXPECTED   315     /* MSG "Unexpected network error" */
#define SE_ADAPT_INCOMPAT       316     /* MSG "(unused) Incompatible remote adaptor" */
#define SE_PRINT_QUEUE_FULL     317     /* MSG "(unused) Print queue full" */
#define SE_PRINT_NO_SPACE       318     /* MSG "(unused) Not enough space for print file" */
#define SE_PRINT_DELETED        319     /* MSG "(unused) Print file was deleted" */
#define SE_NET_NAME_DELETED     320     /* MSG "Network name was deleted" */
#define SE_ACCESS_DENIED        321     /* MSG "Network access is denied" */
#define SE_NET_DEVICE_TYPE      322     /* MSG "(unused) Network device type incorrect" */
#define SE_NET_NAME_NOT_FND2    323     /* MSG "(unused) Network name not found" */
#define SE_NET_NAME_LIMIT       324     /* MSG "(unused) Network name limit exceeded" */
#define SE_NET_SESSION_LIMIT    325     /* MSG "Net BIOS session limit exceeded" */
#define SE_TEMPORARILY_PAUSED   326     /* MSG "(unused) Temporarily paused" */
#define SE_NET_REQ_NOT_ACCEPT   327     /* MSG "Network request not accepted" */
#define SE_REDIR_PAUSED         328     /* MSG "(unused) Print or disk redirection paused" */
#define SE_DOS_RESERVED_73      329
#define SE_DOS_RESERVED_74      330
#define SE_DOS_RESERVED_75      331
#define SE_DOS_RESERVED_76      332
#define SE_DOS_RESERVED_77      333
#define SE_NET_NOT_LOGGED_IN    334     /* MSG "Not logged in to network node specified" */
#define SE_DOS_RESERVED_79      335
#define SE_FILE_EXISTS          336     /* MSG "File exists" */

/* max for error mapping table */
#define MAX_IO_ERROR            336

#define SE_DOS_RESERVED_81      337
#define SE_NOT_MAKE_DIR_ENTRY   338     /* MSG "(unused) Cannot make directory entry" */
#define SE_FAIL_INT24           339     /* MSG "(unused) Fail on INT 24" */
#define SE_TOO_MANY_REDIR       340     /* MSG "Too many redirections" */
#define SE_DUPLICATE_REDIR      341     /* MSG "(unused) Duplicate redirection" */
#define SE_INVALID_PASSWORD     342     /* MSG "(unused) Invalid password" */
#define SE_INVALID_PARAMETER    343     /* MSG "Invalid parameter" */
#define SE_NET_DATA_FAULT       344     /* MSG "A write fault occurred on the network" */
#define SE_NO_PROC_SLOTS        345     /* MSG "(unused) The system cannot start another process at this time" */
#define SE_NOT_INSTALLED        346     /* MSG "Required system component not installed" */
#define SE_DOS_RESERVED_91      347
#define SE_DOS_RESERVED_92      348
#define SE_DOS_RESERVED_93      349
#define SE_DOS_RESERVED_94      350
#define SE_DOS_RESERVED_95      351
#define SE_DOS_RESERVED_96      352
#define SE_DOS_RESERVED_97      353
#define SE_DOS_RESERVED_98      354
#define SE_DOS_RESERVED_99      355

#define SE_356                  356
#define SE_357                  357
#define SE_358                  358
#define SE_359                  359
#define SE_360                  360
#define SE_361                  361
#define SE_362                  362
#define SE_363                  363
#define SE_364                  364
#define SE_BROKEN_PIPE          365     /* MSG "Connection broken" */
#define SE_366                  366
#define SE_367                  367
#define SE_368                  368
#define SE_369                  369
#define SE_370                  370
#define SE_371                  371
#define SE_372                  372
#define SE_373                  373
#define SE_374                  374
#define SE_375                  375
#define SE_376                  376
#define SE_377                  377
#define SE_INSUFFICIENT_BUFFER  378     /* MSG "The data area passed to a system call is too small" */
#define SE_379                  379
#define SE_380                  380
#define SE_381                  381
#define SE_382                  382
#define SE_383                  383
#define SE_384                  384
#define SE_385                  385
#define SE_386                  386
#define SE_387                  387
#define SE_388                  388
#define SE_389                  389
#define SE_390                  390
#define SE_391                  391
#define SE_392                  392
#define SE_393                  393
#define SE_394                  394
#define SE_395                  395
#define SE_396                  396
#define SE_397                  397
#define SE_398                  398
#define SE_399                  399
#define SE_400                  400
#define SE_401                  401
#define SE_402                  402
#define SE_403                  403
#define SE_404                  404
#define SE_405                  405
#define SE_406                  406
#define SE_407                  407
#define SE_408                  408
#define SE_409                  409
#define SE_410                  410
#define SE_411                  411
#define SE_412                  412
#define SE_413                  413
#define SE_414                  414
#define SE_415                  415

/* Errors for other subsystems (i.e. Btrieve, C-ISAM, Winsock, etc...) (416-431) */
#define SE_INITIALIZE_BRAND     416     /* MSG "Record Manager initialization failed" */
#define SE_INACTIVE_BRAND       417     /* MSG "The Record Manager is inactive" */
#define SE_INTERFACE_BRAND      418     /* MSG "The Record Manager interface is invalid" */
#define SE_UNIMPLEMENT_BRAND    419     /* MSG "Record Manager does not implement the required capability" */
#define SE_RESERVED_BRAND       420     /* MSG "Record Manager returned an reserved status code" */
#define SE_GENERIC_BRAND        421     /* MSG "Record Manager returned an generic status code" */
#define SE_UNDEFINED_BRAND      422     /* MSG "Record Manager returned an undefined status code" */
#define SE_BAD_RECONNECT_KEY    423     /* MSG "The reconnection key does not match any connection" */
#define SE_RECONNECT_FAIL       424     /* MSG "The attempt to reconnect has failed while processing in icnetd" */
#define SE_RESYNC_FAIL          425     /* MSG "The attempt to reconnect has failed to resynchronize" */
#define SE_RECONNECTING         426     /* MSG "The connection was broken. Attempting to reconnect..." */
#define SE_HEARTBEAT_FAILURE    427     /* MSG "The network heartbeat has failed to respond" */
#define SE_RECONNECT_PID_DIED   428     /* MSG "The attempt to reconnect has failed: the surrogate process has terminated" */
#define SE_RECONNECT_FAIL_CANCEL 429    /* MSG "The attempt to reconnect failed or was canceled by the user" */
#define SE_RECV_CANCELLED       430     /* MSG "The receive operation was cancelled" */
#define SE_SERVER_ERR_RESP      431     /* MSG "The server response indicates that the request failed" */

/* Errors for WATCH (432-447) */
#define SE_TERM_ALREADY_WATCHED 432     /* MSG "The terminal is already being watched" */
#define SE_CANT_WATCH_PUSHED    433     /* MSG "Cannot watch a pushed terminal" */
#define SE_CANT_WATCH_WATCHER   434     /* MSG "Cannot watch a watching terminal" */
#define SE_WATCHEE_CANT_WATCH   435     /* MSG "A watched terminal cannot watch another terminal" */
#define SE_CANT_INT_TO_WATCH    436     /* MSG "Cannot interrupt the terminal to watch" */
#define SE_WATCHEE_LOGOFF       437     /* MSG "Watched terminal has logged off" */
#define SE_WATCHEE_PUSHED       438     /* MSG "Watched terminal pushed to CLI. Press interrupt to discontinue watching" */
#define SE_INV_OP_OWN_TERM      439     /* MSG "Invalid operation for your own terminal" */
#define SE_WATCHEE_KILL_BY_ERR  440     /* MSG "Watched terminal terminated itself with a program error" */
#define SE_WATCHEE_KILL_BY_INT  441     /* MSG "Watched terminal terminated by interrupt or superior process" */
#define SE_WATCH_PID_DEFUNCT    442     /* MSG "The process is defunct" */
#define SE_WATCHED_PID_DIED     443     /* MSG "The watched terminal's program process has terminated" */
#define SE_CANT_WATCH_SERVER    444     /* MSG "Cannot watch a detached program, GUI-only SP2 surrogate, or CGI surrogate" */
#define SE_CLIENT_SERVER_ERROR  445     /* MSG "Client/Server protocol packet or parameter mismatch" */
#define SE_446                  446
#define SE_447                  447

/* Errors for System V STREAMS TCP (448-479) */
#define SE_WOULDBLOCK           448     /* MSG "Operation would block" */
#define SE_INPROGRESS           449     /* MSG "Operation now in progresss" */
#define SE_ALREADY              450     /* MSG "Operation already in progress" */
#define SE_NOTSOCK              451     /* MSG "Socket operation on non-socket" */
#define SE_DESTADDRREQ          452     /* MSG "Destination address required" */
#define SE_MSGSIZE              453     /* MSG "Message too long" */
#define SE_PROTOTYPE            454     /* MSG "Protocol wrong type for socket" */
#define SE_NOPROTOOPT           455     /* MSG "Protocol not available" */
#define SE_PROTONOSUPPORT       456     /* MSG "Protocol not supported" */
#define SE_SOCKTNOSUPPORT       457     /* MSG "Socket type not supported" */
#define SE_OPNOTSUPP            458     /* MSG "Operation not supported on socket" */
#define SE_PFNOSUPPORT          459     /* MSG "Protocol family not supported" */
#define SE_AFNOSUPPORT          460     /* MSG "Address family not supported by protocol family" */
#define SE_ADDRINUSE            461     /* MSG "Address already in use" */
#define SE_ADDRNOTAVAIL         462     /* MSG "Can't assign requested address" */
#define SE_NETDOWN              463     /* MSG "Network is down" */
#define SE_NETUNREACH           464     /* MSG "Network is unreachable" */
#define SE_NETRESET             465     /* MSG "Network dropped connection on reset" */
#define SE_CONNABORTED          466     /* MSG "Software caused connection abort" */
#define SE_CONNRESET            467     /* MSG "Connection reset by peer" */
#define SE_NOBUFS               468     /* MSG "No buffer space available" */
#define SE_ISCONN               469     /* MSG "Socket is already connected" */
#define SE_NOTCONN              470     /* MSG "Socket is not connected" */
#define SE_SHUTDOWN             471     /* MSG "Can't send/receive after socket shutdown" */
#define SE_TOOMANYREFS          472     /* MSG "Too many references: can't splice" */
#define SE_TIMEDOUT             473     /* MSG "Connection timed out" */
#define SE_CONNREFUSED          474     /* MSG "Connection refused" */
#define SE_LOOP                 475     /* MSG "Too many symbolic links in path" */
#define SE_NAMETOOLONG          476     /* MSG "Filename too long" */
#define SE_HOSTDOWN             477     /* MSG "Host is down" */
#define SE_HOSTUNREACH          478     /* MSG "No route to host" */
#define SE_HOSTNOTFOUND         479     /* MSG "Host not found" */

/* Other errors (480-499) */
#define SE_480                  480
#define SE_NO_STREAMS_RESOURCES 481     /* MSG "No more streams resources are available" */
#define SE_USEREXISTS           482     /* MSG "The user account already exists" */
#define SE_PASSWORDTOOSHORT     483     /* MSG "The password is too short or fails some other restrictions" */
#define SE_BETA_EXPIRED         484     /* MSG "This beta release expired" */
#define SE_BETA_RUN_UNTIL       485     /* MSG "This beta release will run until" */
#define SE_OPEN_SEM_CREATE      486     /* MSG "Open/close semaphore could not be created" */
#define SE_OPEN_SEM_SETUP       487     /* MSG "Open/close semaphore setup failed" */
#define SE_BUF_SEM_CREATE       488     /* MSG "Buffer manager semaphore could not be created" */
#define SE_BUF_SEM_SETUP        489     /* MSG "Buffer manager semaphore setup failed" */
#define SE_LOCK_SEM_CREATE      490     /* MSG "Record lock semaphore could not be created" */
#define SE_LOCK_SEM_SETUP       491     /* MSG "Record lock semaphore setup failed" */
#define SE_LOGON_SEM_CREATE     492     /* MSG "Logon/Logoff semaphore could not be created" */
#define SE_LOGON_SEM_SETUP      493     /* MSG "Logon/Logoff semaphore setup failed" */
#define SE_RMV_OPEN_SEM         494     /* MSG "Open/close semaphore could not be removed" */
#define SE_RMV_BUF_SEM          495     /* MSG "Buffer manager semaphore could not be removed" */
#define SE_RMV_LOCK_SEM         496     /* MSG "Record lock semaphore could not be removed" */
#define SE_RMV_LOGON_SEM        497     /* MSG "Logon/Logoff semaphore could not be removed" */
#define SE_CHILD_EXIT_SIGNAL    498     /* MSG "Child process was terminated by a signal" */
#define SE_CHILD_EXIT_ERROR     499     /* MSG "Child process terminated with an unknown error" */

/* NOTE: keep these in sync with sysdefs.h exit codes */
#define SE_EXIT_CODE            500     /* base of exit code mapping */

#define SE_EXIT_OK              500     /* MSG "Processing was successful" */
#define SE_EXIT_JOB_ERR         501     /* MSG "Processing had errors" */
#define SE_EXIT_JOB_INT         502     /* MSG "Processing was interrupted or aborted" */
#define SE_EXIT_JOB_FATAL       503     /* MSG "Processing was halted by fatal internal error" */
#define SE_EXIT_CMD_ERR         504     /* MSG "Command-line errors prevented running" */
#define SE_EXIT_AUTH_ERR        505     /* MSG "Authorization failure prevented running" */
#define SE_EXIT_INIT_ERR        506     /* MSG "Program initialization errors prevented running" */
#define SE_EXIT_CMD_HELP        507     /* MSG "Command-line help request prevented running" */
#define SE_EXIT_CMD_DONE        508     /* MSG "Command-line request completion prevented running" */
#define SE_EXIT_resv            509

/* Errors for general operating system errors (510 - 511) */
#define SE_UNIMPLEMENTED_FUNC   510     /* MSG "Unimplemented operating system function" */
#define SE_UNEXPECTED_ERROR     511     /* MSG "Unexpected operating system error" */

#define SE_MAX_ERROR            511     /* maximum allowable system error number */

/****************************************************************/
/*                                                              */
/*    utilities error group (UE_xxx) - 512-1023                 */
/*                                                              */
/****************************************************************/

#define UE_MIN_ERROR            512     /* minimum allowable utility error number */


#define UE_OPTIONS_CONFLICT     512    /* MSG "The following options conflict with each other" */
#define UE_SHM_ALIGN_ERROR      513    /* MSG "Shared memory size or alignment error" */
#define UE_SHM_ALLOC_ERROR      514    /* MSG "Shared memory allocation error" */
#define UE_B_INV                515    /* MSG "Invalid argument for -B option" */
#define UE_SHMGET               516    /* MSG "Shared memory area could not be allocated" */
#define UE_SHM_OF_n             517    /* MSG "Shared memory area of " */
#define UE_n_BYTES_REQ          518    /* MSG " bytes are required" */
#define UE_n_BYTES_ALLOC        519    /* MSG " bytes allocated" */
#define UE_C_INV                520    /* MSG "Invalid argument for -C option" */
#define UE_C_ILL                521    /* MSG "Cannot use -C option for output file" */
#define UE_Cp_ILL               522    /* MSG "Cannot use -C p option for output file" */
#define UE_C_COUNT              523    /* MSG "The maximum number of -C arguments has been specified" */
#define UE_C_NOT_DIR            524    /* MSG "The -C argument must specify a directory" */
#define UE_C_ARGS               525    /* MSG "-C Search List" */
#define UE_C_IGNOR_Ni           526    /* MSG "The -C option is ignored with the -N i option" */
#define UE_cdilsx_MUTEX         527    /* MSG "Only one of -c, -d, -i, -l, -s, and -x may be specified" */
#define UE_RUNNING              528    /* MSG "icexec is already running" */
#define UE_ABNORMAL             529    /* MSG "icexec was abnormally terminated" */
#define UE_D_INV                530    /* MSG "Invalid argument for -D option" */
#define UE_D_CNT                531    /* MSG "Too many -D options have been specified" */
#define UE_D_CONFL_R            532    /* MSG "The -D option conflicts with the -R option" */
#define UE_D_CONFL_tTd          533    /* MSG "The -D option conflicts with the -t or -T d option" */
#define UE_SHMDT                534    /* MSG "Releasing shared memory area" */
#define UE_RMV_SHM              535    /* MSG "Removing shared memory area" */
#define UE_Ee_OPT               536    /* MSG "The -e or -E option was already specified" */
#define UE_E_INV                537    /* MSG "Invalid argument for -E option" */
#define UE_TERMINATED           538    /* MSG "icexec will be terminated" */
#define UE_INITIALIZING         539    /* MSG "Initializing shared memory area, please wait..." */
#define UE_CLEANUP_PROC         540    /* MSG "Attempting to clean up after the terminated process" */
#define UE_PIPE_CREATE          541    /* MSG "Creating command pipe" */
#define UE_PIPE_REMOVE          542    /* MSG "Removing command pipe" */
#define UE_F_INV                543    /* MSG "Invalid argument for -F option" */
#define UE_F_CNT                544    /* MSG "The -F option was specified more times than allowed" */
#define UE_CMD_ACCESS           545    /* MSG "User not privileged for this action" */
#define UE_TERM_NO_ICRUN        546    /* MSG "Terminal is not configured to run ICRUN" */
#define UE_G_INV                547    /* MSG "Invalid argument for -G option" */
#define UE_Gl_IGN               548    /* MSG "The '-G o' option is ignored unless '-l' or '-L' is set" */
#define UE_AT_LEAST             549    /* MSG "At least " */
#define UE_KB_REQ               550    /* MSG " KB of buffers are required" */
#define UE_I_INV                551    /* MSG "Invalid argument for -I option" */
#define UE_I_CNT                552    /* MSG "Too many I options" */
#define UE_I_CONFL_tTi          553    /* MSG "The -I option conflicts with the -t or -T i option" */
#define UE_ix_CONFLICT          554    /* MSG "The -i and -x options are mutually exclusive" */
#define UE_LOCAL_CACHE          555    /* MSG "Not enough buffers for process local buffer cache" */
#define UE_QUEUE_NAME           556    /* MSG "Invalid queue name" */
#define UE_K_INV                557    /* MSG "Invalid argument for -K option" */
#define UE_K_ILL                558    /* MSG "Cannot use -K option for output file" */
#define UE_IO_AREA              559    /* MSG "base I/O control area" */
#define UE_K_CNT                560    /* MSG "Too many K options" */
#define UE_SEQ_AREA             561    /* MSG "sequential I/O control area" */
#define UE_IND_AREA             562    /* MSG "indexed I/O control area" */
#define UE_Ll_OPT               563    /* MSG "The -l or -L option was already specified" */
#define UE_L_INV                564    /* MSG "Invalid argument for -L option" */
#define UE_L_ILL                565    /* MSG "Cannot use -L option for output file" */
#define UE_REL_AREA             566    /* MSG "relative I/O control area" */
#define UE_ISAM_AREA            567    /* MSG "isam I/O control area" */
#define UE_M_INV                568    /* MSG "Invalid argument for -M option" */
#define UE_mt_CONFLICT          569    /* MSG "The -m and -t options are mutually exclusive" */
#define UE_PROC_AREA            570    /* MSG "process control area" */
#define UE_PCQ_AREA             571    /* MSG "printer control area" */
#define UE_STR_AREA             572    /* MSG "string area" */
#define UE_PTR_AREA             573    /* MSG "printer translation table area" */
#define UE_SHM_EXISTS           574    /* MSG "Shared memory area already exists" */
#define UE_N_INV                575    /* MSG "Invalid argument for -N option" */
#define UE_SHM_ACCESS           576    /* MSG "Shared memory area could not be accessed" */
#define UE_SHM_STATUS           577    /* MSG "Shared memory area status check failed" */
#define UE_SHM_ATTACH           578    /* MSG "Shared memory area could not be attached" */
#define UE_SHM_REV              579    /* MSG "Shared memory area revision does not match" */
#define UE_nr_MUTEX             580    /* MSG "Only one of -n and -r may be specified" */
#define UE_n_REQ_ix             581    /* MSG "The -n option can only be used with -i or -x" */
#define UE_SHM_ANOTHER          582    /* MSG "Shared memory area is being initialized by another copy of icexec" */
#define UE_O_INV                583    /* MSG "Invalid argument for -O option" */
#define UE_PDF_AREA             584    /* MSG "pdf format descriptor area" */
#define UE_O_REQ_none           585    /* MSG "The -O option can not be used with any other options" */
#define UE_c_REQ_N_s            586    /* MSG "The -c option also requires the -N s option" */
#define UE_c_UNSUPPORTED        587    /* MSG "The -c option is not supported on this OS platform" */
#define UE_P_INV                588    /* MSG "Invalid argument for -P option" */
                                       /* */
#define UE_p_IGNOR_u            590    /* MSG "The -p option is ignored with the -u option" */
#define UE_PT_MUTEX_b           591    /* MSG "Only one of -P or -T may be specified with -b" */
                                       /* */
                                       /* */
                                       /* */
#define UE_R_INV                595    /* MSG "Invalid argument for -R option" */
#define UE_R_ILL                596    /* MSG "Cannot use -R option for output file" */
#define UE_R_VAL                597    /* MSG "The -R argument must be 1 thru " */
#define UE_r_REQ_ix             599    /* MSG "The -r option can only be used with -i or -x" */
#define UE_R_CONFL_tTd          600    /* MSG "The -R option conflicts with the -t or -T d option" */
                                       /* */
                                       /* */
                                       /* */
#define UE_S_INV                604    /* MSG "Invalid argument for -S option" */
#define UE_S_ILL                605    /* MSG "The -S option requires an indexed input file" */
#define UE_s_REQ_ARG            606    /* MSG "The -s option requires a program argument" */
#define UE_s_CONFL_ix           607    /* MSG "The -s option conflicts with the -i or -x option" */
                                       /* */
                                       /* */
                                       /* */
#define UE_T_INV                611    /* MSG "Invalid argument for -T option" */
#define UE_tT_REQIR_m           612    /* MSG "The -t or -T option requires the -m option" */
                                       /* */
                                       /* */
#define UE_U_INV                615    /* MSG "Invalid argument for -U option" */
#define UE_u_CONFL_Ns           616    /* MSG "The -u option conflicts with the -N s option" */
#define UE_u_CONFL_eE           617    /* MSG "The -u option conflicts with the -e or -E option" */
                                       /* */
                                       /* */
#define UE_V_INV                620    /* MSG "Invalid argument for -V option" */
#define UE_V_ILL                621    /* MSG "Cannot use -V option for output file" */
                                       /* */
                                       /* */
#define UE_X_INV                624    /* MSG "Invalid argument for -X option" */
#define UE_NO_PROC              625    /* MSG "No files/arguments were processed" */
#define UE_1_PROC               626    /* MSG "1 file/argument was processed" */
#define UE_n_PROC               627    /* MSG " files/arguments were processed" */
#define UE_NO_ERRORS            628    /* MSG "No files/arguments had errors" */
#define UE_1_ERROR              629    /* MSG "1 file/argument had errors" */
#define UE_n_ERRORS             630    /* MSG " files/arguments had errors" */
#define UE_NO_ADDED             631    /* MSG "No files were added" */
#define UE_1_ADDED              632    /* MSG "1 file was added" */
#define UE_n_ADDED              633    /* MSG " files were added" */
#define UE_NO_REPL              634    /* MSG "No files were replaced" */
#define UE_1_REPL               635    /* MSG "1 file was replaced" */
#define UE_n_REPL               636    /* MSG " files were replaced" */
#define UE_NO_ADD_REPL          637    /* MSG "No files were added or replaced" */
#define UE_NO_DELETED           638    /* MSG "No files were deleted" */
#define UE_1_DELETED            639    /* MSG "1 file was deleted" */
#define UE_n_DELETED            640    /* MSG " files were deleted" */
#define UE_NO_EXPORTED          641    /* MSG "No files were exported" */
#define UE_1_EXPORTED           642    /* MSG "1 file was exported" */
#define UE_n_EXPORTED           643    /* MSG " files were exported" */
#define UE_NO_ADDED_LK          644    /* MSG "No entries were added to the link file" */
#define UE_1_ADDED_LK           645    /* MSG "1 entry was added to the link file" */
#define UE_n_ADDED_LK           646    /* MSG " entries were added to the link file" */
#define UE_NO_REPL_LK           647    /* MSG "No entries were replaced in the link file" */
#define UE_1_REPL_LK            648    /* MSG "1 entry was replaced in the link file" */
#define UE_n_REPL_LK            649    /* MSG " entries were replaced in the link file" */
#define UE_NO_ADD_REPL_LK       650    /* MSG "No entries were added or replaced in the link file" */
#define UE_NO_EXPORTED_LK       651    /* MSG "No entries were exported from the link file" */
#define UE_1_EXPORTED_LK        652    /* MSG "1 entry was exported from the link file" */
#define UE_n_EXPORTED_LK        653    /* MSG " entries were exported from the link file" */
#define UE_NO_LISTED            654    /* MSG "No files were listed" */
#define UE_1_LISTED             655    /* MSG "1 file was listed" */
#define UE_n_LISTED             656    /* MSG " files were listed" */
                                       /* */
                                       /* */
                                       /* */
                                       /* */
                                       /* */
#define UE_b_INV                662    /* MSG "The -b option is not valid for this runtime */
#define UE_UNIMPL_OPT           663    /* MSG "Option not implemented" */
#define UE_NO_INPUT             664    /* MSG "No input arguments were specified" */
#define UE_PROCESS              665    /* MSG "Processing" */
#define UE_ENV_LENGTH           666    /* MSG "Environment is too long to process" */
#define UE_ENV_COUNT            667    /* MSG "Too many arguments in environment" */
#define UE_INV_NUM              668    /* MSG "The argument is not a valid number" */
#define UE_RANGE                669    /* MSG "The argument is out of range" */
#define UE_ARG_LENGTH           670    /* MSG "Argument is too long" */
#define UE_CX_PD_EXT            671    /* MSG "The filename must end with .cx or .pd" */
#define UE_SWAP_PGM             672    /* MSG "The program file is being swapped in order to decode it" */
#define UE_INTERRUPT            673    /* MSG "Processing was interrupted and may be incomplete" */
#define UE_NOT_DIR              674    /* MSG "Argument is not a directory" */
#define UE_NO_OPER              675    /* MSG "No operations were specified" */
#define UE_CREATING             676    /* MSG "Creating" */
#define UE_USING                677    /* MSG "Using" */
#define UE_ARG_NO_PATH          678    /* MSG "Argument may not have a path" */
#define UE_REQUIRED_OPT         679    /* MSG "The following option is required" */
                                       /* */
                                       /* */
                                       /* */
#define UE_BAD_LIB_INDEX        683    /* MSG "The library index is corrupt" */
#define UE_FULL_LIB_INDEX       684    /* MSG "The library index is full" */
#define UE_TOO_MANY_ARGS        685    /* MSG "Too many arguments were specified" */
                                       /* */
#define UE_NX_XD_REV            687    /* MSG "Unknown .nx/.xd version" */
#define UE_REQ_SIMPLE           688    /* MSG "A simple filename or template is required" */
#define UE_NO_MATCHES           689    /* MSG "No files matched the template" */
#define UE_DISALLOW_ARGS        690    /* MSG "No arguments are allowed" */
#define UE_READY                691    /* MSG " is ready" */
#define UE_FINISHED             692    /* MSG " is finished" */
                                       /* */
#define UE_LICE_DEVICE          694    /* MSG "Software protection device" */
                                       /* */
#define UE_INSUFF_ARGS          696    /* MSG "Not enough arguments were specified" */
                                       /* */
                                       /* */
                                       /* */
#define UE_LEA_50               700    /* MSG "Packing density must be at least fifty percent" */
#define UE_MOR_100              701    /* MSG "Packing density cannot be more than 100 percent" */
#define UE_INVALID_TYPE         702    /* MSG "Invalid file type for output" */
#define UE_ONE_CONVERT          703    /* MSG "Only one convert character per line" */
#define UE_INV_ALT_KEY          704    /* MSG "Invalid alternate key number specified" */
#define UE_KEY_LEAST            705    /* MSG "Alternate key number must be at least" */
#define UE_KEY_MOST             706    /* MSG "Alternate key number must be less than" */
#define UE_INV_PK               707    /* MSG "Invalid packing density specification" */
#define UE_EXP_IMPERATIVE       708    /* MSG "A command imperative (SORT/MERGE/COPY) is expected here" */
#define UE_INV_DEN_PRM          709    /* MSG "Packing density was already specified for the primary key" */
#define UE_INV_DEN_ALT          710    /* MSG "Packing density was already specified for alternate key" */
#define UE_REQ_IND              711    /* MSG "Index file requires keys and size" */
#define UE_REQ_REL              712    /* MSG "Relative file requires size" */
#define UE_EXP_DELIM            713    /* MSG "A string specifying the delimiters is expected here" */
#define UE_EXP_REC_TYPE         714    /* MSG "A record format type is expected here" */
#define UE_EXP_LOC              715    /* MSG "A field specifier is expected here (begin/end or begin:len)" */
#define UE_EXP_TYPE             716    /* MSG "A key type (ALPHANUMERIC or NUMERIC) is expected here" */
#define UE_FLD_OUTPUT_REC       717    /* MSG "The field specifiers go beyond the end of the output record" */
#define UE_FLD_INPUT_REC        718    /* MSG "The field specifiers are beyond at least one of the input records" */
#define UE_NO_OUTPUT            719    /* MSG "No output argument was specified" */
#define UE_MERGE_REQ_2          720    /* MSG "The merge option requires at least 2 input files" */
#define UE_KEYSET_LEN           721    /* MSG "The total length of all keys exceeds the system limit" */
#define UE_KEY_INPUT_REC        722    /* MSG "The keys are not all fully contained in the input records" */
#define UE_REC_FLD_REQ          723    /* MSG "At least one pos:len field specifier is required" */
#define UE_EXP_LDG_TRL          724    /* MSG "Either LEADING or TRAILING is expected here" */
#define UE_INV_OCTAL            725    /* MSG "Invalid octal constant" */
#define UE_DUPL_COLLATE         726    /* MSG "Duplicate collating/converting sequence definition character" */
#define UE_EXP_LRV              727    /* MSG "LEFT, RIGHT, or VARIABLE is expected here" */
#define UE_EXP_STR              728    /* MSG "A string literal is expected here" */
#define UE_EXP_COND_EXPR        729    /* MSG "A conditional expresion is expected here" */
#define UE_EXP_MASSAGE          730    /* MSG "A massage command is expected here" */
#define UE_EXP_RHS              731    /* MSG "A string literal, field specifier, or integer is expected here" */
#define UE_EXP_COND_TERM        732    /* MSG "A NOT or simple condition is expected here" */
#define UE_EXP_COND_FACT        733    /* MSG "A simple condition or '(' is expected here" */
#define UE_MAX_INPUT_CNT        734    /* MSG "The maximum number of input files has already been specified" */
#define UE_INV_VALUE            735    /* MSG "The value is out of range" */
#define UE_ONE_OUTPUT           736    /* MSG "Only one OUTPUT statement may be specified" */
#define UE_END_AR_EXPR          737    /* MSG "Internal error - bad conditional expression" */
#define UE_PUSH_OPER            738    /* MSG "Internal error - operator stack overflow/underflow" */
#define UE_POP_OPND             739    /* MSG "Internal error - operand stack overflow/underflow" */
#define UE_DO_OPER              740    /* MSG "Internal error - invalid expression operator" */
#define UE_OPND_OVERFLOW        741    /* MSG "The expression is too complex to evaluate" */
#define UE_PROCESSED            742    /* MSG "Processed" */
#define UE_OPND_MISMATCH        743    /* MSG "The operands for this operation are not compatible" */
#define UE_EXP_CONDITION        744    /* MSG "A conditional expression is expected here" */
#define UE_REQ_REC_LEN          745    /* MSG "Record length specification is required" */
#define UE_DISALLOW_TEMP        746    /* MSG "Templates are not allowed" */
#define UE_FILE_OLDER           747    /* MSG "File is not newer than library entry: not imported" */
#define UE_LIB_OLDER            748    /* MSG "Library entry is not newer than file: not exported" */
#define UE_EXISTS_IN_CL         749    /* MSG "File already exists in the library" */
#define UE_IMPORTING            750    /* MSG "importing" */
#define UE_DELETING             751    /* MSG "deleting" */
#define UE_ALLOCATING           752    /* MSG "allocating" */
#define UE_EXPORTING            753    /* MSG "exporting" */
#define UE_LIB_CONTENTS         754    /* MSG "Library Index Listing" */
#define UE_NAME                 755    /* MSG "File Name" */
#define UE_SIZE                 756    /* MSG "File Size" */
#define UE_MOD_DATE             757    /* MSG "Last Modified" */
#define UE_LIB_STATS            758    /* MSG "Library Statistics Listing" */
#define UE_READING_STATS        759    /* MSG "reading library for statistics" */
#define UE_CL_FILES             760    /* MSG "files are in the library" */
#define UE_CL_INX_ENTS          761    /* MSG "of the index entries are in use" */
#define UE_CL_INX_SPACE         762    /* MSG "of the index space is in use" */
#define UE_CL_DELETED           763    /* MSG "deleted file areas are in the library" */
#define UE_ADDED_CL             764    /* MSG "has been added to the library" */
#define UE_REPLACED_CL          765    /* MSG "has been replaced in the library" */
#define UE_DELETED_CL           766    /* MSG "has been deleted" */
#define UE_EXPORTED_CL          767    /* MSG "has been exported" */
#define UE_LK_STATS             768    /* MSG "Statistics for link file" */
#define UE_EXISTS_IN_LK         769    /* MSG "Entry already exists in the link file" */
#define UE_LK_NAME_LEN          770    /* MSG "Name exceeds maximum allowed link file name length" */
#define UE_LK_INPUT_FMT         771    /* MSG "Invalid link file input format" */
#define UE_LK_ENTRIES           772    /* MSG "entries are in the link file" */
#define UE_LK_PAGES             773    /* MSG "pages are being used by the link information" */
#define UE_BAD_LK_FILE          774    /* MSG "The link file is corrupt" */
#define UE_FULL_LK_FILE         775    /* MSG "The link file is full" */
#define UE_TRUNC_REV            776    /* MSG "Revision argument is too long: changed to" */
#define UE_NEW_OEM_REV          777    /* MSG "New revision is" */
#define UE_OLD_OEM_REV          778    /* MSG "Old revision is" */
#define UE_DUPL_TABLE           779    /* MSG "A table by this name is already defined" */
#define UE_MAX_TABLES           780    /* MSG "The maximum number of collating table definitions has been reached" */
#define UE_LEN_PROHIBIT         781    /* MSG "Record length specification is not allowed for indexed or relative files" */
#define UE_INPUT_CNT            782    /* MSG "Input record count" */
#define UE_OUTPUT_CNT           783    /* MSG "Output record count" */
#define UE_LIB_EMPTY            784    /* MSG "The library is empty and is being deleted" */
#define UE_TABLE_ERR            785    /* MSG "The table could not be loaded" */
#define UE_MAX_KEYS             786    /* MSG "The maximum number of key definitions has been reached" */
#define UE_KEY_BAD_TYPE         787    /* MSG "The key type is not valid for the key length" */
#define UE_TABLE_NOT_DEF        788    /* MSG "The table name is not defined" */
#define UE_CMD_STACK            789    /* MSG "Internal error - command stack error" */
#define UE_ONE_CHR_LIT          790    /* MSG "A single-character literal or decimal character value is expected here" */
#define UE_EXP_LOC_STR          791    /* MSG "A field area location or string literal is expected here" */
#define UE_Oc_REQ_B             792    /* MSG "The -O c option requires -B" */
#define UE_B_REQ_Ocv            793    /* MSG "The -B option can only be used with -O c or -O v" */
#define UE_C_REQ_Ocva           794    /* MSG "The -C option can only be used with -O c, -O v, or -O a" */
#define UE_MAX_OPNDS            795    /* MSG "The maximum number of operands for this statement has been reached" */
#define UE_S_REQ_Ocv            796    /* MSG "The -S option can only be used with -O c or -O v" */
#define UE_STR_LEN_1            797    /* MSG "The string must be 1 character in length" */
#define UE_PARSE_OVFL           798    /* MSG "Parse stack overflow, simplify expressions" */
#define UE_PARSE_ENDRULE        799    /* MSG "Internal parser error - endrule reached" */
#define UE_MSG_CREATE           800    /* MSG "Creating server socket" */
#define UE_PARSE_UNFL           801    /* MSG "Internal parser error - parse stack underflow" */
#define UE_PARSE_TBL            802    /* MSG "Internal parser error - invalid parse op" */
#define UE_EXPECT               803    /* MSG "The following element was expected here" */
#define UE_CANT_RECOVER         804    /* MSG "The syntaxer is unable to recover and resume syntaxing" */
#define UE_SKIP_TOKENS          805    /* MSG "The syntaxer is skipping source to attempt error recovery" */
#define UE_REPLYING             806    /* MSG "Error sending reply message" */
#define UE_RESUME_HERE          807    /* MSG "Processing is resuming here" */
#define UE_KILL_ERR             808    /* MSG "Termination request could not be sent" */
#define UE_KILL_SENT            809    /* MSG "Termination request has been sent" */
#define UE_PID_GONE             810    /* MSG "Process cannot be accessed" */
#define UE_INS_EXPECTED         811    /* MSG "Inserting expected element" */
#define UE_DEL_UNEXPECTED       812    /* MSG "Deleting unexpected element" */
#define UE_W_INV                813    /* MSG "Invalid argument for -W option" */
#define UE_LIT_LEN              814    /* MSG "Literal is too long" */
#define UE_LOG_IS_ENABLED       815    /* MSG "Logging is already enabled" */
#define UE_LOG_NOT_ENABLED      816    /* MSG "Logging is not enabled" */
#define UE_EOL_IN_LIT           817    /* MSG "Literal not closed before end of line" */
#define UE_TOK_LEN              818    /* MSG "Item is too long" */
#define UE_LOG_GENERATION       819    /* MSG "The log generation number is not valid" */
#define UE_ILL_TOKEN            820    /* MSG "Illegal token" */
#define UE_NUM_IN_LIT           821    /* MSG "Invalid numeric specifier in literal" */
#define UE_K_REQ                822    /* MSG "At least one -K option is required" */
#define UE_EXP_IF_BODY          823    /* MSG "A massage statement list is expected here" */
#define UE_EXP_ELSE             824    /* MSG "An ELSE or END-IF is expected here" */
#define UE_EXTRA_RPAREN         825    /* MSG "Unbalanced parentheses; right parenthesis is being ignored" */
#define UE_NEXT_RECORD          826    /* MSG "Next Record" */
#define UE_STOP_MASSAGE         827    /* MSG "STOP massage statement was encountered" */
#define UE_MAX_SKIP_FILES       828    /* MSG "The maximum number of skip files has already been specified" */
#define UE_OUTPUT_SKIP          829    /* MSG "Output skip count" */
#define UE_INPUT_SKIP           830    /* MSG "Input skip count" */
#define UE_KEY_REQ              831    /* MSG "At least one KEY statement must be specified" */
#define UE_DUPL_REC             832    /* MSG "Duplicates count" */
#define UE_NO_KEY_COPY          833    /* MSG "No KEY definitions are allowed with the COPY imperative" */
#define UE_O_REQ                834    /* MSG "The -O option is required" */
#define UE_MASSAGE_SKIP         835    /* MSG "Massage skip count" */
#define UE_LOG_REQ_ICISAM_7     836    /* MSG "Logging requires ICISAM Revision 7" */
#define UE_o_OPT                837    /* MSG "The -o option was already specified" */
#define UE_Q_OPT                838    /* MSG "The -Q option was already specified" */
#define UE_Q_INV                839    /* MSG "Invalid argument for -Q option" */
#define UE_MASSAGE_TRUNC        840    /* MSG "Massage overflow count" */
#define UE_P_CNT                841    /* MSG "Too many -P options have been specified" */
#define UE_OUTPUT_TRUNC         842    /* MSG "Output truncated count" */
#define UE_ITEM_ALPHANUM_ED     843    /* MSG "Item defined is alphanumeric edited" */
#define UE_ITEM_NUMERIC_ED      844    /* MSG "Item defined is numeric edited" */
#define UE_ITEM_USAGE_INDEX     845    /* MSG "Item defined is USAGE INDEX" */
#define UE_ITEM_USAGE_PTR       846    /* MSG "Item defined is USAGE POINTER" */
#define UE_COLS_OMITTED         847    /* MSG "One or more columns were omitted due to the presence of" */
#define UE_NOT_SUPP_ODBC        848    /* MSG "This option is not supported by the ICOBOL ODBC driver" */
#define UE_ITEM_KEY             849    /* MSG "Item defined was a key or key segment.  Type changed from" */
#define UE_H_OPT                850    /* MSG "The -H option was already specified" */
#define UE_H_INV                851    /* MSG "Invalid argument for -H option" */
#define UE_UIB_WRONG_DLL        852    /* MSG "The panel editor is using the wrong dynamic link library (UIB.DLL)" */
#define UE_UIB_EDITOR_ERR       853    /* MSG "An error has occurred in the panel editor" */
#define UE_UIB_UNKNOWN_ERR      854    /* MSG "The panel editor return code is unknown" */
#define UE_INPUT_ZERO           855    /* MSG "Zero-length input count" */
#define UE_BAD_REPLACE_ALL      856    /* MSG "The search string cannot be a subset of the replacement string" */
#define UE_DELIM_INPUT_ONLY     857    /* MSG "The DELIMITED phrase is only allowed on INPUT files" */
#define UE_EXP_CNT_LEN          858    /* MSG "COUNT or LENGTH is expected here" */
#define UE_INV_OPTION           859    /* MSG "Invalid option" */
#define UE_INV_OPTION_VALUE     860    /* MSG "Invalid value for option" */
#define UE_Ll_CONF_FPT          861    /* MSG "The -L and -l options conflict with the -F, -P, and -T options" */
#define UE_Ll_REQ_b             862    /* MSG "The -L and -l options require the the -b option" */
#define UE_EXP_LEFT_RIGHT       863    /* MSG "LEFT or RIGHT is expected here" */
#define UE_EXP_DEFINE           864    /* MSG "DEFINE is expected here" */
#define UE_EXP_KEY              865    /* MSG "A KEY phrase is expected here" */
#define UE_EXP_READ_WRITE       866    /* MSG "READ or WRITE is expected here" */
#define UE_EXP_KEYS_RECS        867    /* MSG "KEYS or RECS is expected here" */
#define UE_DUPL_INPUT           868    /* MSG "An input file by this name has already been defined" */
#define UE_FILE_NOT_DEF         869    /* MSG "The file name is not defined" */
#define UE_TAG_NO_CMDS          870    /* MSG "This option cannot be specified with WHEN READ processing" */
#define UE_DUPL_FILE_CMDS       871    /* MSG "A WHEN section has already been specified for this file" */
#define UE_DUPL_INPUT_CMDS      872    /* MSG "A WHEN section for generic input has already been specified" */
#define UE_DUPL_OUTPUT_CMDS     873    /* MSG "A WHEN section for generic output has already been specified" */
#define UE_EXP_USAGE            874    /* MSG "A valid numeric USAGE is expected here" */
#define UE_EXP_CONVERT_OPT      875    /* MSG "A CONVERT TO option is expected here" */
#define UE_OPTION_IGNORED       876    /* MSG "The following option is no longer supported and is being ignored" */
#define UE_Ov_REQ_BDEPSU        877    /* MSG "The -O v option requires at least one of either -B, -D, -E, -P, -S, or -U" */
#define UE_C_REQ_B              878    /* MSG "The -C option can only be used with the -B option" */
#define UE_C_IS_REQD            879    /* MSG "The -C option is required to specify a command to perform" */
#define UE_D_REQ_Ocv            880    /* MSG "The -D option can only be used with -O c or -O v" */
#define UE_E_REQ_Ocv            881    /* MSG "The -E option can only be used with -O c or -O v" */
#define UE_P_REQ_Ocuv           882    /* MSG "The -P option can only be used with -O c, -O u, or -O v" */
#define UE_U_REQ_Ocuv           883    /* MSG "The -U option can only be used with -O c, -O u, or -O v" */
#define UE_RECOVERY_MISMATCH    884    /* MSG "The screen setup does not match the recovery information" */
#define UE_M_REQ_O              885    /* MSG "The -M option requires -O" */
#define UE_Aa_INV               886    /* MSG "Invalid argument for -a or -A option" */
#define UE_FILE_DELETED         887    /* MSG "The file was deleted" */
#define UE_RECOVERY_NOT_SUP     888    /* MSG "The server does not support the crash recovery connection option" */
#define UE_Oo_OPT               889    /* MSG "The -o or -O option was already specified" */
#define UE_Or_REQ_M             890    /* MSG "The -O r option requires -M" */
#define UE_Ol_CONFL_M           891    /* MSG "The -O l option can not be used with -M" */
#define UE_Oa_INV_BDEPSUT       892    /* MSG "The -O a option can not be used with -B, -D, -E, -P, -S, -T, or -U" */
#define UE_Oa_REQ_C             893    /* MSG "The -O a option requires the -C option" */
#define UE_Ou_REQ_PUT           894    /* MSG "The -O u option requires the -P, -U, and -T options" */
#define UE_Ou_INV_BCDES         895    /* MSG "The -O u option can not be used with -B, -C, -D, -E, or -S" */
#define UE_T_REQ_Ou             896    /* MSG "The -T option can only be used with -O u" */
#define UE_RECOVERY_FAILED      897    /* MSG "The attempt to reconnect with the crash recovery information failed" */
#define UE_NO_MULTIPLE_RECOVERY 898    /* MSG "An icrunrc with crash recovery is already running for this server; crash recovery is being disabled" */
#define UE_UI_INIT              899    /* MSG "A user interface element failed to initialize properly" */
#define UE_FILE_CREATED         900    /* MSG "The file was created" */
#define UE_FILE_NOT_IN_PROJ     901    /* MSG "The file is not in the project database" */
#define UE_X_REQ_M              902    /* MSG "The -X option requires the -M option" */
#define UE_IS_MODIFIED          903    /* MSG "The item has been modified and requires processing" */
#define UE_IC2X_NO_DEBUG        904    /* MSG "The ICOBOL 2 runtime mode does not support debugging" */
#define UE_zZ_OPT               905    /* MSG "The -z or -Z option was already specified" */
#define UE_zZ_IGN               906    /* MSG "The -z or -Z (debug) option is being ignored" */
#define UE_REQ_DEBUG_PRIV       907    /* MSG "The Debug privilege is required to run in debug mode" */
#define UE_INV_CMD_REPL         908    /* MSG "Invalid command-line replacement argument" */
#define UE_NO_ACTIVE_DOC        909    /* MSG "There is no current document: unable to determine replacement argument" */
#define UE_NO_PROJECT_ARG       910    /* MSG "There is no open project, or the requested field is not configured: unable to determine replacement argument" */
#define UE_S_CONFLICTS          911    /* MSG "The -S option conflicts with the following option:" */
#define UE_WIRE_PQ              912    /* MSG "Locking .pq file" */
#define UE_PQ_Q_COUNT           913    /* MSG "Invalid PCQ Queue count" */
#define UE_PQ_JOB_COUNT         914    /* MSG "Invalid PCQ Job count" */
#define UE_BAD_PQ_Q_COUNT       915    /* MSG ".pq file error: the queue count has changed" */
#define UE_BAD_JOB_COUNT        916    /* MSG ".pq file error: the job count has changed" */
#define UE_INV_PCQ_COUNT        917    /* MSG "The PCQ count exceeds the queue count available in the .pq file" */
#define UE_UPGRADE_PQ           918    /* MSG "Attempting to upgrade the .pq file" */
#define UE_RENAME_PQ            919    /* MSG "The old .pq file has been renamed to" */
#define UE_UPGRADE_PQ_FAIL      920    /* MSG "Upgrade of .pq file has failed" */
#define UE_INV_DISP             921    /* MSG "has an invalid disposition value" */
#define UE_INV_FEEDBACK         922    /* MSG "Invalid Feedback" */
#define UE_GqR_OPT              923    /* MSG "The -G q options requires code revision 3 or above" */
#define UE_L_CONFLICTS          924    /* MSG "The -L option conflicts with -C, -K, -S, -T, and -V" */
#define UE_OPTS_REQ_ENA         925    /* MSG "The -L, -M, and -R options are only valid for -O e or -O u" */
#define UE_LOG_OP_CORRUPT       926    /* MSG "The log operation packet appears to be corrupt" */
#define UE_D_REQ_LIST           927    /* MSG "The -D options are only valid for -O l" */
#define UE_XL_REQ_O_l           928    /* MSG "An argument with the .xl extension is only valid for -O l" */
#define UE_INV_OPER_SLAVE       929    /* MSG "(unused) Operation must be applied to the master file, not the remote or mirror file" */
#define UE_DIFF_SERVERS         930    /* MSG "The -M and -R options may not specify the same server" */
#define UE_INV_NOT_SLAVE        931    /* MSG "Operation is only valid for a mirror slave file" */
#define UE_INV_NOT_MASTER       932    /* MSG "Operation is only valid for a mirror master file" */
#define UE_NO_PROMOTED          933    /* MSG "Operation cannot be performed on a promoted mirror file" */
#define UE_LOG_MISMATCH         934    /* MSG "The ISAM file and its log file, mirror file, or remote log do not match" */
#define UE_SYNC_REQ_REMOTE      935    /* MSG "Synchronize requires a remote log file" */
#define UE_SYNC_REQUIRED        936    /* MSG "ICLOG Sync is required" */
#define UE_NO_SLAVE             937    /* MSG "Operation cannot be performed on a mirror slave file" */
#define UE_RECOVER_REQUIRED     938    /* MSG "ICLOG Recover is required" */
#define UE_LOG_TOO_FEW          939    /* MSG "Log has too few operations" */
#define UE_LOG_TOO_MANY         940    /* MSG "Log has additional operations, use ICLOG Apply" */
#define UE_INFO_POSTED          941    /* MSG "Current information has been posted" */
#define UE_LIC_LOCAL            942    /* MSG "Local licensing has been selected" */
#define UE_LIC_REMOTE           943    /* MSG "Remote licensing has been selected" */
#define UE_LIC_INITDRV          944    /* MSG "Error initializing the hardware driver" */
#define UE_LIC_REM_ONLY         945    /* MSG "Only the remote license server can be authorized to run" */
#define UE_LIC_UNSUPP_ID_IGN    946    /* MSG "The license entry is for a product that is not supported by this icpermit and is being ignored" */
#define UE_LIC_UNSUPP_REV_IGN   947    /* MSG "The license entry is for a revision that is not supported by this icpermit and is being ignored" */
#define UE_LIC_UPDATE_ERRS      948    /* MSG "The attempt to update the license database failed.  See the icpermit log." */
#define UE_LIC_UPDATE_CONFLICT  949    /* MSG "The newly added license conflicts with an existing license entry. Restart icpermit." */
#define UE_LIC_UPDATED          950    /* MSG "The software licenses have been updated" */
#define UE_LIC_FAILSAFE_OFF     951    /* MSG "The system is no longer authorized from the failsafe protection file" */
#define UE_LIC_UPDATE_PROT      952    /* MSG "The license protection has changed and is being updated and reauthorized" */
#define UE_LIC_BAD_IPC          953    /* MSG "Invalid IPC connection to icpermit (probably mismatched icpermits)" */
#define UE_IPC_CREATE_REQ       954    /* MSG "Creating the request IPC message queue" */
#define UE_IPC_SEND_REQ         955    /* MSG "Sending to the request IPC message queue" */
#define UE_IPC_RECV_REQ         956    /* MSG "Receiving from the request IPC message queue" */
#define UE_IPC_REMOVE_REQ       957    /* MSG "Removing the request IPC message queue" */
#define UE_IPC_CREATE_REPLY     958    /* MSG "Creating the reply IPC message queue" */
#define UE_IPC_SEND_REPLY       959    /* MSG "Sending to the reply IPC message queue" */
#define UE_IPC_RECV_REPLY       960    /* MSG "Receiving from the reply IPC message queue" */
#define UE_IPC_REMOVE_REPLY     961    /* MSG "Removing the reply IPC message queue" */
#define UE_LIC_c_O              962    /* MSG "The -c option conflicts with the -O option" */
#define UE_LIC_CHANGED          963    /* MSG "The license information has changed and is being updated" */
#define UE_LIC_REMOVED          964    /* MSG "The license is being removed" */
#define UE_LIC_ADDED            965    /* MSG "The license has been added" */
#define UE_LIC_NO_CONN          966    /* MSG "The process has no connection to the license server" */
#define UE_LIC_S_DIED           967    /* MSG "The license server terminated unexpectedly" */
#define UE_LIC_INV_SEL          968    /* MSG "Invalid information selector index" */
#define UE_LIC_INV_HAN          969    /* MSG "Invalid license server handle" */
#define UE_LIC_NOT_OPEN         970    /* MSG "The license handle is not open" */
#define UE_LIC_UNCHANGED        971    /* MSG "The license information has not changed and the update was ignored" */
#define UE_LIC_CON_REQ          972    /* MSG "Unable to connect to the license server socket" */
#define UE_LIC_CON_HAN          973    /* MSG "Unable to establish a license server connection" */
#define UE_LIC_CONN_CNT         974    /* MSG "There are no more license server connections available" */
#define UE_LIC_DUP_CONN         975    /* MSG "Application error: process is already connected" */
#define UE_LIC_CONN_BAD         976    /* MSG "Internal server error: connection table is corrupt" */
#define UE_LIC_UNSUPPORTED_MSG  977    /* MSG "The icpermit server does not support the requested operation" */
#define UE_LIC_CONN_INV         978    /* MSG "Invalid connection handle to server" */
#define UE_LIC_INV_OPER         979    /* MSG "Invalid command request from client" */
#define UE_LIC_SITE             980    /* MSG "Usage is governed by the terms of the Site License with " */
#define UE_LIC_EXP_DATE         981    /* MSG "The software license will expire " */
#define UE_LIC_EXPIRED          982    /* MSG "The software license has expired" */
#define UE_LIC_NOT_AUTH         983    /* MSG "The required software license is not authorized" */
#define UE_LIC_OPEN_CNT         984    /* MSG "The maximum user count for this license has been reached" */
#define UE_LIC_OPEN_MEM         985    /* MSG "The license server cannot allocate a new license handle" */
#define UE_LIC_BAD_REV          986    /* MSG "The software license does not authorize this version of the program" */
#define UE_LIC_BAD_OPTS         987    /* MSG "The software license does not authorize required features of the program" */
#define UE_LIC_CORR_1           988    /* MSG "The software license has been modified" */
                                       /* */
                                       /* */
#define UE_LIC_DISABLED         991    /* MSG "The software licenses have been disabled" */
#define UE_LIC_ENABLED          992    /* MSG "The software licenses have been re-enabled" */
#define UE_LIC_REM_SELF         993    /* MSG "Remote licensing cannot be directed to the local machine" */
#define UE_LIC_STARTED          994    /* MSG "The license server has been started" */
                                       /* */
#define UE_LIC_NOT_PERM         996    /* MSG "The operation can only be performed by the license server" */
#define UE_LIC_COUNT            997    /* MSG "No more licenses can be handled by the license server" */
#define UE_LIC_OS_AUTH          998    /* MSG "The license is not authorized for this operating system/environment" */
#define UE_LIC_READY            999    /* MSG "The license server is ready" */
#define UE_LIC_BEG_TERM         1000    /* MSG "Beginning license server termination" */
                                        /* */
#define UE_LIC_BAD_DATA         1002    /* MSG "Invalid or mis-matched license information" */
#define UE_LIC_DUPL_LIC         1003    /* MSG "Duplicate entries for the same license" */
#define UE_LIC_PROC_LIC         1004    /* MSG "Processing license description file" */
#define UE_LIC_PROT_DEV         1005    /* MSG "Processing protection device authorization, please wait..." */
#define UE_TRACING_OFF          1006    /* MSG "Tracing of requests has been disabled" */
#define UE_TRACING_ON           1007    /* MSG "Tracing of requests has been enabled" */
#define UE_LIC_OPENED           1008    /* MSG "The software license has been opened" */
#define UE_LIC_CLOSED           1009    /* MSG "The software license has been closed" */
#define UE_LIC_PROT_CON         1010    /* MSG "License descriptions have conflicting protection device information" */
#define UE_LIC_FAILSAFE_ON      1011    /* MSG "The system is authorized from the failsafe protection file" */
#define UE_LIC_PROT_MIS         1012    /* MSG "License description does not match the protection device information" */
#define UE_LIC_DEMO             1013    /* MSG "Software License is for DEMONSTRATION PURPOSES ONLY" */
#define UE_LIC_DEMO_TO          1014    /* MSG "Software License is for DEMONSTRATION PURPOSES ONLY from " */
#define UE_LIC_NOTHING          1015    /* MSG "No licenses are authorized" */
#define UE_LIC_CHECK_OK         1016    /* MSG "License check was successful" */
#define UE_LIC_EXPAND           1017    /* MSG "Expanding PLUS license into a RUN license and a DEV license" */
#define UE_LIC_INV_PROT         1018    /* MSG "Unsupported license protection type for this operating system" */
                                        /* */
#define UE_LIC_RUNNING          1020    /* MSG "The license server is running" */
                                        /* */
                                        /* */
                                        /* */

#define UE_MAX_ERROR            1023    /* maximum allowable utility error number */



